{**********************************************************}
{              CLOSIM v 1.00  --  TOOLBOX UNIT             }
{**********************************************************}
{ Containing various tools for the simulation program on   }
{ the Closure of Tidal Basins, written in Turbo Pascal 7.0 }
{ and Turbo Vision Graphics by Mark Middag, TUDelft, 1994. }
{**********************************************************}

Unit SimTools;

Interface

uses CRT, DOS, Memory,                                            {Dos Units}
     GObjects, GDrivers,			      {Turbo Vision Graphics}
     MCursor2, GMENU6,
     GViews,  GDialogs,
     GMsgBox, GStdDlg,
     GApp, GColors, GWindow,
     BMPDrvr, GBut,
     MyGraph3, GraphPrc,                       {Extended Graphics Procedures}

     SIMVARS;                    {Simulation Program Variables and Constants}


function  N(Nummer: Real): String;                {Converts Real into String}
function  I(Nummer: Real): String;             {Converts Integer into String}
function  T(Nummer: Real): Integer;              {Converts Real into Integer}
function  Sgn(Nummer: Real): Integer;     {Indicates Sign of Number (-1,0,1)}
function  Power(x,a: Real): Real;                     {Normal Power Function}
function  Max(a,b: Real): Real;            {Gives the maximum of two numbers}
Function  Min(a,b: Real): Real;            {Gives the minimum of two numbers}
function  Tan(x: Real): Real;                                  {Tan Function}
function  ArcSin(x: Real): Real;                           {Arc Sin Function}
function  Log(A: Real): Real;                                  {Log Function}
function  SeaLevel(MeanSeaLevel: Real;             {Calculation of Sea Level}
		   TideAmp,
		   TidePeriod,
		   TidePhase0: RealArr;
		   JobHours: Real): Real;
function  MouseX: Integer;                               {Mouse X Coordinate}
function  MouseY: Integer;                               {Mouse Y Coordinate}
function  MouseK: Integer;                                 {Mouse Key Status}
function  MousePressed: Boolean;                      {Whether Mouse Pressed}
function  MouseStabile: Boolean;                      {Whether Mouse Touched}
Function  Value(S: String): Real;               {Numerical Value of a String}
procedure WaitMouse;                                   {Wait for Mouse Event}
procedure Opt_ToggleSound;                              {Toggle Sound On/Off}
procedure Beep;                                            {Produce one Beep}
procedure MultiBeep;                                {Produce Series of Beeps}
procedure EverySecond;                                {Programmer's Use Only}
procedure Opt_Quit;                                             {Quit to Dos}
procedure Plot(x1,y1,Color: real);                   {Extended Plot Function}
procedure DrawTo(x1,y1: Real);                       {Extended Draw Function}
procedure MoveCurs(x1,y1: Real);                     {Extended Move Function}
procedure DrawLine(x1,y1,x2,y2: Real);               {Extended Line Function}
procedure TextXY(x1,y1: Real; S: String);       {Extended OutTextXY Function}
procedure Wipe(x1,y1,x2,y2: Real);                                {Wipe Area}
procedure Box(x1,y1,x2,y2: Real);                                  {Draw Box}
procedure FillBox(x1,y1,x2,y2: Real);                             {Fill Area}
procedure CalculateRequiredVolume(Width: RealArr);          {Required Volume}
Procedure DataTextXY(X, Y: Integer; S: String; Data: Real);    {Text Numbers}
Procedure StartPermission(                        {Check whether the Process}
	  Var Ers: String; var Perm: Boolean);               {can be started}
Procedure SetStartDraws;                               {Reset Draw Variables}
Procedure NoActivities;                    {Stop All Construction Activities}
Procedure Tempor_Interr_Calc;	     {Temporary Interruption of Calculations}
Procedure Tempor_Resume_Calc;               {Continue Calculations if needed}
Procedure SetDialogGradual;			       {Set dialog box cells}
Procedure MaxCheck;		     {Check for greatest and smallest values}
Function StorageSurface(Level: Real): Real;       {Calculate Storage Surface}

const NoB = 1;				                      {Button Status}
      BothB = 2;
      RightB= 3;
      LeftB = 4;

var MX, MY: Real;			        {Scaling Factor for Drawings}

Implementation                             {Definition of written procedures}


procedure Tempor_Interr_Calc;        {Temporary interruption of calculations}
begin
   OStarted:=Started; Started:=False;
end;

procedure Tempor_Resume_Calc;	            {continue calculations if needed}
begin
   Started:=OStarted;
   Dialoged:=True;
end;

function N(Nummer: Real): String;       {Convert real variables into strings}

Var s:String[20];

begin
   Str(Nummer:0:2, S);
   if Nummer*10=Round(Nummer*10) then Str(Nummer:0:1, S);
   if Nummer=Round(Nummer) then Str(Nummer:0:0, S);
   N:=S;
end;

function I(Nummer: Real): String;    {Convert integer variables into strings}

var s: String[25];

begin
   Str(Nummer:0:0, S);
   I:=S;
end;



function T(Nummer: Real): Integer;     {Convert integer variables into reals}

var N: Integer;

begin
   N:=Round(Nummer);
   T:=N;
end;

function Sgn(Nummer: Real): Integer;       {Return sign of variable (-1,0,1)}

var s: Integer;

begin
   if nummer<0 then s:=-1;
   if nummer>0 then s:=1;
   if nummer=0 then s:=0;
   Sgn:=S;
end;

Function Value(S: String): Real;           {Return Numerical Value of String}

var N: Real;
    Control: Integer;

begin

   Val(S, N, Control);
   Value:=N;

end;

Function SeaLevel(MeanSeaLevel: Real;	                {Calculate Sea Level}
		  TideAmp,
		  TidePeriod,
		  TidePhase0: RealArr;
		  JobHours: Real): Real;

var phase, SL: real;

begin

  SL:=MeanSeaLevel;
  for Counter:=1 to 4 do          {Add Actual Value of All Tidal Compontents}
  begin
      if TidePeriod[Counter]<>0 then
      begin
	 Phase:=((JobHours*3600 + TidePhase0[Counter]) / TidePeriod[Counter]);
	 SL:= SL + TideAmp[Counter]*sin(2*pi*phase);
      end;
  end;
  if TimeToStorm>0 then                                     {Add Storm Setup}
  begin
     if StormChance=1 then StormChance:=0;
     ActStormSurge:=Abs(1-Cos(2*PI*(1-Abs(TimeToStorm/(StormPeriod*3600)))))
		    *StormSurge/2;
     SL:=SL+ActStormSurge;
     TimeToStorm:=TimeToStorm-TimeStep;
     if TimeToStorm<0 then TimeToStorm:=0;
     if TimeToStorm=0 then ActStormSurge:=0;
  end;
  SeaLevel:=SL;
end;

Function StorageSurface(Level: Real): Real;       {CALCULATE STORAGE SURFACE}

var ks: Real;      {temporal variable for storage surface}
     k: Integer;   {data point counter}

begin
   For k:=1 to 5 do                                     {for ALL data points}
   if (Level>KomDepth[k-1])
    and (Level<KomDepth[k]) then               {IF level between data levels}
   begin
      ks:=KomSur[k-1]+
	  (Level-KomDepth[k-1])*
	  (KomSur[k]-KomSur[k-1])/
	  (KomDepth[k]-KomDepth[k-1]);     {INTERPOLATE surface between data}
   end;
   StorageSurface:=ks;                       {RETURN VALUE for basin surface}
end;

Function Power(x, a: Real): Real;                  {Return power of argument}

var xb, ab, pow: Real;

begin
    xb:=abs(x);
    ab:=abs(a);
    if xb<>0 then pow:=exp(ab*ln(xb))
	     else pow:=0;
    if a<0 then pow:=1/pow;
    power:=pow;

end;

function Log(A: Real): Real;		       {Return logarithm of argument}

begin
   if A>0 then Log:=ln(A)/Ln(10)
	  else Log:=0;
end;

Function Max(a,b: Real): Real;              {Return Maximum of two variables}

begin
   if a>b then Max:=A
	  else Max:=B;
end;

Function Min(a,b: Real): Real;              {Return Minimum of two variables}

begin
   if a<b then Min:=A
	  else Min:=B;
end;

Function Tan(x: Real): Real;                         {Return Tan of Argument}

var Tn: Real;

begin

    if Cos(x)<>0 then Tn:=Sin(X)/Cos(X)
		 else Tn:=0;

    Tan:=Tn;

end;

procedure MaxCheck;

begin
   for GCT:=1 to NumOfGaps do
   begin
      if GapWidth[GCT]<20 then GapWidth[GCT]:=20;
      if GapWidth[GCT]>10000 then GapWidth[GCT]:=10000;
      if GradualLeft[GCT]>20000 then GradualLeft[GCT]:=20000;
      if GradualLeft[GCT]<0 then GradualLeft[GCT]:=0;
      if GradualRight[GCT]>20000 then GradualRight[GCT]:=20000;
      if GradualRight[GCT]<0 then GradualRight[GCT]:=0;
      if GradualUp[GCT]>20000 then GradualUp[GCT]:=20000;
      if GradualUp[GCT]<0 then GradualUp[GCT]:=0;
      if DamD50[GCT]<0 then DamD50[GCT]:=0;
      if DamD50[GCT]>4000 then DamD50[GCT]:=4000;
      if DamTopWidth[GCT]>400 then DamTopWidth[GCT]:=400;
      if DamTop[GCT]>35 then DamTopWidth[GCT]:=35;
      if DamTopWidth[GCT]<0 then DamTopWidth[GCT]:=0;
   end;
   for Counter:=1 to 5 do
   begin
      if KomSur[Counter]>500000000 then KomSur[Counter]:=500000000;
      if KomSur[Counter]<15000 then KomSur[Counter]:=15000;
   end;
   if VesselDraft<2 then VesselDraft:=2;
   if RiverFlow>10000 then RiverFlow:=10000;
   if StormSurge>15 then StormSurge:=15;
   if StormSurge<0 then StormSurge:=0;
   if StormPeriod<0 then StormPeriod:=0;
   if StormPeriod>750 then StormPeriod:=750;
   if StormChance>1 then StormChance:=1;
   if StormChance<0 then StormChance:=0;
   if Chezy>120 then Chezy:=120;
   if Chezy<20 then Chezy:=20;
   if BottomD50<0.1 then BottomD50:=0.1;
   if BottomD50>4000 then BottomD50:=4000;
end;

procedure NoActivities;                    {Stop All Construction Activities}

begin
   for GCT:=1 to NumOfGaps do
   begin
	 GradualLeft[GCT]:=0; GradualRight[GCT]:=0; GradualUp[GCT]:=0;
   end;
end;

function ArcSin(x: Real): Real;                  {Return Arc Sin of Argument}

begin

    ArcSin := ArcTan (x/SqRt (1-Sqr(x)));

end;

Procedure WaitMouse;                      {Wait until mouse has been pressed}

begin

    repeat until mousepressed;
    repeat until mousepressed=false;

end;

Function MouseStabile: Boolean;	      {Whether Mouse is being Touched or Not}

begin
    if MouseX*MouseY = MouseSum then MouseStabile:=True
				else MouseStabile:=False;

    MouseSum:=MouseX*MouseY;
end;

procedure Beep;                                          {Produce short beep}

begin
   for Counter:=0 to 10 do
   begin
      Sound(800+Counter*50); Delay(5); NoSound; Delay(2);
   end;
end;

procedure MultiBeep;                                {Produce Series of Beeps}

begin
   If Mousek=3 then Halt;
   Beep; Beep; Beep; Beep;
   Beep; Beep; Beep; Beep;
end;

procedure Opt_ToggleSound;                              {Toggle Sound On/Off}
begin
  if SoundOn=True  then SoundOn:=False
		   else SoundOn:=True;
end;

Procedure EverySecond;                  {Programmer's Use, Window Management}

begin
  if mousek=2 then delay(500);
  if mousek=3 then begin halt; end;
  if (DrawCounter/40)=Int(DrawCounter/40) then
     begin
	if SomethingDrawn=False then OverallOpen:=False;
	if SomethingWritten=False then DataBoxOpen:=False;
     end;
  Inc(DrawCounter);
  if (DrawCounter/40)=Int(DrawCounter/40) then
     begin SomethingDrawn:=False; SomethingWritten:=False end;

end;

procedure Opt_Quit;				    {Exit Program, Go to Dos}
begin
   Halt;
end;

Procedure Get_Mouse_Action				       {Mouse Status}
	  (var But: Integer; var Hor,Ver: integer);
var
  Reg: registers;
begin
    with Reg do
    begin
	Ax := 3;
	Intr($33,Reg);
	Hor := Cx div 8;
	Ver := Dx div 8;
	{$B+}
	If ((Bx and $1) <> $1)  and  ((Bx and $2) <> $2) then
	begin
	    But := NoB;
	    exit;
	end;
	If ((Bx and $1) = $1)  and   ((Bx and $2) = $2) then
	   But := BothB
	else
	begin
	    If (Bx and $1) = $1 then
	       But := LeftB
	    else
	       But := RightB;
	end;
	{$B-}
    end;
end;

Function Mousek;				           {Mouse Key Status}

var a,b,c: integer;

begin
   Get_Mouse_Action(a,b,c);
   if a = NoB then mousek:=0;
   if a = leftb then mousek:=1;
   if a = rightb then mousek:=2;
   if a = bothb then mousek:=3;
end;

Function MousePressed;                     {Whether Mouse Key Pressed or Not}

begin
   if Mousek>0 then MousePressed:=True
	       else MousePressed:=False;
end;

Function Mousex;				         {Mouse X Coordinate}

var a,b,c: integer;

begin
   Get_Mouse_Action(a,b,c);
   Mousex:=b;
end;


Function Mousey;                                         {Mouse Y Coordinate}

var a,b,c: integer;

begin
   Get_Mouse_Action(a,b,c);
   Mousey:=c;
end;

			   {The Graphics Functions below have been extended;}
			       {they now are scaled according to the monitor}
			     {type and can deal with real variables as well.}

procedure Plot(x1,y1,Color: real);		     {Extended Plot Function}
begin
  MY:=GetMaxY/480; MX:=GetMaxX/640;
  PutPixel(Round(X1*MX),Round(Y1*MY), Round(Color));
end;

procedure DrawTo(x1,y1: Real);			     {Extended Draw Function}
begin
  MY:=GetMaxY/480; MX:=GetMaxX/640;
  LineTo(Round(X1*MX),Round(Y1*MY));
end;

procedure MoveCurs(x1,y1: Real);		     {Extended Move Function}
begin
  MY:=GetMaxY/480; MX:=GetMaxX/640;
  MoveTo(Round(X1*MX),Round(Y1*MY));
end;

procedure DrawLine(x1,y1,x2,y2: Real);		     {Extended Line Function}
begin
  MY:=GetMaxY/480; MX:=GetMaxX/640;
  MoveTo(Round(X1*MX),Round(Y1*MY));
  LineTo(Round(X2*MX),Round(Y2*MY));
end;

procedure Wipe(x1,y1,x2,y2: Real);                     {Erase Area of Screen}
begin
  MY:=GetMaxY/480; MX:=GetMaxX/640;
  SetFillStyle(SolidFill,0);
  Bar(Round(X1*MX),Round(Y1*MY),Round(X2*MX),Round(Y2*MY));
end;

procedure TextXY(x1,y1: Real; S: String);       {Extended OutTextXY function}
begin
  SetTextStyle(DefaultFont, HorizDir, 1);
  SetTextJustify(LeftText, CenterText);
  MY:=GetMaxY/480; MX:=GetMaxX/640;
  Wipe(X1*Mx-04, Y1*My-8, X1*MX+120, Y1*My+8);
  OutTextXY(Round(X1*MX),Round(Y1*MY),S);
end;

Procedure DataTextXY(X, Y: Integer;		{Numerical Data to OutTextXY}
			S: String; Data: Real);
begin
   Wipe(X-4,Y-8, X+180, Y+8);
   TextXY(X,Y, S + N(Data));
end;

procedure SetDialogGradual;

begin
   for GCT:=1 to NumOfGaps do
   if (WayOfConstruction[GCT]=csSandDump) or
      (WayOfConstruction[GCT]=csTrucks) then
      begin
	 HorOn[GCT]:=8;
	 VerOn[GCT]:=0;
	 GradualUp[GCT]:=0
      end
      else
      begin
	 HorOn[GCT]:=0;
	 VerOn[GCT]:=8;
	 GradualLeft[GCT]:=0;
	 GradualRight[GCT]:=0;
      end;
end;

procedure Box(x1,y1,x2,y2: Real);			           {Draw Box}
begin
  MY:=GetMaxY/480; MX:=GetMaxX/640;
  Rectangle(Round(X1*MX),Round(Y1*MY),Round(X2*MX),Round(Y2*MY));
end;

procedure FillBox(x1,y1,x2,y2: Real);			{Fill Area on Screen}

var T: Integer;

begin
   for T:=Round(X1) to Round(X2) do DrawLine(t,y1,t,y2);
end;

procedure CalculateRequiredVolume(Width: RealArr);   {Required Volume of Dam}

var H: Real;                                                {Height variable}

begin
   for GCT:=1 to NumOfGaps do                      {calculation for all gaps}
   begin
      H:=DamTop[GCT]-YDR[GCT];               {Height still to be constructed}
      if Tan(DSS[GCT])<>0 then                    {Not to be divided by zero}
      RequiredVolume[GCT]:=              {Volume which is still to be dumped}
	   Width[GCT]*(                                       {Length of dam}
	   (DamTopWidth[GCT]*H)+                         {Rectangular centre}
	   (H/Tan(DSS[GCT]))*H);                                      {Slope}
      RequiredVolume[GCT]:=                   {In case the angle is changed,}
      RequiredVolume[GCT]+             {material can have been dumped before}
      ActualVolume[GCT];
   end;
end;

procedure SetStartDraws;                        {Reset all Drawing Variables}
begin
    for GCT:=1 to NumOfGaps do
    if GCT<>1 then
       StartDrawX[GCT]:=StartDrawX[GCT-1]+10+OrigGapWidth[GCT-1]*WidthFact
	      else
       StartDrawX[GCT]:=10;
end;

procedure StartPermission			{Check All Data before start}
	  (Var Ers: String; var Perm: Boolean);

begin
    Perm:=True;                       {If nothing wrong, permission is given}
    Ers:='';
    for GCT:=1 to NumOfGaps do
    begin
       if RequiredVolume[GCT]=0 then Ers:='dimensions'; {If Something wrong,}
       if (GapWidth[GCT]<=0) then Ers:='gap width';        {no permission is}
      {if (DamTop[GCT]<=0)  then Ers:='dam top';                {given and a}
       if (Tan(DSH[GCT])=0) then Ers:='dam head angle';    {warning appears.}
       if (Tan(DSS[GCT])=0) then Ers:='dam side angle';
       if (DamD50[GCT]<0.15)  then Ers:='dam material';
    end;
    if Ers<>'' then Perm:=False;
end;

end.
