{**********************************************************}
{            CLOSIM v 1.00  --  MAIN PROGRAM SHELL         }
{**********************************************************}
{ Containing the Turbo Vision Graphics User Interface for  }
{ the simulation program on the Closure of Tidal Basins.   }
{ Written in Turbo Pascal 7.0 by Mark Middag, TUDelft, 1994}
{**********************************************************}

Program Sim2;

uses CRT, DOS,                                      {Borland Turbo Pascal 7.0}
     Memory,                                               {Memory Procedures}
     MyGraph3,                                     {Advanced Graphics Library}
     GObjects, GDrivers,                         {Turbo Vision Graphics Units}
     MCursor2, GMENU6,
     GViews,   GDialogs,
     GMsgBox,  GStdDlg,
     GApp,     GColors,
     GWindow,  GBut,
     BMPDrvr,

     SIMVARS,                                              {Program Variables}
     GSIMOPTS,                                                  {Menu Options}
     GSIMDIAL,                               {Dialog Boxes and User Interface}
     SIMTOOLS,                                     {Various Programming Tools}
     SIMHELP,                                        {On Line Help Procedures}
     SIMCALC,                         {Calculation for Closure of Tidal Basin}
     SIMDRAWS;                             {Graphical Presentation of Results}

					    {The procedure declarations below}
				    {cause compiler to link in Bitmap Buttons}
procedure ICSAVE;   external;          {The Bitmap Buttons appear on the left}
{$L ICSAVE.OBJ}                                         {side of the desktop.}
procedure ICLOAD;   external;             {Bitmap Buttons can be edited using}
{$L ICLOAD.OBJ}                               {Window's PaintBrush and after,}
procedure ICTOGGLE; external;                     {apply the programs BMP2BMG}
{$L ICTOGGLE.OBJ}                                             {and BINOBJ.EXE}
procedure ICWINDOW; external;
{$L ICWINDOW.OBJ}
procedure ICDATBOX; external;
{$L ICDATBOX.OBJ}
procedure ICNEWCL;  external;
{$L ICNEWCL.OBJ}
procedure ICINTRO;   external;
{$L ICINTRO.OBJ}
procedure ICQUIT;   external;
{$L ICQUIT.OBJ}
procedure ICSHELL;  external;
{$L ICSHELL.OBJ}
procedure ICGRAD;   external;
{$L ICGRAD.OBJ}
procedure ICSTORM;  external;
{$L ICSTORM.OBJ}

var
  OldExitProc : Pointer;                        {Saves Exit Procedure Address}
  Graphic     : boolean;                  {True if Screen is in Graphics Mode}

procedure GExitProc; far;      {Restores screen to Text Mode if Program Halts}
begin
  ExitProc := OldExitProc;                   {Restores Exit Procedure Address}
  CloseGraph;                                  {Shut Down the Graphics System}
end;


function GSystemError(ErrorCode: integer;            {Error Warning Procedure}
	      Drive: byte): Integer; far;

const
  SRetryOrCancel:  string[30] = '~Enter~: Retry  ~Esc~: Cancel';
var
  P: Pointer;
  S: string;
  X,YOff : integer;
  SS : string;
  VPort : ViewPortType;
  SaveText : TextSettingsType;
begin
  P := Pointer(Drive + Ord('A'));
  FormatStr(S, GetCritErrorStr(ErrorCode), P);
  SS := S + '      ' + SRetryOrCancel;
  X := (GetMaxX - (Length(SS))*Charlen) div 2;

  GetViewSettings(VPort);                              {save current viewport}
  SetViewPort(0,0,GetMaxX,GetMaxY,ClipOn);                {set to full screen}

  GetTextSettings(SaveText);                        {save current font, style}
  SetTextStyle(font8x8,HorizDir,1);
  YOff := CalcVertTextOffset(MenuBar^.Size.y);

  SetColor(lightcyan);
  SetFillStyle(solidfill, red);                  {drawn over menu bar, so can}
				   {easily be erased by calling MenuBar^.Draw}
  Bar3d(0, 0, GetMaxX, MenuBar^.Size.y, 0, false);
  WriteCStrXY(X, YOff, SS, white, yellow);
  SetColor(white);
  OutTextXY(Charlen,YOff, Chr($10));
  OutTextXY(GetMaxX-2*Charlen,YOff, Chr($11));

  GSystemError := FarSelectKey;                  {get retry/cancel user input}
  MenuBar^.Draw;                                         {erase error message}

  with SaveText do
    SetTextStyle(Font, Direction, CharSize);
  with VPort do
    SetViewPort(X1, Y1, X2, Y2, Clip);
end;

Type                                    {Type Declaration for various Objects}

  POverall = ^TOverall;                     {Window with Graphic Presentation}
  TOverall = object(TWinBackGround)                {of Closure of Tidal Basin}
    Count : integer;
    Speed : integer;
    constructor Init(var Bounds: TRect);
    procedure Draw; virtual;
    procedure DrawOverall;
    procedure HandleEvent(var Event : TEvent); virtual;
  end;

  PDataBox = ^TDataBox;                    {Window with Numerical Information}
  TDataBox = object(TWinBackGround)                {on Closure of Tidal Basin}
    Count : integer;
    Speed : integer;
    constructor Init(var Bounds: TRect);
    procedure Draw; virtual;
    procedure DrawDataBox;
    procedure HandleEvent(var Event : TEvent); virtual;
  end;

  constructor TOverall.Init(var Bounds: TRect);     {Constructor for Graphics}
  begin                                                               {Window}
     TWinBackGround.Init(Bounds);
     EventMask := evTimerTick;
     VColor := black;               {store drawing color}
  end;

  procedure TOverall.Draw;             {Procedure which Draws the information}
  var   Glob: TRect;                {information on the closure in the window}
  begin
    GetVPRelCoords(Glob);     {get view's outline in viewport relative coords}
    SetFillStyle(solidfill,VColor);                     {set background color}
    Bar(Glob.A.x,Glob.A.y,Glob.B.x,Glob.B.y);                {draw background}

    ReNewWindow:=True;

    if NumOfKenterings>0 then                        {If new window is drawn,}
       JustKentered:=True;                      {it should be filled with the}
						 {information on every aspect}
    LevelDrX:=1000;

    MCur.Hide;                                         {Hide the Mouse Cursor}
    DrawOverall;                                            {Draw all aspects}
    MCur.Show;                                         {Show the Mouse Cursor}

  end;

  procedure TOverall.DrawOverall;              {Draw all aspects of graphical}
  var                                                {information into window}
    Radius : word;
    Glob : TRect;
    Color : integer;
  begin
    GetVPRelCoords(Glob);     {get view's outline in viewport relative coords}

    WX1:=Glob.A.X;                            {Remember coordinates of window}
    WY1:=Glob.A.Y;                                   {for display and scaling}
    WDX:=Size.X;
    WDY:=Size.Y;

    if (OChanged<>NumOfGaps*OrigTotalWidth) or (ReNewWindow) then
    begin
       ReNewWindow:=False;
       if OrigTotalWidth<>0 then                          {For scale drawings}
       WidthFact:=0.37*(WDX-10*NumOfGaps)/OrigTotalWidth;
       SetStartDraws;                                 {If some width changed,}
    end;
    OChanged:=NumOfGaps*OrigTotalWidth;

    SomethingDrawn:=True;                          {For Window Open Detection}
    MCur.Hide;                                             {Hide Mouse Cursor}
    if Started then Overall_Draw(WX1,WY1,WDX,WDY);              {Draw aspects}
    if (JustKentered and Started) or Zipped[GCT] then
    begin
       JustKentered:=False;                            {If levels just equal,}
       Overall_KenterDraw(WX1,WY1,WDX,WDY);             {draw rest of aspects}
    end;
    if Zipped[GCT] then
    begin
       Zipped[GCT]:=False;
       DataChanged:=True;
       Started:=False;
    end;
    MCur.Show;                                         {Show the Mouse Cursor}
  end;

  procedure TOverall.HandleEvent(var Event : TEvent);
  begin
      if TopView <> PView(DeskTop^.Owner) then          {If window is opened,}
      begin                                              {else exit procedure}
	 exit;
      end;

      {if GetState(sfActive) then}                 {Remove accolades for only}
      OverallOpen:=True;                            {drawing in active window}
      if Started=True then DrawOverall;
  end;

  constructor TDataBox.Init(var Bounds: TRect);       {Constructor for window}
  begin                                                  {with numerical data}
     TWinBackGround.Init(Bounds);
     EventMask := evTimerTick;
     VColor := black;                                    {store drawing color}
  end;

  procedure TDataBox.Draw;
  var   Glob: TRect;
	VPort: ViewPortType;
	PLX, TX, TY: Integer;
  begin
    GetVPRelCoords(Glob);     {get view's outline in viewport relative coords}

    SetFillStyle(solidfill,VColor);                     {set background color}
    Bar(Glob.A.x,Glob.A.y,Glob.B.x,Glob.B.y);                {draw background}
    RenewDataBox:=True;
    {DrawDataBox;}          {Accolades might be removed if window is extended}
  end;

  procedure TDataBox.DrawDataBox;              {Fill DataBox with information}
  var
    Radius : word;
    Glob : TRect;
    VPort: ViewPortType;
    Color : integer;
    TX, TY, PLX : Integer;
  begin
    GetVPRelCoords(Glob);     {get view's outline in viewport relative coords}
    GetViewSettings(VPort);
    SetViewPort(Glob.A.X, Glob.A.Y,                    {Restrict new viewport}
		T(Min(GetMaxX,Glob.B.X)),
		T(Min(Glob.B.Y+20, GetMaxY-32)), ClipOn);
    SetColor(LightGray);
    SomethingWritten:=True;                  {For DataBox window opened-check}
    begin
       TX:=10;                                         {Relative X-coordinate}
       TY:=50;                                         {Relative Y-coordinate}
       if DayChanged or RenewDataBox then
       begin
	  SetColor(White);
	  DayChanged:=False;
	  TextXY(TX,40,      DayS+', ');
	  TextXY(TX+11*8,40, BasinDay+'/'+
	      BasinMonth+'/'+BasinYear);                       {Time in basin}
	  SetColor(LightGray);
	  TextXY(TX+88,53,I(JobDayNo));                    {Number of job day}
       end;
       if RenewDataBox then
       begin
	  SetColor(White);
	  TextXY(TX,53,'Job day #: ');
	  TextXY(TX,66, 'Hsea (m): ');
	  TextXY(TX,79, 'Qt (m3/s): ');
	  TextXY(TX,92, 'As (m2):   ');
	  TextXY(TX,105, 'Setup (m): ');
	  TextXY(TX,118, 'Dur (s):   ');
       end;
       SetColor(LightGray);
       TextXY(TX+88,66,N((SeaLevel2/100)*100));          {Actual Sea level, m}
       TextXY(TX+88,79,N(TotalFlow));                 {Sum of Gap Flows, m3/s}
       TextXY(TX+88,92,N(TotalGapSurface));          {Sum of Gap Surfaces, m2}
       if (TimeToStorm>0) or RenewDataBox then
       begin
	  TextXY(TX+88,105,N((ActStormSurge*100)/100));{Actual Storm Setup, m}
	  TextXY(TX+88,118,N(TimeToStorm));          {Duration left for storm}
       end;
       for GCT:=1 to NumOfGaps do
       begin
	  If Construction[GCT]=Collapsed then      {If construction collapsed}
	  begin
	     SetColor(LightRed);
	     TextXY(TX,TY+320+GCT*14,'CONSTRUCTION '+I(GCT)+' COLLAPSED');
	     SetColor(LightGray);
	  end;
	  If Construction[GCT]=Finished then       {If construction collapsed}
	  begin
	     SetColor(LightGreen);
	     TextXY(TX,TY+320+GCT*14,'CONSTRUCTION '+I(GCT)+' FINISHED');
	     SetColor(LightGray);
	  end;
       end;
    if RenewDataBox then
    begin
	SetColor(White);
	for GCT:=1 to NumOfGaps do
	begin
	   PLX:=TX-13+GCT*50;
	   DataTextXY(PLX,TY+95,'GAP ',GCT);
	end;
	TextXY(TX,108+TY,'%prf');                          {% of gap filled, %}
	TextXY(TX,121+TY,'Qgap');           {Flow through individual gap, m3/s}
	TextXY(TX,134+TY,'Vgap');             {Velocity in individual gap, m/s}
	TextXY(TX,147+TY,'Agap');                     {Flow surface of gap, m2}
	TextXY(TX,160+TY,'Weir');                        {State of overfall, -}
	TextXY(TX,173+TY,'Yprf');                     {Level of dam top, m+MSL}
	TextXY(TX,186+TY,'Wgap');                             {Width of gap, m}
	TextXY(TX,199+TY,'Hdam');                     {Actual height of dam, m}
	TextXY(TX,212+TY,'Vreq');                 {Required volume for dam, m3}
	TextXY(TX,225+TY,'Vdum');                   {Dumped volume for dam, m3}
	TextXY(TX,238+TY,'Vero');                   {Eroded volume for dam, m3}
	TextXY(TX,251+TY,'Vprf');                    {Actual volume of dam, m3}
	TextXY(TX,264+TY,'Hole');                       {Deepest scour hole, m}
	TextXY(TX,277+TY,'Eqpm');                           {Kind of Equipment}
	TextXY(TX,290+TY,'Prod');                      {Total Production, m3/h}
	TextXY(TX,303+TY,'Size');                              {Particle Sizes}
	(*
	TextXY(TX,316+TY,'Logs');
	if (not ErosLog) and (Not VeloLog) and
	(not LevelLog) and (Not GapLog) then
	TextXY(TX+37, 316+TY, 'No logfiles');
	if ErosLog  then TextXY(TX+37   ,316+TY,'E');     {Log file erosion on}
	if VeloLog  then TextXY(TX+37+16,316+TY,'V');    {Log file velocity on}
	if LevelLog then TextXY(TX+37+32,316+TY,'L');      {Log file levels on}
	if GapLog   then TextXY(TX+37+48,316+TY,'G');  {Log file dimensions on}
	*)
	SetColor(LightGray);
    end;
       for GCT:=1 to NumOfGaps do            {Below, the presented data above}
       begin                                          {is written numerically}
	  PLX:=TX-13+GCT*50;
	  DataTextXY(PLX,TY+108,'',Percentage[GCT]);
	  DataTextXY(PLX,TY+121,'',Round(GapFlow[GCT]));
	  DataTextXY(PLX,TY+134,'',Round(Velocity[GCT]*10)/10);
	  DataTextXY(PLX,TY+147,'',Round(GapSurface[GCT]));
	  if WeirSituation[GCT]=Complete   then TextXY(PLX,TY+160,'CRIT');
	  if WeirSituation[GCT]=InComplete then TextXY(PLX,TY+160,'NORM');
	  DataTextXY(PLX,TY+173,'',Round(GapDepthAtMSL[GCT]*100)/100);
	  DataTextXY(PLX,TY+186,'',Round(GapWidth[GCT]*100)/100);
	  DataTextXY(PLX,TY+199,'',Round(ActDamHeight[GCT]*100)/100);
	  if Dialoged then DataTextXY(PLX,TY+212,'',Round(RequiredVolume[GCT]));
	  DataTextXY(PLX,TY+225,'',Round(TotalDumped[GCT]));
	  DataTextXY(PLX,TY+238,'',Round(TotalEroded[GCT]));
	  DataTextXY(PLX,TY+251,'',Round(ActualVolume[GCT]));
	  DataTextXY(PLX,TY+264,'',Max(MaxInHole[GCT],MaxOutHole[GCT]));
	  if dialoged then
	  begin
	     Case WayOfConstruction[GCT] of
		  csTrucks:   TextXY(PLX,TY+277,'TRUC');
		  csVessels:  TextXY(PLX,TY+277,'VESS');
		  csCableWay: TextXY(PLX,TY+277,'CABL');
		  csSandDump: TextXY(PLX,TY+277,'PIPE');
	     end;
	     DataTextXY(PLX,TY+290,'',Round(GradualLeft[GCT])+
					    GradualRight[GCT]+
					    GradualUp[GCT]);
	     DataTextXY(PLX,TY+303,'',Round(DamD50[GCT]*100)/100);
	  end;
       end;
       Dialoged:=False;
       RenewDataBox:=False;
    end;
    SetViewPort(VPort.X1, VPort.Y1, VPort.X2,        {Restore original (full)}
			   VPort.Y2, ClipOn);                       {ViewPort}
  end;

  procedure TDataBox.HandleEvent(var Event : TEvent);
  begin
      if TopView <> PView(DeskTop^.Owner) then        {Only if window is open}
      begin
	 exit;
      end;

      {if GetState(sfActive) then}            {If accolades are removed, only}
      if Started=True then DrawDataBox;         {drawing takes place when the}
      DataBoxOpen:=True;                                    {window is active}

    {end;}
  end;

const

  ROverall: TStreamRec = (                              {Constant- and Record}
     ObjType: 3001;                                {declaration for saving of}
     VmtLink: Ofs(TypeOf(TOverall)^);                {desktop files, Graphics}
     Load:    @TOverall.Load;
     Store:   @TOverall.Store
  );
  RDataBox: TStreamRec = (
     ObjType: 3002;
     VmtLink: Ofs(TypeOf(TDataBox)^);         {Same for numerical information}
     Load:    @TDataBox.Load;
     Store:   @TDataBox.Store
  );

  procedure RegisterLocals;                              {Register both views}
  begin
    RegisterType(ROverall);
    RegisterType(RDataBox);
  end;

type
  TSimApp = object(TProgram)                       {Declaration of procedures}
    constructor Init;                                  {within the SIM object}
    procedure GetEvent(var Event : TEvent); virtual;
    procedure DosShell;                                          {exit to DOS}
    procedure HandleEvent(var Event: TEvent); virtual;    {Handling of Events}
    procedure InsertOverallWin;                         {Open graphics window}
    procedure InsertDataBoxWin;                         {Open numerics window}
    procedure InitMenuBar; virtual;                        {Initiate Menu Bar}
    procedure InitMessageBar;                           {Initiate Message Bar}
    procedure InitStatusLine; virtual;                  {Initiate Status Line}
    procedure InitToolBar;                        {Initiate Bitmap Button Bar}
    procedure PutPicture(FName: PathStr; X,Y: Integer);       {Opening Screen}
    procedure SaveDeskTop;                              {Save Desktop to File}
    procedure LoadDeskTop(FName: String);             {Load Desktop from File}
    procedure MainProgram;                     {Simulation program, main loop}
    procedure Default(Comment: Word);         {Load Default Closure Situation}
    procedure LogFiles;                                      {Apply Log Files}
    procedure Intro;                                       {Intro Information}
    procedure Load;                               {Load any Closure Situation}
    procedure Save;                            {Save actual Closure Situation}
    procedure SaveAs;                          {Save Closure Situation as....}
    procedure Quit;                              {Quit program, back to shell}
    procedure InitiateProcess;                    {Set Closure to Equilibrium}
    procedure AdaptAll;                                       {Adapt all data}
    procedure Start;                                      {Start Calculations}
    procedure Interr(Comment: Boolean);               {Interrupt Calculations}
    procedure ProcessToggle;                 {Start or Interrupt Calculations}
    procedure ToggleSound;                               {Toggle Sound on/off}
    procedure SelectColors;                             {Select Color Palette}
    procedure DateTime;                           {Change basin Date and Time}
    procedure Basin;                        {Change basin surface information}
    procedure RiverData;                                   {Change river data}
    procedure Closure;                                   {Change general data}
    procedure DepthsWidths;                         {Change depths and widths}
    procedure Tide;                                 {Change tidal information}
    procedure Dimensions;                              {Change dam dimensions}
    procedure Methods;                               {Change building methods}
    procedure VesselDraft;                          {Draft of Dumping Vessels}
    procedure Angles;                            {Change head- and side angle}
    procedure Protection;                {Length/quality of bottom protection}
    procedure GradualClose;                           {Change production data}
    procedure CaissonClose;                              {Not implemented yet}
    procedure StartStorm;                                     {Start storming}
    procedure DefStorm;                                       {Define a storm}
    procedure Culvert;                           {Build a culvert as spillway}
    procedure HelpOnTopics;                                      {Help option}
    destructor Done; virtual;                                    {End program}
    destructor HaltDone;                   {End program during graphics setup}
  end;

destructor TSimApp.Done;               {Called for normal program termination}
begin
  TProgram.Done;                                               {Reset program}
  MCur.Done;                                    {releases mouse cursor memory}
  CloseGraph;                                              {Back to text mode}
  Graphic := false;
  DoneSysError;                                        {No error to give back}
  DoneEvents;                                     {No actual events to handle}
  DoneVideo;                                            {Release video memory}
  DoneMemory;                                        {Release reserved memory}
end;

destructor TSimApp.HaltDone;              {used if program halts while trying}
						   {to initilize graphic mode}
begin
  DoneSysError;                                        {No error to give back}
  DoneEvents;                                     {No actual events to handle}
  DoneVideo;                                            {Release video memory}
  DoneMemory;                                        {Release reserved memory}
end;

constructor TSimApp.Init;                            {Initiation of interface}
  procedure DoStreamRegistration;  {register objects and views for stream I/O}
  begin
    RegisterObjects;
    RegisterViews;
    RegisterDialogs;
    RegisterMenus;
    RegisterApp;
    RegisterStdDlg;
    RegisterWindows;
    RegisterLocals;
    RegisterBitMaps;
  end;
var
  GraphDriver,GraphMode,ErrorCode : integer;
begin
  Graphic := false;
  InitMemory;                                                     {Set memory}
  InitVideo;                                                       {Set video}
  InitEvents;                                                  {Set event set}
  InitSysError;                                                    {Set error}
  if RegisterBGIdriver(@EGAVGADriverProc) < 0 then           {Detect Initiate}
  begin                                                      {graphics driver}
    HaltDone;
    Writeln('Internal EGA/VGA driver not linked.');
    Halt(1);
  end;
  DetectGraph(GraphDriver, GraphMode);
  if not ((GraphDriver = VGA) or (GraphDriver = EGA)) then begin
    HaltDone;
    Writeln('Error - system does not support EGA or VGA graphics.');
    Halt(1);
  end;

	       {Optional - forces color display mode if in B&W mode. This can}
			      {cause a problem with B&W LCD laptops which can}
			 {drive an external VGA color monitor. They end up in}
			    {color mode and so Turbo Vision selects the color}
					     {palette instead of B&W palette.}
  (*SetVideoMode(smCO80);*)


  if GraphDriver = VGA then GraphMode := VGAHi           {enter graphics mode}
    else GraphMode := EGAHi;
  InitGraph(GraphDriver,GraphMode,'');
  ErrorCode := GraphResult;
  if ErrorCode <> grOK then begin
    HaltDone;
    Writeln('Graphics Error: ',GraphErrorMsg(ErrorCode));
    Halt(1);
  end
  else begin                        {install exit procedure to Close graphics}
    OldExitProc := ExitProc;                    {save previous exit procedure}
    ExitProc := @GExitProc;               {insert new exit procedure in chain}
    Graphic := true;
			     {install graphic mode DOS critical error handler}
    SysErrorFunc := GSystemError;
					{improves look of dark gray and brown}
					   {on VGA monitors, no effect in EGA}
    ImprovePaletteColors;
  end;

  if ParamStr(1)='' then
  begin
     TSimApp.PutPicture('TEMPOR.BMP', 90, 100);          {Load opening screen}
     Repeat until KeyPressed or MousePressed;       {Repeat until key pressed}
     Repeat until MousePressed=False;                       {and key released}
  end;
  MCur.Init;                                             {mouse cursor object}
  MCur.SetSpeed(12,12);               {how fast cursor moves, "normal" is 8,8}

  TProgram.Init;                                     {Initiate User Interface}

  DoStreamRegistration;                                     {Register streams}

  InitMessageBar;                                       {Initiate message bar}

  DoubleDelay := 6;       {time between mouse button presses for double press}
				      {Normal Turbo Vision uses 8 - very slow}

     {set default Viewport to just cover the DeskTop. The MainMenu,MessageBar}
	{and StatusLine temporarily reset viewport when they draw themselves.}

  with DeskTop^ do SetViewPort(Origin.x, Origin.y,
	   Origin.x + Size.x, Origin.y + Size.y, ClipOn);

  MCur.SetGrid(1,1,0,0);                              {set mouse grids to off}
  MouseSnapToMenuGrid := false;
  MouseSnapToDialogGrid := false;

  InitToolBar;                                    {Initiate Bitmap Button Bar}
end;

procedure TSimApp.DosShell;       {Must override method TApplication.DosShell}
begin
		   {USE TurboVision 2.0 MEMORY Unit if compiling with TP 7.0,}
					      {use MEMORY ver 1.0 with TP.6.0}
  RestoreCrtMode;                                          {back to text mode}

  DoneSysError;                                              {No system error}
  DoneEvents;                                                      {No events}
  DoneVideo;                                            {Release Video System}

  {$IFDEF VER60}                                            {Compiler command}
    SetMemTop(HeapPtr);                          {reduce reserved memory size}
  {$ELSE}
    DoneDosMem;
  {$ENDIF}
  Writeln('Type EXIT to return to '+ ProgName + '...');
  SwapVectors;
  Exec(GetEnv('COMSPEC'), '');
  SwapVectors;
  {$IFDEF VER60}
    SetMemTop(HeapEnd);                                {reserve all of memory}
  {$ELSE}
    InitDosMem;
  {$ENDIF}

  InitVideo;                                   {Back to video, events, errors}
  InitEvents;                                          {of simulation program}
  InitSysError;

  SetGraphMode(GetGraphMode);                          {Back to graphics mode}
  ImprovePaletteColors;                     {Improve VGA gray and brown again}

  MCur.RestoreSettings;            {Restore eventually changed mouse settings}

  Redraw;                                         {Use Redraw here, not Draw.}
  if DosError <> 0 then
  DOSErrorMessageBox(DosError, 'Running DOS shell');       {If error occurred}
end;

procedure HandleLogs;                                        {Adapt Log Files}
begin
      if ErosLog  = True then                      {Allways first write basin}
	 Write(txErosLog, JobHours:2:2);        {time to each opened log file}
      if VeloLog  = True then
	 Write(txVeloLog, JobHours:2:2);
      if LevelLog = True then
      begin
	  Write(txLevelLog, JobHours:2:2);         {Write Sea and Basin Level}
	  Write(txLevelLog, '  ',ActSeaLevel:2:2,'  ', BasinLevel:2:2);
      end;
      if GapLog   = True then Write(txGapLog, JobHours:2:2);

      for GCT:=1 to NumOfGaps do
      begin
						      {Erosion and Production}
	 if ErosLog  = True then Write(txErosLog, '  ',
	 TotalErosion[GCT]:2:2,'  ',TotalDumped[GCT]:2:2,'  ',ActualVolume[GCT]:2:2);
	 if VeloLog  = True then Write(txVeloLog, '  ', GapSurface[GCT]:2:2,'   ',
	 Velocity[GCT]:2:2);                                 {Velocity in gap}
	 if GapLog   = True then Write(txGapLog, '  ',
	 GapWidth[GCT]:2:2,'  ', GapDepthAtMSL[GCT]:2:2);      {Gap diameters}
      end;

      if ErosLog  = True then WriteLn(txErosLog);               {To next line}
      if VeloLog  = True then WriteLn(txVeloLog);
      if LevelLog = True then WriteLn(txLevelLog);
      if GapLog   = True then WriteLn(txGapLog);
end;

Procedure TSimApp.MainProgram;
begin
   EverySecond;                                        {Programmer's use only}
   if (DataChanged=True) and                      {If new information entered}
   (ProcessInited=False) and                       {If not set to equilibrium}
   (Started=True) then                               {If calculations started}
   begin
       DataChanged:=False;                           {Initiate proces and set}
       RenewWindow:=True;                          {closure situation back to}
       Started:=False;                        {equilibrium; stop calculations}
       Opt_InitProcess;                               {and load empty desktop}
       TSimApp.LoadDesktop('SIM.DSK');
   end;
   if Started and                                {If calculations started and}
   MouseStabile then                                    {Mouse not moved then}
   begin
      Calculate;                                     {Calculate new situation}
      HandleLogs;                                            {Adapt Log Files}
   end;
end;

procedure TSimApp.GetEvent(var Event : TEvent);
const
  HelpInUse : boolean = false;
  LastPressDouble : boolean = false;
begin

  TProgram.GetEvent(Event);                         {Usual Call to Get Events}

  TSimApp.MainProgram;                               {Execute Simulation Loop}
end;

procedure TSimApp.HandleEvent(var Event: TEvent);         {Handling of Events}

  procedure Colors;                                  {Change of Color Palette}
  var
    D: PColorDialog;
  begin
    D := New(PColorDialog, Init('',
      ColorGroup('Desktop',       DesktopColorItems(nil),
      ColorGroup('Menus',         MenuColorItems(nil),
      ColorGroup('Dialogs',  DialogColorItems(dpTV1Dialog, nil),
      ColorGroup('Windows',  WindowColorItems(wpBlueWindow, nil),
	nil))))));
    D^.HelpCtx := hcColorSel;

    if ExecuteDialog(D, Application^.GetPalette) <> cmCancel then
    begin
      ReDraw;                            {Redraw application with new palette}
    end;
  end;

  procedure DosErr;                         {Warning if any disk error occurs}
  var
    F: Text;
    cmd : integer;
  begin
    cmd := MessageBox(^C'Testing DOS Critical Error'+
	  ^M^M^C'Remove any disk in drive A:',nil,mfWarning+mfOKCancel);
    if cmd <> cmOK then exit;

    Assign(F, 'a:\8anyfile.7Z3');            {Just to check whether the error}
  {$I-}                                                   {has been corrected}
    Reset(F);
    Close(F);
    cmd := IOResult;
  {$I+}
  end;

  procedure DoAboutBox;                             {Program Name and Version}
  begin
      MessageBox(^C'CLOSIM v 1.0'^M
		     +^C'A simulation program on'^M
		     +^C'the Closure of Tidal Basins',
      nil, mfInformation+mfOKButton);
  end;

var
  R: TRect;
  PDir,FInputBox : PView;
  cmd : integer;
begin
  if (ShiftViewPtr <> Nil) then ShiftViewPtr^.HandleEvent(Event);

  TProgram.HandleEvent(Event);                 {usual call to ancestor method}

  if Event.What = evCommand then                {If a command has been chosen}
  begin
    if HelpRequired then Help_On(Event.Command)    {Help on topic if required}
    else
    case Event.Command of
      cmAbout: DoAboutBox;                     {Show program Name and Version}
      cmChangeDir:                                     {Change Directory Tree}
	begin
	  PDir := New(PChDirDialog, Init(cdNormal {+ cdHelpButton},0));
	  cmd := DeskTop^.ExecView(PDir);
	  Dispose(PDir, Done);
	end;
      cmSetColors: Colors;                           {Color Palette Selection}
      cmDOSshell : DOSShell;                                  {Goto Dos Shell}
      cmDosCriticalError : DosErr;                        {If an Error Occurs}
      cmOptionsSave : SaveDeskTop;                      {Save Desktop to File}
      cmOptionsLoad : LoadDeskTop('SIM.DSK');         {Load Desktop from File}
      cmOverallWindow : InsertOverallWin;             {Insert Graphics Window}
      cmDataBoxWindow  : InsertDataBoxWin;            {Insert Numerics Window}
      cmDefault:Default(cmYes);               {Load Default Closure Situation}
      cmLogFiles: LogFiles;                     {Change Log Files to be Saved}
      cmIntro: Intro;                                      {Intro information}
      cmOpen:Load;                                {Load any Closure Situation}
      cmSave:Save;                             {Save Actual Closure Situation}
      cmSaveAs:SaveAs;                         {Save Closure Situation As....}
      cmQuit:Quit;                                    {Quit and Back to Shell}
      cmInitiateProcess:InitiateProcess;             {Reset Closure Situation}
      cmAdaptAll: AdaptAll;                                   {Adapt All Data}
      cmStart:Start;                                      {Start Calculations}
      cmInterr:Interr(True);                          {Interrupt Calculations}
      cmProcessToggle: ProcessToggle;             {Toggle Calculations on/off}
      cmToggleSound: ToggleSound;                        {Toggle Sound on/off}
      cmSelectColors: SelectColors;                     {Select Color Palette}
      cmDateTime:DateTime;                        {Change Basin Date and Time}
      cmBasin:Basin;                        {Change Basin Storage Information}
      cmRiverData: RiverData;                              {Change River Data}
      cmClosure: Closure;                                {Change General Data}
      cmDepthsWidths:DepthsWidths;                  {Change Depths and Widths}
      cmTide:Tide;                                  {Change Tidal Information}
      cmDimensions: Dimensions;                        {Change Dam Dimensions}
      cmMethods: Methods;
      cmVesselDraft: VesselDraft;
      cmAngles: Angles;                           {Change Head and Side Angle}
      cmProtection:Protection;              {Change Information on Protection}
      cmGradualClose:GradualClose;                        {Change Productions}
      cmCaissonClose:CaissonClose;                       {Not implemented yet}
      cmStartStorm: StartStorm;                                {Start a Storm}
      cmDefStorm: DefStorm;                                   {Define a Storm}
      cmCulvert: Culvert;                        {Build a Culvert as Spillway}
      cmHelpOnTopics: HelpOnTopics;                              {Help option}
    end;
    if (DataChanged=True) and
       (Started=True)   then                       {If data has been changed,}
    begin                                               {Process is reset and}
       DataChanged:=False;                            {stopped, empty desktop}
       RenewWindow:=True;                               {is loaded from disk.}
       Started:=False;
       Opt_InitProcess;
       TSimApp.LoadDesktop('SIM.DSK');
    end;
  end;
end;

procedure TSimApp.InsertOverallWin;                   {Insert Graphics Window}
var
  P : PView;
  W : PWindow;
  R : TRect;

begin
if OverallOpen=False then                                  {If not opened yet}
   begin
     SetStartDraws;                                      {Reset draw counters}

     R.Assign(5*Grid-1,1*Grid,40*Grid,43*Grid);         {Reserve Window Space}

     W := New(PSubWindow, Init(R,'Overall View of Closure',wnNoNumber));

     W^.GetMaxSubViewSize(R);                                  {Insert window}
     P := New(POverall, Init(R));
     W^.Insert(P);
     DeskTop^.Insert(W);
   end;
end;

procedure TSimApp.InsertDataBoxWin;        {Insert Numerics Window on Desktop}
var
  P : PView;
  W : PWindow;
  R : TRect;

begin
if DataBoxOpen=False then                                  {If not opened yet}
   begin
     R.Assign(40*Grid+4,1*Grid,62*Grid,43*Grid);        {Reserve window space}

     W := New(PSubWindow, Init(R,'Data Field',wnNoNumber));

     W^.GetMaxSubViewSize(R);                  {Insert Data Window on desktop}
     P := New(PDataBox, Init(R));
     W^.Insert(P);
     DeskTop^.Insert(W);
   end;
end;

procedure TSimApp.InitMessageBar;       {message that covers over the MenuBar}
begin
  MessageBar := New(PGMessageBar,Init);
  Insert(MessageBar);
end;

Procedure TSimApp.Load;                               {Load Closure Situation}

var C: Boolean;

begin

  C:=Dial_FileSelect('Closure Situation to Load',   {Select file to be loaded}
		    '*.CTB', 'DEFAULT.CTB', FTL);

  if (FTL<>'') and (C<>False) then                     {If something selected}
  begin
       Opt_Load(FTL);                                    {Load data from file}
       FTS:=FTL;                                       {Save-name is new name}
       TSimApp.Interr(False);                         {Interrupt calculations}
       LoadDesktop('SIMFREE.DSK');
  end;
end;

Procedure TSimApp.SaveAs;                      {Save Actual Closure Situation}

var C: Boolean;

begin

  C:=Dial_FileSelect('Closure Situation to Save',     {Select file to save to}
		    '*.CTB', 'DEFAULT.CTB', FTS);

  if (FTS<>'') and (C<>False) then                     {If something selected}
  begin
       Opt_Save(FTS);                                              {Save data}
  end;

end;

Procedure TSimApp.Save;                        {Save Actual Closure Situation}
						   {Without choosing new name}
begin
   Opt_Save(FTS);
end;

procedure TSimApp.Intro;

begin
   Dial_Intro;
end;

Procedure TSimApp.LogFiles;                                 {Change log files}
begin
   if ErosLog  = True then Close(txErosLog);        {Close all open log files}
   if VeloLog  = True then Close(txVeloLog);
   if LevelLog = True then Close(txLevelLog);
   if GapLog   = True then Close(txGapLog);

   Dial_LogFiles(ErosLog, VeloLog, LevelLog, GapLog);     {Log file selection}

   if ErosLog  = True then                              {Open new logfile for}
   begin                                             {Erosion and Production,}
      Assign(txErosLog, 'EROSPROD.LOG');                         {if required}
      ReWrite(txErosLog);
      WriteLn(txErosLog, 'Erosion in gap profiles with respect to process time.');
      WriteLn(txErosLog);
   end;
   if VeloLog  = True then                              {Open new logfile for}
   begin                                                     {gap velocities,}
      Assign(txVeloLog, 'VELOCITY.LOG');                         {if required}
      ReWrite(txVeloLog);
      WriteLn(txVeloLog, 'Velocity in gap profiles with respect to process time.');
      WriteLn(txVeloLog);
   end;
   if LevelLog  = True then                             {Open new logfile for}
   begin                                                {Sea and Basin Level,}
      Assign(txLevelLog, 'LEVELS.LOG');                          {if required}
      ReWrite(txLevelLog);
      WriteLn(txLevelLog, 'Sea- and basin level with respect to process time.');
      WriteLn(txLevelLog);
   end;
   if GapLog  = True then                               {Open new logfile for}
   begin                                              {gap depths and widths,}
      Assign(txGapLog, 'GAPDIMEN.LOG');                          {if required}
      ReWrite(txGapLog);
      WriteLn(txGapLog, 'Depth and width of gap profiles with respect to process time.');
      WriteLn(txGapLog);
   end;
end;

Procedure TSimApp.Default(Comment: Word);                {Load default values}
begin
  MCur.SelectHourGlass;                                 {Change cursor symbol}
  If Comment=cmYes then
  MessageBar^.ShowText('Now Loading Default Values');            {Message bar}
  Opt_Load('DEFAULT.CTB');                                 {Load default data}
  FTS:='DEFAULT.CTB';                                    {Change name to save}
  TSimApp.Interr(False);                                   {Stop calculations}
  if Comment=cmYes then
  MessageBar^.Hide;                                            {hide menu bar}
  MCur.SelectStdCursor;                                 {Select normal cursor}
  DataChanged:=True;                                  {Process will be inited}
end;

Procedure TSimApp.Quit;                           {Quit and back to DOS shell}
begin
   if ErosLog  = True then Close(txErosLog);      {Close all opened log files}
   if VeloLog  = True then Close(txVeloLog);
   if LevelLog = True then Close(txLevelLog);
   if GapLog   = True then Close(txGapLog);
   Opt_Quit;
end;

procedure TSimApp.AdaptAll;
begin
   P:=True;
   if (ProcessInited=False) and (SomethingDumped) then
      P:=Dial_ReallyChange;
   if P then begin
      Started:=False;
      TSimApp.LoadDesktop('SIMFREE.DSK');
      DialSeriesOn:=True;
      Dial_Closure(NumOfGaps, Chezy, BottomD50, TimeStep);
      if ExitDialSeries=false then Opt_AdaptAll;
   end;
   DialSeriesOn:=False;
end;

Procedure TSimApp.InitiateProcess;      {Option for Initiation of Process and}
begin                                          {Resetting the Closure Gaps to}
   TSimApp.Interr(False);                                        {Equilibrium}
   DataChanged:=False;
end;

Procedure TSimApp.Start;                               {Start of calculations}
var Ers: String;
    Perm: Boolean;
begin
   StartPermission(Ers, Perm);                       {Check for error in data}
   if Perm=False then                                  {if error, don't start}
      if Ers<>'' then
      Control := MessageBox('Impossible to start, due to an'+
	  ^M'error in the information with'+
	  ^M'respect to the '+Ers+'.',nil,mfWarning + mfOkButton)
      else
      begin Started:=False; Perm:=True; end;

   if Perm=True then                                    {If no error in data,}
   begin
      Opt_Start;					 {Start calculations}
      if StartupCanceled=False then
      begin
      MessageBar^.ShowText('Process Has Now Been Started');      {Message Bar}
      Delay(500);
      if OverallOpen=False then InsertOverallWin;       {Open graphics window}
      if DataBoxOpen=False then InsertDataBoxWin;       {Open numerics window}
      Started:=True;
      MessageBar^.Hide;
      end;
   end
end;

Procedure TSimApp.Interr(Comment: Boolean);           {Interrupt calculations}
begin
   Started:=False;                                         {Stop calculations}
   if Comment=True then
   MessageBar^.ShowText('Process Has Now Been Interrupted');
   if Comment=True then Delay(500);             {Only message bar if required}
   if Comment=True then MessageBar^.Hide;
end;

procedure TSimApp.ProcessToggle;                  {Toggle calculations on/off}

begin
   if Started=False then TSimApp.Start
		    else TSimApp.Interr(True);
end;

procedure TSimApp.ToggleSound;                           {Toggle sound on/off}
begin
   Opt_ToggleSound;
end;

procedure TSimApp.SelectColors;                        {Select Color Pallette}
var
  D: PColorDialog;
begin
  D := New(PColorDialog, Init('',
    ColorGroup('Desktop',       DesktopColorItems(nil),
    ColorGroup('Menus',         MenuColorItems(nil),
    ColorGroup('Dialogs',  DialogColorItems(dpGrayDialog, nil),
      nil)))));

  if ExecuteDialog(D, Application^.GetPalette) <> cmCancel then
  begin
    DoneMemory;                                    {Dispose all group buffers}
    ReDraw;                              {Redraw application with new palette}
  end;
end;

procedure TSimApp.DateTime;                       {Change Basin Date and Time}
begin
   Opt_DateTime;
end;

procedure TSimApp.Basin;                           {Change Basin Surface Data}
begin
   Opt_Basin;
end;

procedure TSimApp.RiverData;                       {Change data on river flow}
begin
   Opt_RiverData;
end;

procedure TSimApp.Closure;             {Change general information on closure}
begin
   Started:=False;
   P:=True;
   if (ProcessInited=False) and (SomethingDumped) then
      P:=Dial_ReallyChange;
   ONOG:=NumOfGaps;
   if P then begin
      TSimApp.LoadDesktop('SIMFREE.DSK');
      Started:=False;
      Dial_Closure(NumOfGaps, Chezy, BottomD50, TimeStep);
      if NumOfGaps>ONOG then Opt_AdaptAll;
   end;
   DialSeriesOn:=False;
end;

Procedure TSimApp.DepthsWidths;             {Change depths and widths of gaps}
begin
   Opt_DepthsWidths;
end;

Procedure TSimApp.Tide;                            {Change information on the}
begin                                                       {tidal components}
   Opt_Tide;
end;

Procedure TSimApp.Dimensions;                      {Change information on the}
begin                                                         {dam dimensions}
   DialSeriesOn:=False;
   Opt_Dimensions;
end;

procedure TSimApp.Methods;
begin
    DialSeriesOn:=False;
    Opt_Methods;
end;

procedure TSimApp.VesselDraft;
begin
    Opt_VesselDraft;
end;

Procedure TSimApp.Angles;
begin
   Opt_Angles;                                    {Change Head and Side Angle}
   CalculateAngles(WayOfConstruction, DSS, DSH);       {Verify Maximum Angles}
end;

Procedure TSimApp.Protection;                   {Change length and quality of}
begin                                                  {the bottom protection}
   Opt_Protection;
end;

Procedure TSimApp.StartStorm;                                  {Start a Storm}
begin
   if StormSurge=0 then Opt_DefStorm;
   StormChance:=1;
end;

Procedure TSimApp.DefStorm;                                   {Define a Storm}
begin
   Opt_DefStorm;
end;

procedure TSimApp.CaissonClose;             {Caisson Closures not implemented}
begin                                           {yet, therefore a warning box}
   Warn_CaissonClosure;
end;

Procedure TSimApp.GradualClose;        {Change of Gradual Closure Productions}
var OldDSS: RealArr;
    SkippedVolume: RealArr;
    DamH: Real;
    AnySkipped:Boolean;

begin
   DialSeriesOn:=False;
   AnySkipped:=False;
   for GCT:=1 to NumOfGaps do
   if (SkippedVolumeLeft[GCT]>0) or (SkippedVolumeRight[GCT]>0) then
      AnySkipped:=True;
   if (ClosureScheme[GCT]=Horizontal)
   and AnySkipped then                       {If still material to be skipped,}
   Warn_SkippedNoChange                      {information can not be changed.}
   else
   begin
      Opt_GradualClose;                                  {Ask for productions}
      for GCT:=1 to 3 do OldDSS[GCT]:=DSS[GCT];
      CalculateAngles(WayOfConstruction, DSS, DSH);            {Verify angles}
      for GCT:=1 to 3 do
	 if (DumpedLeft[GCT]<>0) or (DumpedRight[GCT]<>0) then
	 if (OldDSS[GCT]<>0) then
	 begin
	    DamH:=DamTop[GCT]-GapDepthAtMSL[GCT];          {If angle changed,}
	    SkippedVolume[GCT]:=DamTopWidth[GCT]*         {then skip material}
	    ((0.5*DamH*Tan(DSS[GCT])/Tan(OldDSS[GCT])*
	    (DamH/Tan(OldDSS[GCT]))-
	    (DamH*DamH/Tan(OldDSS[GCT]))));
	 end;
   end;
end;

procedure TSimApp.Culvert;                                {Construct Spillway}
begin
   Opt_Culvert;
end;

procedure TSimApp.HelpOnTopics;                                {Set Help flag}
begin
   if HelpRequired=True then HelpRequired:=False
			else begin HelpRequired:=True; Warn_HelpOn; end;
end;

procedure TSimApp.InitMenuBar;          {Turbo Vision Graphics Menu Bar}
var
  R: TRect;
begin
  MenuBarHeight := {15}23;              {programmer's choice, Menu Bar Heigth}
  GetExtent(R);                                         {All menu items below}
  MenuBar := New(PGMenuBar, Init(R, NewMenu(
    NewSubMenu('~I~nfo ', hcNoContext, NewMenu(
      NewItem('~A~bout Simulator ', '', 0, cmAbout, hcNoContext,
      NewItem('~I~ntro Information ', '', 0, cmIntro, hcNoContext,
      nil))),

    NewSubMenu('~F~ile', hcNoContext, NewMenu(
      NewItem('~O~pen...', 'F3', kbF3, cmOpen, hcOpen,
      NewItem('~S~ave...', 'F2', kbF2, cmSave, hcSave,
      NewItem('Save ~A~s', 'Alt-F2', kbAltF2, cmSaveAs, hcSaveAs,
      NewLine(
      NewItem('~C~hange dir...', '', kbNoKey, cmChangeDir, hcChangeDir,
      NewItem('~D~OS shell', '', kbNoKey, cmDosShell, hcDosShell,
      NewItem('E~x~it', 'Alt+X', kbAltX, cmQuit, hcExit,
      nil)))))))),

    NewSubMenu('~P~rogram ', hcNoContext, NewMenu(
      NewItem('~T~oggle Sound', '' ,0 , cmToggleSound, hcNoContext,
      NewItem('Select ~C~olors', '',0, cmSelectColors, hcNoContext,
      NewItem('~L~og Files', '', 0, cmLogFiles, hcNoContext,
      NewSubMenu('~D~esktop', hcNoContext, NewMenu(
	NewItem('~S~ave desktop', '', kbNoKey, cmOptionsSave, hcNoContext,
	NewItem('~L~oad desktop', '', kbNoKey, cmOptionsLoad, hcNoContext,
	nil))),
      nil))))),

    NewSubMenu('P~r~ocess ', hcNoContext, NewMenu(
      NewItem('~D~efault reset ', 'F9',kbF9 , cmDefault, hcNoContext,
      NewItem('~N~ew Closure', '', 0, cmAdaptAll, hcNoContext,
      NewItem('Init ~P~rocess','' , 0, cmInitiateProcess, hcNoContext,
      NewItem('~S~tart Process', 'F5',kbF5 , cmStart, hcNoContext,
      NewItem('~I~nterrupt Process', 'F6' ,kbF6 , cmInterr, hcNoContext,
      nil)))))),

    NewSubMenu('~B~asin ', hcNoContext, NewMenu(
      NewItem('~G~eneral', '', 0, cmClosure, hcNoContext,
      NewItem('Date & ~T~ime', '', 0 , cmDateTime, hcNoContext,
      NewItem('~B~asin surface', '', 0 , cmBasin, hcNoContext,
      NewItem('~D~epths and Widths', '', 0 , cmDepthsWidths, hcNoContext,
      NewItem('Tidal ~C~onditions', '', 0 , cmTide, hcNoContext,
      NewItem('~R~iver data','',0,cmRiverData, hcNoContext,
      NewSubMenu('~S~torm ', hcNoContext, NewMenu(
	NewItem('~D~efine Storm', '', 0, cmDefStorm, hcNoContext,
	NewItem('~S~tart Storm', '', 0, cmStartStorm, hcNoContext,
      nil))),
      nil)))))))),

    NewSubMenu('~C~onstruction ', hcNoContext, NewMenu(
      NewItem('Building ~M~ethod', '', 0, cmMethods, hcNoContext,
      NewItem('~B~ottom Protection', '',0 , cmProtection, hcNoContext,
      NewItem('Dam ~D~imensions', '', 0, cmDimensions, hcNoContext,
      NewItem('Dam ~A~ngles', '', 0, cmAngles, hcNoContext,
      NewItem('G~r~adual Closure', 'F8', kbF8, cmGradualClose, hcNoContext,
      NewItem('C~a~isson Closure', '',0 , cmCaissonClose, hcNoContext,
      NewItem('C~o~nstruct Culvert', '',0, cmCulvert, hcNoContext,
      NewLine(
      NewItem('Dumping ~V~essel Draft', '', 0, cmVesselDraft, hcNoContext,
      nil)))))))))),

    NewSubMenu('~W~indows', hcNoContext, NewMenu(
      NewItem('~O~verall View', '', kbNoKey, cmOverallWindow , hcNoContext,
      NewItem('~D~ataBox Window', '', kbNoKey, cmDataBoxWindow, hcNoContext,
      NewItem('~C~lose', 'Alt+F3', kbAltF3, cmClose, hcClose,
      nil)))),

    NewSubMenu('~H~elp ', hcNoContext, NewMenu(
      NewItem('~H~elp on options', 'F7',kbF7, cmHelpOnTopics, hcNoContext,

    nil)),nil)))))))
  ))));
end;

procedure TSimApp.InitStatusLine;               {Status line, below on screen}
  function  HiddenStatusKeys(Next : PStatusItem) : PStatusItem;
  begin
    HiddenStatusKeys :=                                {Status keys which are}
	NewStatusKey('', kbF10, cmMenu,             {not shown on status line}
	NewStatusKey('', kbAltF3, cmClose,
	NewStatusKey('', kbF8, cmGradualClose,
	Next)));
  end;
var
  R: TRect;
begin
  GetExtent(R);
  R.A.Y := R.B.Y - 9 {Boxheight};      {this gives a 10 pixel tall StatusLine}
StatusLine :=   New(PGStatusLine, Init(R,
    NewStatusDef(0, $FFFF,                              {Status line commands}
      NewStatusKey('~F1~ Help', kbF1, cmHelp,
      NewStatusKey('~F2~ Save', kbF2, cmSave,
      NewStatusKey('~F3~ Open', kbF3, cmOpen,
      NewStatusKey('~F4~ Save As', kbF4, cmSaveAs,
      NewStatusKey('~F6~ Toggle Process', kbF6, cmProcessToggle,
      NewStatusKey('~Alt-X~ Exit', kbAltX, cmQuit,
      HiddenStatusKeys(nil))))))),
       nil)));

StatusLine^.VFont := font8x8;
		  {use for 10 pixel tall StatusLine - default font is font8x8}
end;

procedure TSimApp.InitToolBar;
    {NOTE FOR PROGRAMMER: this is a toolbar that is inserted into the DeskTop}
	       {just like a window. It can be any size. Windows can cover it.}
	  {As an alternative, you could make a toolbar which is inserted into}
	    {the application like a menu and reduces the size of the DeskTop.}
			  {See Bitmap documentation of Turbo Vision Graphics.}
const
  BWidth = 32;                                              {Width of Buttons}
  BHeight = 32;                                            {Height of Buttons}
var
  PBar : PToolBar;
  PBut : PIconButton;
  R : TRect;
  NumOfButtons: Integer;
begin
  NumOfButtons:=11;                                        {Number of Buttons}
  R.Assign(0, 0, 5 +BWidth, 2+Boxheight + NumOfButtons *BHeight);
  PBar := New(PToolBar, Init(R, ''));

	      {Buttons have ofSelectable set by default.  If so, the Selected}
	 {button will have a dotted line drawn around it. Setting bfGrabFocus}
	  {in the Opts field of the constructor will cause a button to Select}
      {itself when clicked with mouse. So the dotted line will be on the last}
							     {clicked button.}
	       {If the dotted line is not wished, clear the ofSelectable flag}
	    {in the button's Options field after construction. bfGrabFocus is}
				   {not needed in this case but doesn't hurt.}
	    {Note that buttons will respond to HotKeys, if you have set them.}

  R.A.x := 3;  R.A.y := 14;                                     {INTRO BUTTON}
  PBut := New(PIconButton, Init(R, '',cmIntro,
	  bfGrabFocus+tbDrawFrame+tbAutoSize, @ICIntro));
  PBut^.Options := PBut^.Options and not ofSelectable;
  PBar^.Insert(PBut);

  Inc(R.A.y, BHeight);                                           {LOAD BUTTON}
  PBut := New(PIconButton, Init(R, '',cmOpen,
	  bfGrabFocus+tbDrawFrame+tbAutoSize, @ICLOAD));
  PBut^.Options := PBut^.Options and not ofSelectable;
  PBar^.Insert(PBut);

  Inc(R.A.y, BHeight);                                           {SAVE BUTTON}
  PBut := New(PIconButton, Init(R, '',cmSaveAs,
	  bfGrabFocus+tbDrawFrame+tbAutoSize, @ICSAVE));
  PBut^.Options := PBut^.Options and not ofSelectable;
  PBar^.Insert(PBut);

  Inc(R.A.y, BHeight);                                         {TOGGLE BUTTON}
  PBut := New(PIconButton, Init(R, '',cmProcessToggle,
	  bfGrabFocus+tbDrawFrame+tbAutoSize, @ICTOGGLE));
  PBut^.Options := PBut^.Options and not ofSelectable;
  PBar^.Insert(PBut);

  Inc(R.A.y, BHeight);                                {GRAPHICS WINDOW BUTTON}
  PBut := New(PIconButton, Init(R, '',cmOverallWindow,
	  bfGrabFocus+tbDrawFrame+tbAutoSize, @ICWINDOW));
  PBut^.Options := PBut^.Options and not ofSelectable;
  PBar^.Insert(PBut);

  Inc(R.A.y, BHeight);                                {NUMERICS WINDOW BUTTON}
  PBut := New(PIconButton, Init(R, '',cmDataBoxWindow,
	  bfGrabFocus+tbDrawFrame+tbAutoSize, @ICDATBOX));
  PBut^.Options := PBut^.Options and not ofSelectable;
  PBar^.Insert(PBut);

  Inc(R.A.y, BHeight);                                    {NEW CLOSURE BUTTON}
  PBut := New(PIconButton, Init(R, '', cmAdaptAll,
	  bfGrabFocus+tbDrawFrame+tbAutoSize, @ICNEWCL));
  PBut^.Options := PBut^.Options and not ofSelectable;
  PBar^.Insert(PBut);


  Inc(R.A.y, BHeight);                                {GRADUAL CLOSURE BUTTON}
  PBut := New(PIconButton, Init(R, '', cmGradualClose,
	  bfGrabFocus+tbDrawFrame+tbAutoSize, @ICGRAD));
  PBut^.Options := PBut^.Options and not ofSelectable;
  PBar^.Insert(PBut);

  Inc(R.A.y, BHeight);                                {BUTTON FOR STORM START}
  PBut := New(PIconButton, Init(R, '~N~',cmStartStorm,
	  bfGrabFocus+tbDrawFrame+tbAutoSize, @ICSTORM));
  PBut^.Options := PBut^.Options and not ofSelectable;
  PBar^.Insert(PBut);

  Inc(R.A.y, BHeight);                                {GO TO DOS SHELL BUTTON}
  PBut := New(PIconButton, Init(R, '', cmDosShell,
	  bfGrabFocus+tbDrawFrame+tbAutoSize, @ICSHELL));
  PBut^.Options := PBut^.Options and not ofSelectable;
  PBar^.Insert(PBut);

  Inc(R.A.y, BHeight);                                           {QUIT BUTTON}
  PBut := New(PIconButton, Init(R, '', cmQuit,
	  bfGrabFocus+tbDrawFrame+tbAutoSize, @ICQUIT));
  PBut^.Options := PBut^.Options and not ofSelectable;
  PBar^.Insert(PBut);

  PBar^.SelectNext(false);

  DeskTop^.Insert(PBar);
end;

procedure TSimApp.PutPicture(FName: PathStr; X,Y: Integer);   {Opening Screen}
var
  R : TRect;
  BitPtr : PBitMap;
  cmd : integer;
  FInputBox : PFileDialog;
  InFile : file;
  Result : word;
  Buf : array[0..Sizeof(TBitMapInfoHeader)-1] of byte;
  TotalBytes : LONGint; {!!!}
  ErrStr : string;
begin
  BitPtr := nil;
  Inc(WinNum);
  R.A.x := 100; R.A.y := 100;
  if FName <> '' then begin
    Assign(InFile, FName);
    Reset(InFile,1);                                     {reads 1 byte blocks}

						    {read just the InfoHeader}
    BlockRead(InFile, Buf, Sizeof(TBitMapInfoHeader), Result);

		    {remember - the Infoheader is in Buf, not yet in BitPtr^.}
    ErrStr := BMPFormatOKStr(PBitMap(@Buf), FName);
    If ErrStr = '' then begin
      BitPtr := AllocateBMPmem(PBitMap(@Buf)); {allocate mem,use special call}
      if BitPtr <> nil then begin
	TotalBytes := GetBitImageSize(PBitMap(@Buf));

	Reset(InFile,1);          {start again at beginning of file, read all}
	BlockRead(InFile, BitPtr^, TotalBytes, Result);

	WinToTVColor(BitPtr);
	MCur.Hide;                                         {Hide Mouse Cursor}
	PutBitMap(X,Y, BitPtr, 0, NormalPut);
	MCur.Show;                                         {Show Mouse Cursor}
      end;
    end
    else
      cmd := MessageBox(ErrStr, nil, mfError+mfOKButton);

    System.Close(InFile);

    if BitPtr <> nil then FreeMem(BitPtr, TotalBytes);
  end;
end;

procedure TSimApp.SaveDeskTop;                  {Save desktop to file SIM.DSK}
const
  FName = 'SIM.DSK';
var
  SaveFile : TBufStream;
  FStatus,cmd : integer;
  Pal : PString;
begin
    SaveFile.Init(FName, stCreate, 1048);                 {create a save file}
    Pal := PString(GetPalette);                       {get pointer to palette}
    SaveFile.WriteStr(Pal);                                     {save palette}
    SaveFile.Put(DeskTop);                                      {save DeskTop}
    SaveFile.Flush;
    FStatus := SaveFile.Status;
    SaveFile.Done;                                            {flushes buffer}
    if FStatus <> stOK then
      if FStatus = stPutError then
	cmd := MessageBox('Put of unregistered object.',nil,
	mfError + mfOkButton)
      else if SaveFile.ErrorInfo <> 0 then
	   DOSErrorMessageBox(SaveFile.ErrorInfo, FName)
	   else
	     cmd := MessageBox('Error saving file.',nil,
	     mfError + mfOkButton);
end;

procedure TSimApp.LoadDeskTop(FName: String);         {Load desktop from file}
  procedure CloseView(P: PView); far;
  begin
    Message(P, evCommand, cmClose, nil);
  end;
  procedure ReadFile(var S : TBufStream);
  var
    Pal : PString;
  begin
    if Desktop^.Valid(cmClose) then
    begin
      Pal := S.ReadStr;
      if Pal <> nil then
      begin
	GetPalette^ := Pal^;
	DisposeStr(Pal);
      end;
      Delete(DeskTop);
      Dispose(DeskTop,Done);
      DeskTop := PDeskTop(ValidView(PDeskTop(S.Get)));

      Insert(DeskTop);
    end;
  end;
var
  SaveFile : TBufStream;
  FStatus,cmd : integer;
begin
  SaveFile.Init(FName, stOpenRead, 1048);
  if (SaveFile.Status = stOK) then begin                          {found file}
    ReadFile(SaveFile);
    FStatus := SaveFile.Status;
    SaveFile.Done;                                            {flushes buffer}
    if FStatus <> stOK then
      if FStatus = stGetError then
	cmd := MessageBox('Get of unregistered object.',nil,
	mfError + mfOkButton)
      else if SaveFile.ErrorInfo <> 0 then
	   DOSErrorMessageBox(SaveFile.ErrorInfo, FName)
	   else
	     cmd := MessageBox('Error reading file.',nil,
	     mfError + mfOkButton);
  end;
end;

Procedure InitProgram;                    {Initiations for Simulation Program}

begin
  SoundOn       := True;                                {Sound Flag set to On}
  Zipped[GCT]   := False;
  HelpRequired  := False;                                   {No help required}
  TimeToStorm   := 0;                                        {No storm active}
  ErosLog  := False;                                     {No log files at all}
  VeloLog  := False;
  LevelLog := False;
  GapLog   := False;
  RememProfLev   := False;                           {No profiles remembered}
  RememContours  := False;                           {No contours remembered}
  RememLevels    := False;                             {No levels remembered}
  InitTimeStep   := 450;
  TimeStep       := InitTimeStep;
end;

Procedure TestDamDestruction;
var CC: Integer;
    OutP: Text;
begin
   Assign(OutP, 'TEST1000');
   ReWrite(OutP);
   NumOfGaps:=1;
   DamD50[1]:=1000;
   BottomD50:=DamD50[1];
   Chezy:=50;
   for CC:=1 to 2500 do
   begin
      Velocity[1]:=CC/300;
      DamDestruction;
      WriteLn(OutP,CC, Velocity[1], ErosionPerMPerS[1]);
      {ReadLn;}
   end;
   halt;
end;

Procedure TestBedDestruction;

var OutP: Text;
    Breusers: Real;
    TestTimeHours, CC: Integer;
    TSK: Real;

begin
   GapSurface[1]:=1;
   NumOfSnaps[1]:=5;
   Construction[1]:=Busy;
   StandLengthProt[1]:=100;
   SnapWidth[1]:=5;
   NumOfGaps:=1;
   OrigTotalGapSurface:=5000;
   GapDepthAtMSL[1]:=1000;

   StaticsOn:=True;
   Assign(OutP, 'BEDGRAPH');
   ReWrite(OutP);
   BottomD50:=4;
   Chezy:=70;
   StaticAlpha:=2.5;
   StaticVelocityEndBP:=1.3;
   OrigGapDepthAtMSL[1]:=10;
   ClrScr;
   WriteLn(OutP,'   TIME ELAPSED           DEPTH in PROGRAM        DEPTH acc BREUSERS');
   WriteLn(OutP,'=====================================================================');
   for CC:=0 to 130 do
   begin
      TestTimeHours:=CC;
      WriteLn(CC);
      Repeat
	 TSK:=TimeSinceKent;
	 BedDestruction;
      Until TimeSinceKent/3600>=TestTimeHours;
      NumOfKenterings:=5;
      Kentering;
      Breusers:=Power(StaticAlpha*StaticVelocityEndBP-CriticVelocity,1.7)*
		     Power(OrigGapDepthAtMSL[1],0.2)*Power((TSK/3600), 0.4)/
		     (10*Power(Delta,0.7));
      WriteLn(OutP, TSK,'        ',InHoleDepth[1,2],'        ',Breusers);
      AUUC34[1,2]:=0;
      InHoleDepth[1,2]:=0;
      InHoleScour[1,2]:=0;
   end;
   Close(OutP);
   halt;
end;

var                                                             {Main Program}
  SimApp: TSimApp;
  StartPar: String;

begin
  {Assign(OutP, 'alphas');
  Rewrite(OutP);}
  SimApp.Init;                    {Initiate Simulation Program User Interface}
  InitProgram;                                   {Initiate Simulation Program}
  SimApp.Default(cmNo);                               {Load Default Situation}
  StartPar:=ParamStr(1);
  {StartPar:='kabel1.ctb';}
  if StartPar<>'' then
  begin
     Opt_Load(StartPar);
     SimApp.InsertOverallWin;                           {Open graphics window}
     SimApp.InsertDataBoxWin;                           {Open numerics window}
     Started:=True;
     Dialoged:=True;
     ONOG:=NumOfGaps;
  end;
  SimApp.Run;                                                    {Run Program}
  {Close(OutP);}
  SimApp.Done;                                      {Shut Down User Interface}
end.
