Unit SimOpts;

Interface

uses Crt, Dos, Graph,
     SIMVARS, SIMCALC, SIMTOOLS, SIMDIALS, SIMDRAWS;

procedure Opt_Load(FTL: FileString);
procedure Opt_Save(FTS: FileString);
procedure Opt_InitProcess;
procedure Opt_Start;
procedure Opt_DateTime;
procedure Opt_Basin;
procedure Opt_RiverData;
procedure Opt_Closure;
procedure Opt_DepthsWidths;
procedure Opt_Tide;
procedure Opt_Dimensions;
procedure Opt_Protection;
procedure Opt_GradualClose;
procedure Opt_Culvert;
procedure Opt_ViewOverall(Action: Boolean);
procedure Opt_ViewLevels;
procedure Opt_ViewTop;
procedure Opt_ViewProfile;
procedure Opt_ViewLength;

Implementation                             {Definition of written procedures}

Procedure Opt_InitProcess;

var x,y: Integer;

begin
  Close(SnapFile);
  Assign(SnapFile, 'SNAP');
  Rewrite(SnapFile);
  Started:=False;                                       {Process interrupted}
  for GCT:=1 to NumOfGaps do GapWidth[GCT]:=OrigGapWidth[GCT];
  Equilize_Profiles;                        {Restore profiles to equilibrium}
  JobHours:=0;                     {After, restore all building activities}
  NumOfKenterings:=0;
  OrigMaxHeight:=1000;
  OrigTotalGapSurface:=0;
  OrigTotalWidth:=0;
  BasinLevel:=MeanSeaLevel;
  OldBasinLevel:=MeanSeaLevel;
  for GCT:=1 to NumOfGaps do
  begin
      OrigGapWidth[GCT]      :=  GapWidth[GCT];
      OrigGapDepthAtMSL[GCT] :=  GapDepthAtMSL[GCT];
      OrigGapSurface[GCT]    :=  abs(OrigGapWidth[GCT]*OrigGapDepthAtMSL[GCT]);
      GapSurface[GCT]        :=  OrigGapSurface[GCT];
      OrigTotalGapSurface    :=  OrigTotalGapSurface+OrigGapSurface[GCT];
      OrigTotalWidth         :=  OrigTotalWidth+GapWidth[GCT];
      DamYL[GCT]             :=  OrigGapDepthAtMSL[GCT];
      NumOfSnaps[GCT]        :=  R(Min(GapWidth[GCT]/15,40));
      SnapWidth[GCT]         :=  GapWidth[GCT]/NumOfSnaps[GCT];
      DamYR[GCT]             :=  OrigGapDepthAtMSL[GCT];
      YDR[GCT]               :=  OrigGapDepthAtMSL[GCT];       {Sill to zero}
      XDRL[GCT]              :=  0;                        {Toes to extremes}
      XDRR[GCT]              :=  OrigGapWidth[GCT];
      DumpedLeft[GCT]        :=  0;                      {No material dumped}
      DumpedRight[GCT]       :=  0;
      DumpedUp[GCT]          :=  0;
      ActualVolume[GCT]      :=  0;
      GradualUp[GCT]         :=  0;
      GradualLeft[GCT]       :=  0;
      GradualRight[GCT]      :=  0;
      UpMaxLevel[GCT]        :=  100;
      ErodedLeft[GCT]        :=  0;
      ErodedRight[GCT]       :=  0;
      ErodedUp[GCT]          :=  0;
      TotalEroded[GCT]       :=  0;                      {No material eroded}
      TotalDumped[GCT]       :=  0;
      ProcessLeft[GCT]       :=  Start;       {Processes left in start phase}
      ProcessRight[GCT]      :=  Start;
      Construction[GCT]      :=  Busy;
      MaxInHole[GCT]         :=  0;
      MaxOutHole[GCT]        :=  0;
      GapMu[GCT]             :=  1;
      for SC:=0 to NumOfSnaps[GCT] do
	for Counter:=1 to 20 do
	begin
	   InProtY[GCT, SC, Counter]:=0;
	   OutProtY[GCT, SC, Counter]:=0;
	end;
      StandLengthProt[GCT]:=ProtSection[GCT]*40;
      DamHeigth[GCT]:=DamTop[GCT]-OrigGapDepthAtMSL[GCT];
      RequiredVolume[GCT]:=
	   OrigGapWidth[GCT]*(                                {Length of dam}
	   (DamTopWidth[GCT]*DamHeigth[GCT])+            {Rectangular centre}
	   (DamHeigth[GCT]/Tan(DSS[GCT]))*DamHeigth[GCT]);            {Slope}
      for SC:=0 to NumOfSnaps[GCT] do
      begin
	 for Counter:=0 to 20 do InProtY[GCT,SC,Counter]:=0;
	 for Counter:=0 to 20 do OutProtY[GCT,SC,Counter]:=0;
	 LastProtIn[GCT, SC]   := 20;
	 LastProtOut[GCT, SC]  := 20;
	 InHoleScour[GCT, SC]  := 0;              {Restore Scour Processes}
	 InHoleDepth[GCT, SC]  := 0;
	 OutHoleScour[GCT, SC] := 0;
	 OutHoleDepth[GCT, SC] := 0;
      end;
  end;
  TotalGapSurface:=OrigTotalGapSurface;

  RememProfLev   := False;                           {No profiles remembered}
  RememContours  := False;

  DetermineMaxima;

  Determine_EquilibriumProfile;

  FillScreen;

  DataChanged:=False;

end;

Procedure Opt_Load(FTL: FileString);

var  InCh: Text;

begin
   RememProfLev:=False;
   Assign(InCh, FTL); reset(InCh);
   ReadLn(InCh, BasinYear);
   ReadLn(InCh, BasinMonth);
   ReadLn(InCh, BasinDay);
   ReadLn(InCh, BasinHour);
   ReadLn(InCh, BasinMinute);
   ReadLn(InCh, YearDay);
   ReadLn(InCh, DayS);
   ReadLn(InCh, JobSeconds);
   ReadLn(InCh, RiverFlow);
   ReadLn(InCh, CulvertSurface);
   ReadLn(InCh, Chezy);
   ReadLn(InCh, BottomD50);
   ReadLn(InCh, MeanSeaLevel);
   ReadLn(InCh, ActSeaLevel);
   ReadLn(InCh, OSeal);
   ReadLn(InCh, OldBasinLevel);
   ReadLn(InCh, BasinLevel);
   ReadLn(InCh, TotalFlow);
   ReadLn(InCh, Velocity);
   ReadLn(InCh, LevelFactY);
   ReadLn(InCh, LevelDrX);
   ReadLn(InCh, NumOfKenterings);
   for Counter:=1 to 4 do
   begin
      ReadLn(InCh, TideAmp[Counter]);
      ReadLn(InCh, TidePeriod[Counter]);
      ReadLn(InCh, TidePhase0[Counter]);
   end;
   ReadLn(InCh, TotalAmplitude);
   ReadLn(InCh, EquiTotalGapSurface);
   ReadLn(InCh, OrigMaxHeight);
   ReadLn(InCh, OrigTotalWidth);
   ReadLn(InCh, WidthFact);
   ReadLn(InCh, FlowDirection);
   ReadLn(InCh, OldFlowDirection);
   for Counter:=1 to 5 do
   begin
      ReadLn(InCh,KomDepth[Counter]);
      ReadLn(InCh,KomSur[Counter]);
   end;
   ReadLn(InCh, NumOfGaps);
   for GCT:=1 to NumOfGaps do
   begin
      ReadLn(InCh, WeirSituation[GCT]);
      ReadLn(InCh, Construction[GCT]);
      ReadLn(InCh, OrigGapWidth[GCT]);
      ReadLn(InCh, GapWidth[GCT]);
      ReadLn(InCh, OrigGapDepthAtMSL[GCT]);
      ReadLn(InCh, OrigGapSurface[GCT]);
      ReadLn(InCh, GapFlow[GCT]);
      ReadLn(InCh, GapMu[GCT]);
      ReadLn(InCh, DumpedLeft[GCT]);
      ReadLn(InCh, DumpedRight[GCT]);
      ReadLn(InCh, DumpedUp[GCT]);
      ReadLn(InCh, ProcessLeft[GCT]);
      ReadLn(InCh, ProcessRight[GCT]);
      ReadLn(InCh, ActualVolume[GCT]);
      ReadLn(InCh, XDRL[GCT]);
      ReadLn(InCh, XDRR[GCT]);
      ReadLn(InCh, YDR[GCT]);
      ReadLn(InCh, DamYL[GCT]);
      ReadLn(InCh, DamYR[GCT]);
      ReadLn(InCh, GapDepthAtMSL[GCT]);
      ReadLn(InCh, DamTopWidth[GCT]);
      ReadLn(InCh, DamTop[GCT]);
      ReadLn(InCh, RequiredVolume[GCT]);
      ReadLn(InCh, DamHeigth[GCT]);
      ReadLn(InCh, DSH[GCT]);
      ReadLn(InCh, DSS[GCT]);
      ReadLn(InCh, DamD50[GCT]);
      ReadLn(InCh, GradualLeft[GCT]);
      ReadLn(InCh, GradualUp[GCT]);
      ReadLn(InCh, UpMaxLevel[GCT]);
      ReadLn(InCh, GradualRight[GCT]);
      ReadLn(InCh, StartDrawX[GCT]);
      ReadLn(InCh, StandLengthProt[GCT]);
      ReadLn(InCh, ProtSection[GCT]);
      ReadLn(InCh, SnapWidth[GCT]);
      ReadLn(InCh, MaxOutHole[GCT]);
      ReadLn(InCh, MaxInHole[GCT]);
      ReadLn(InCh, MaxInHolePlace[GCT]);
      ReadLn(InCh, MaxOutHolePlace[GCT]);
      ReadLn(InCh, NumOfSnaps[GCT]);
      for SC:=1 to NumOfSnaps[GCT] do
      begin
	 ReadLn(InCh, InHoleScour[GCT, SC]);
	 ReadLn(InCh, InHoleDepth[GCT, SC]);
	 ReadLn(InCh, oInHoleDepth[GCT, SC]);
	 ReadLn(InCh, OutHoleScour[GCT, SC]);
	 ReadLn(InCh, OutHoleDepth[GCT, SC]);
	 ReadLn(InCh, oInHoleDepth[GCT, SC]);
	 ReadLn(InCh, LastProtIn[GCT, SC]);
	 ReadLn(InCh, LastProtOut[GCT, SC]);
	 ReadLn(InCh, AUUC34[GCT, SC]);
	 for Counter:=1 to 20 do
	 begin
	    ReadLn(InCh, InProtY[GCT, SC, Counter]);
	    ReadLn(InCh, OutProtY[GCT, SC, Counter]);
	 end;
     end;
   end;
   ReadLn(InCh, TotalGapSurface);
   ReadLn(InCh, OrigTotalGapSurface);
   ReadLn(InCh, TidalPrism);
   ReadLn(InCh, U02);
   ReadLn(InCh, ReducPerM);
   ReadLn(InCh, TimeSinceKent);
   close(InCh);
   FillScreen;
   DataChanged:=False;
end;

procedure Opt_Save(FTS: FileString);

var Outch: Text;

begin
   if DataChanged then Opt_InitProcess;
   Assign(OutCh, FTS); rewrite(OutCh);
   WriteLn(OutCh, BasinYear);
   WriteLn(OutCh, BasinMonth);
   WriteLn(OutCh, BasinDay);
   WriteLn(OutCh, BasinHour);
   WriteLn(OutCh, BasinMinute);
   WriteLn(OutCh, YearDay,                        '  Day of Year           ');
   WriteLn(OutCh, DayS);
   WriteLn(OutCh, JobSeconds:5:5,                 '  Seconds of Process    ');
   WriteLn(OutCh, RiverFlow:5:5,                  '  River Flow            ');
   WriteLn(OutCh, CulvertSurface:5:5,             '  Culvert Surface       ');
   WriteLn(OutCh, Chezy:5:5,                      '  Chezy Value           ');
   WriteLn(OutCh, BottomD50:5:5,                  '  BottomD50             ');
   WriteLn(OutCh, MeanSeaLevel:5:5,               '  Mean Sea Level        ');
   WriteLn(OutCh, ActSeaLevel:5:5,                '  Actual Sea Level      ');
   WriteLn(OutCh, OSeal:5:5,                      '  Old Sea Level         ');
   WriteLn(OutCh, OldBasinLevel:5:5,              '  Old Basin Level       ');
   WriteLn(OutCh, BasinLevel:5:5,                 '  Actual Basin Level    ');
   WriteLn(OutCh, TotalFlow:5:5,                  '  Total Flow throug Gaps');
   WriteLn(OutCh, Velocity:5:5,                   '  Flow Velocity         ');
   WriteLn(OutCh, LevelFactY:5:5,                 '  Y factor LevelDrawing ');
   WriteLn(OutCh, LevelDrX:5:5,                   '  Coord X Level Drawing ');
   WriteLn(OutCh, NumOfKenterings:5,              '  Kenterings Till Now   ');
   for Counter:=1 to 4 do
   begin
      WriteLn(OutCh, TideAmp[Counter]:5:5,     '     Tidal Amplitude Factor');
      WriteLn(OutCh, TidePeriod[Counter]:5:5,  '     Tidal Period          ');
      WriteLn(OutCh, TidePhase0[Counter]:5:5,  '     Tidal Phase at T=0    ');
   end;
   WriteLn(OutCh, TotalAmplitude:5:5,             '  Max Amplitude Possible');
   WriteLn(OutCh, EquiTotalGapSurface:5:5,        '  Gap Surf   Equilibrium');
   WriteLn(OutCh, OrigMaxHeight:5:5,              '  Original Maximum Depth');
   WriteLn(OutCh, OrigTotalWidth:5:5,             '  Original Total Width  ');
   WriteLn(OutCh, WidthFact:5:5,                  '  Drawing Width Factor  ');
   WriteLn(OutCh, FlowDirection:5,                '  Actual Flow Direction ');
   WriteLn(OutCh, OldFlowDirection:5,             '  Last Flow Direction   ');
   for Counter:=1 to 5 do
   begin
      WriteLn(OutCh,KomDepth[Counter]:5:5,     '     Level in Basin        ');
      WriteLn(OutCh,KomSur[Counter]:5:5,       '     with Surface in Basin ');
   end;
   WriteLn(OutCh, NumOfGaps:5,                    '  Number of Gaps to Close');
   for GCT:=1 to NumOfGaps do
   begin
      WriteLn(OutCh, WeirSituation[GCT]:5,        '  Actual Weir Situation ');
      WriteLn(OutCh, Construction[GCT]:5,         '  Construction Status   ');
      WriteLn(OutCh, OrigGapWidth[GCT]:5:5,       '  Original Width of Gap ');
      WriteLn(OutCh, GapWidth[GCT]:5:5,           '  Actual Width of Gap   ');
      WriteLn(OutCh, OrigGapDepthAtMSL[GCT]:5:5,  '  Original Depth of Gap ');
      WriteLn(OutCh, OrigGapSurface[GCT]:5:5,     '  Original Gap Surface  ');
      WriteLn(OutCh, GapFlow[GCT]:5:5,            '  Actual Gap Flow       ');
      WriteLn(OutCh, GapMu[GCT]:5:5,              '  Contraction in Gap    ');
      WriteLn(OutCh, DumpedLeft[GCT]:5:5,         '  Volume Dumped Left    ');
      WriteLn(OutCh, DumpedRight[GCT]:5:5,        '                Right   ');
      WriteLn(OutCh, DumpedUp[GCT]:5:5,           '                Vertical');
      WriteLn(OutCh, ProcessLeft[GCT]:5,          '  Process Left          ');
      WriteLn(OutCh, ProcessRight[GCT]:5,         '  Process Right         ');
      WriteLn(OutCh, ActualVolume[GCT]:5:5,       '  Actual Volume of Dam  ');
      WriteLn(OutCh, XDRL[GCT]:5:5,               '  X left of Apron       ');
      WriteLn(OutCh, XDRR[GCT]:5:5,               '  X right of Apron      ');
      WriteLn(OutCh, YDR[GCT]:5:5,                '  Apron Level           ');
      WriteLn(OutCh, DamYL[GCT]:5:5,              '  Dam Level Left        ');
      WriteLn(OutCh, DamYR[GCT]:5:5,              '  Dam Level Right       ');
      WriteLn(OutCh, GapDepthAtMSL[GCT]:5:5,      '  Actual Gap Depth      ');
      WriteLn(OutCh, DamTopWidth[GCT]:5:5,        '  Top Width of Dam      ');
      WriteLn(OutCh, DamTop[GCT]:5:5,             '  Required Top Level    ');
      WriteLn(OutCh, RequiredVolume[GCT]:5:5,     '  Required Dam Volume   ');
      WriteLn(OutCh, DamHeigth[GCT]:5:5,          '  => Required Dam Height');
      WriteLn(OutCh, DSH[GCT]:5:5,                '  Slope of Dam Head     ');
      WriteLn(OutCh, DSS[GCT]:5:5,                '  Slope of Section      ');
      WriteLn(OutCh, DamD50[GCT]:5:5,             '  D50 of Dam Material   ');
      WriteLn(OutCh, GradualLeft[GCT]:5:5,        '  Speed Closure Left    ');
      WriteLn(OutCh, GradualUp[GCT]:5:5,          '                Right   ');
      WriteLn(OutCh, UpMaxLevel[GCT]:5:5,         '  Level Limit Vertical  ');
      WriteLn(OutCh, GradualRight[GCT]:5:5,       '                 UpSide ');
      WriteLn(OutCh, StartDrawX[GCT]:5:5,         '  Drawing of Sections; X');
      WriteLn(OutCh, StandLengthProt[GCT]:5:5,    '  Length of Protection  ');
      WriteLn(OutCh, ProtSection[GCT]:5:5,        '  Length of BP section  ');
      WriteLn(OutCh, SnapWidth[GCT]:5:5,          '  Width between Scour SC');
      WriteLn(OutCh, MaxOutHole[GCT]:5:5,         '  Maximum Scour Outside ');
      WriteLn(OutCh, MaxInHole[GCT]:5:5,          '  Maximum Scour Inside  ');
      WriteLn(OutCh, MaxInHolePlace[GCT]:5:5,     '  Place Mx Scour Inside ');
      WriteLn(OutCh, MaxOutHolePlace[GCT]:5:5,    '  Place Mx Scour Outside');
      WriteLn(OutCh, NumOfSnaps[GCT]:5,           '  Number of Scour Snaps ');
      for SC:=1 to NumOfSnaps[GCT] do
      begin
	 WriteLn(OutCh, InHoleScour[GCT,SC]:5:5,  '      Scour Hole Inside ');
	 WriteLn(OutCh, InHoleDepth[GCT,SC]:5:5,  '      Reduced Scour     ');
	 WriteLn(OutCh, oInHoleDepth[GCT,SC]:5:5, '      Last Scour Depth  ');
	 WriteLn(OutCh, OutHoleScour[GCT,SC]:5:5, '      Scour Hole Outside');
	 WriteLn(OutCh, OutHoleDepth[GCT,SC]:5:5, '      Reduced Scour     ');
	 WriteLn(OutCh, oOutHoleDepth[GCT,SC]:5:5,'      Last Scour Depth  ');
	 WriteLn(OutCh, LastProtOut[GCT,SC]:5:5,  '      Last protect   OUT');
	 WriteLn(OutCh, LastProtIn[GCT,SC]:5:5,   '      Last protect    IN');
	 WriteLn(OutCh, AUUC34[GCT,SC]:5:5,       '      Scour Integral    ');
	 for Counter:=1 to 20 do
	 begin
	    WriteLn(OutCh,
	    InProtY[GCT, SC, Counter]:5:5,        '  Protection Level InFl ');
	    WriteLn(OutCh,
	    OutProtY[GCT, SC, Counter]:5:5,       '  Protection Level OutFl');
	 end;
      end;
   end;
   WriteLn(OutCh, TotalGapSurface:5:5,            '  Actual Gap Surface    ');
   WriteLn(OutCh, OrigTotalGapSurface:5:5,        '  Original Total Surface');
   WriteLn(OutCh, TidalPrism:5:5,                 '  Tidal Prism           ');
   WriteLn(OutCh, U02:5:5,                        '  Square Velocity Integr');
   WriteLn(OutCh, ReducPerM:5:5,                  '  Velocity^5 Integral   ');
   WriteLn(OutCh, TimeSinceKent:5:5,              '  Time since Last Kent  ');
   close(OutCh);
end;

procedure Opt_DepthsWidths;

begin
   Case NumOfGaps of
      1: Dial_DepthsWidths1(GapWidth, GapDepthAtMSL, GapMu);
      2: Dial_DepthsWidths2(GapWidth, GapDepthAtMSL, GapMu);
      3: Dial_DepthsWidths3(GapWidth, GapDepthAtMSL, GapMu);
   end;
   for GCT:=1 to NumOfGaps do OrigGapWidth[GCT]:=GapWidth[GCT];
   DataChanged:=True; Started:=False;
end;

procedure Opt_Tide;
begin
   Dial_Tide(TideAmp, TidePeriod, TidePhase0);
   DataChanged:=True; Started:=False;
end;

procedure Opt_Protection;

begin
   if NumOfGaps=1 then Dial_Protection1(StandLengthProt);
   if NumOfGaps=2 then Dial_Protection2(StandLengthProt);
   if NumOfGaps=3 then Dial_Protection3(StandLengthProt);
   for GCT:=1 to NumOfGaps do ProtSection[GCT]:=StandLengthProt[GCT]/40;
   DataChanged:=True; Started:=False;
end;

procedure Opt_GradualClose;

begin
   if NumOfGaps=1 then Dial_Activities1(GradualLeft, GradualRight, GradualUp, UpMaxLevel, DamD50);
   if NumOfGaps=2 then Dial_Activities2(GradualLeft, GradualRight, GradualUp, UpMaxLevel, DamD50);
   if NumOfGaps=3 then Dial_Activities3(GradualLeft, GradualRight, GradualUp, UpMaxLevel, DamD50);
end;
procedure Opt_Dimensions;
begin
   for Counter:=1 to NumOfGaps do
   begin
      DSH[Counter]:=DSH[Counter]*PiToDeg;
      DSS[Counter]:=DSS[Counter]*PiToDeg;
   end;
   if NumOfGaps=1 then Dial_Dimensions1(DamTopWidth, DamTop, DSH, DSS);
   if NumOfGaps=2 then Dial_Dimensions2(DamTopWidth, DamTop, DSH, DSS);
   if NumOfGaps=3 then Dial_Dimensions3(DamTopWidth, DamTop, DSH, DSS);
   for Counter:=1 to NumOfGaps do
   begin
      DSH[Counter]:=DSH[Counter]*DegToPi;
      DSS[Counter]:=DSS[Counter]*DegToPi;
   end;
   DataChanged:=True; Started:=False;
end;

procedure Opt_Basin;
begin
   Dial_Basin(KomDepth, KomSur);
   DataChanged:=True; Started:=False;
end;

procedure Opt_RiverData;
begin
   Dial_Riverdata(RiverFlow);
end;

procedure Opt_Closure;

var ONOG: Integer;

begin
   Dial_Closure(NumOfGaps, Chezy, BottomD50);
   if NumOfGaps>ONOG then
   begin
      Opt_DepthsWidths;
      Opt_Dimensions;
      Opt_GradualClose;
   end;
   DataChanged:=True; Started:=False;
end;

procedure Opt_Culvert;
begin
   Dial_Culvert(CulvertSurface);
end;

procedure Opt_DateTime;
begin
   Dial_DateTime(BasinYear, BasinMonth, BasinDay, BasinHour, BasinMinute);
end;

procedure Opt_ViewLevels;

begin
   PresentedScreen:=LevelScreen;
   Open_Graphic_Presentation(GraphScreen);
   MesFrame('Viewing Level Information');
   Draw_LevelSpace(20,230,620,150)
end;

procedure Opt_ViewTop;

begin
   PresentedScreen:=TopScreen;
   Open_Graphic_Presentation(GraphScreen);
   MesFrame('Presentation of Top View of Closure');
   if Beta<>0 then Draw_TopView(50,240,8,8);
   if Started=False then
   begin
   repeat until mousepressed;
   presentedscreen:=menuscreen;
   Close_Graphic_Presentation(GraphScreen); end;
end;

procedure Opt_ViewProfile;

begin
   PresentedScreen:=ProfileScreen;
   Open_Graphic_Presentation(GraphScreen);
   MesFrame('Presentation of Section of Closure');
   Draw_Profile(40,100,600,100); {to remember values}
   Draw_Contours(40,100,600,100);
   Draw_Profile(40,100,600,100);
   Draw_Contours(40,100,600,100);
   if Started=False then
   begin
   repeat until mousepressed;
   presentedscreen:=menuscreen;
   Close_Graphic_Presentation(GraphScreen);
   end;
end;

procedure Opt_ViewLength;

begin
   PresentedScreen:=LengthScreen;
   Open_Graphic_Presentation(GraphScreen);
   MesFrame('Length Section of Channels');
   if Started=False then
   begin
   repeat until mousepressed;
   presentedscreen:=menuscreen;
   Close_Graphic_Presentation(GraphScreen);
   end;
end;

procedure Opt_ViewOverall(Action: Boolean);

var xl: real;

begin
   If PresentedScreen<>Overall then
   Begin
      PresentedScreen:=Overall;
      Open_Graphic_Presentation(GraphScreen);
      Draw_Contours(40,100,300,40); Draw_Contours(40,100,300,40);
      MesFrame('Viewing Overall Information');
      Draw_LevelSpace(340,130,620,50);
      if Action=False then
      begin
	 RememProfLev:=True;
	 Draw_Profile(40,100,300,40);
	 if Beta<>0 then Draw_Length(480,160,200,2);
	 TextXY(330,13,'Process has not been started.....');
	 Wipe(-1,-1,180,20);
	 Box(-1,-1,180,20);
	 SetColor(White);
	 TextXY(10,13,DayS+', '+BasinYear+'/'+BasinMonth+'/'+BasinDay);
	 if Started=False then
	 begin
	 repeat until mousepressed;
	 presentedscreen:=menuscreen;
	 Close_Graphic_Presentation(GraphScreen);
	 end;
      end;
   end
   else
   begin
      PresentedScreen:=MenuScreen;
      Close_Graphic_Presentation(GraphScreen);
   end;
end;

procedure Opt_Start;

begin
   if DataChanged=True then
   begin
      Opt_InitProcess;
   end;
   Assign(SnapFile, 'C:SNAP'); Rewrite(SnapFile);
   PresentedScreen:=MenuScreen;
   ActSeaLevel:=SeaLevel(MeanSeaLevel, TideAmp, TidePeriod, TidePhase0, JobSeconds);
end;

end.