{**********************************************************}
{            CLOSIM v 1.00  --  DialOG BOX UNIT            }
{**********************************************************}
{ Containing the Dialog boxes of the Turbo Vision Graphics }
{ User Interface for the simulation program on the Closure }
{ of Tidal Basins. Mark Middag, TUDelft, 1994.             }
{**********************************************************}

Unit GSimDial;

Interface

uses CRT, DOS, Memory, MyGraph3,
     GObjects, GDrivers,
     MCursor2, GMENU6,
     GViews,  GDialogs, GMsgBox, GStdDlg,
     GApp, GColors, GWindow,
     BMPDrvr, GBut,

     SIMVARS, SIMTOOLS;

procedure Dial_RiverData(var RiverFlow: Real);                                 {River Flow}
procedure Dial_DateTime(var YE, MO, DA, HO, MI: String);              {Basin Date and Time}
procedure Dial_Tide(var TideAmp, TidePeriod, TidePhase0: RealArr);      {Tidal information}
procedure Dial_Dimensions1(var DamTopWidth, DamTop: RealArr);    {Dam Dimensions for 1 gap}
procedure Dial_Dimensions2(var DamTopWidth, DamTop: RealArr);   {Dam Dimensions for 2 gaps}
procedure Dial_Dimensions3(var DamTopWidth, DamTop: RealArr);   {Dam Dimensions for 3 gaps}
procedure Dial_Methods1(var WayOfConstruction: IntArr);     {Head and Side angle for 1 gap}
procedure Dial_Methods2(var WayOfConstruction: IntArr);    {Head and Side angle for 2 gaps}
procedure Dial_Methods3(var WayOfConstruction: IntArr);    {Head and Side angle for 3 gaps}
procedure Dial_Angles1(var DSS, DSH: RealArr);              {Head and Side angle for 1 gap}
procedure Dial_Angles2(var DSS, DSH: RealArr);             {Head and Side angle for 2 gaps}
procedure Dial_Angles3(var DSS, DSH: RealArr);             {Head and Side angle for 3 gaps}
procedure Dial_GradualClose1(var GradualLeft, GradualRight,          {Production for 1 gap}
		  GradualUp, UpMaxLevel, DamD50: RealArr);
procedure Dial_GradualClose2(var GradualLeft, GradualRight,         {Production for 2 gaps}
                  GradualUp, UpMaxLevel, DamD50: RealArr);
procedure Dial_GradualClose3(var GradualLeft, GradualRight,         {Production for 3 gaps}
		  GradualUp, UpMaxLevel, DamD50: RealArr);
procedure Dial_Basin(var KomDepth, KomSur: RealArr);            {Basin storage information}
procedure Dial_Closure(var NumOfGaps: Integer;
			      var Chezy, BottomD50,
					  TimeStep: Real); {General information on closure}
procedure Dial_DefStorm(
	  var StormSurge, WaveDuringStorm, StormPeriod, StormChance: Real);
procedure Dial_Culvert(var CulvertSurface: Real);                         {Culvert surface}
procedure Dial_Protection1(var LengthProt: RealArr);      {Bottom protection in case 1 gap}
procedure Dial_Protection2(var LengthProt: RealArr);     {Bottom protection in case 2 gaps}
procedure Dial_Protection3(var LengthProt: RealArr);     {Bottom protection in case 3 gaps}
procedure Dial_DepthsWidths1(
             var GapWidth, GapDepthAtMSL, GapMu: RealArr);      {Depth and Width for 1 gap}
procedure Dial_DepthsWidths2(
             var GapWidth, GapDepthAtMSL, GapMu: RealArr);     {Depth and Width for 2 gaps}
procedure Dial_DepthsWidths3(
             var GapWidth, GapDepthAtMSL, GapMu: RealArr);     {Depth and Width for 3 gaps}
procedure Dial_ControleFile;
procedure Dial_VesselDraft(Var VesselDraft: Real);        {Choose draft of dumping vessels}
procedure Dial_Logfiles(
 var ErosLog, VeloLog, LevelLog, GapLog: Boolean);       {Which logfiles should be written}
procedure Warn_Material(MaterialSize, GapNo: Integer);          {Warning for Material Size}
procedure Warn_OnlyFullProcess;                          {Warning for Early Process Change}
procedure Warn_SlowProcess;				   {Warning for low computer speed}
procedure Warn_OnlySmallToBig;                            {If smaller particles are chosen}
procedure Warn_Protection;                                  {Warning for bottom protection}
procedure Warn_DepthWidthFact;                             {Warning for Depth Width Factor}
procedure Warn_Zipped;                                {Warning: wait until nothing skipped}
procedure Warn_VesselDraft;                             {Warning: depth for vessels needed}
procedure Warn_CaissonClosure;                       {Caisson Closure: Not Implemented Yet}
procedure Warn_SkippedNoChange;                               {Warning for Skipped Volumes}
procedure Warn_CableWayDamTopWidth;		    {Crest width restricted with cable way}
procedure Warn_NextDamTopWidth;		      {Crest width too small for next construction}
procedure Warn_BotProt;         	     {Protection length too small for construction}
procedure Warn_HelpOn;                                      {Warning: Help has been put on}
procedure HelpBox(S: String);                              {Empty box for help information}
function Dial_ReallyChange: Boolean;                     {Warning for Change of Parameters}
function Dial_EquilizeOrNot: Boolean;
function  Dial_FileSelect(Title: String; Mask, Try:
		PathStr; var FT: PathStr): Boolean;            {Turbo Vision Help Selector}
procedure Dial_Intro;						        {Intro Explanation}
Function  Dial_Startup: Boolean;              	                      {Startup Explanation}

implementation

var Dialog : PDialog;
    B : PView;
    R : TRect;
    Control : Word;
    U: String;

type
    RecString=String[45];

procedure MakePlace(a,b,c,d: Integer);
begin
   R.A.X :=a*CharLen;
   R.B.X :=R.A.X + (c-a)*CharLen -1;
   R.A.Y :=b*BoxHeight;
   R.B.Y :=R.A.Y + (d-b)*BoxHeight -1;
end;

Procedure Dial_RiverData(var RiverFlow: Real);

type
   RecRiverFlowData = record
     SRF: RecString;
   end;

var RiverFlowData: RecRiverFlowData;

begin
   DialY1:=2; DialY2:=25; MakePlace(9, DialY1, 76, DialY2);
   Dialog:=New(PDialog,Init(R,'River Flow Into Basin'));
   Tempor_Interr_Calc;
   ExitDialSeries:=False;
   with Dialog^ do
   begin
      MakePlace(2, 2, 65, 5);
      Insert(New(PgStaticText, Init(R,
      'The data with respect to a river is given as'^M+
      'an average flow. Remember, that when there is'^M+
      'a river flow, a culvert should be constructed.', DefaultOpts)));

      MakePlace(35,7,45,8);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(5,7,35,8);
      Insert(New(PgStaticText, Init(R, 'Average Flow (m3/s): ', DefaultOpts)));

      MakePlace(44,DialY2-5,54,DialY2-3);
      Insert(New(PButton, Init(R, '~C~ancel',cmCancel, bfDefault)));
      MakePlace(55,DialY2-5,65,DialY2-3);
      Insert(New(PButton, Init(R, '~O~K',cmOK, bfDefault)));

   end;

   with RiverFlowData do
   begin
      SRF:=N(RiverFlow);
   end;

   Dialog^.SetData(RiverFlowData);
   Control:=DeskTop^.ExecView(Dialog);
   if Control<>cmCancel
   then
   begin
      Dialog^.GetData(RiverFlowData);
      with RiverFlowData do
      begin
	 val(SRF,RiverFlow,control);
      end;
   end
   else ExitDialSeries:=True;
   Tempor_Resume_Calc;
end;

procedure Dial_DateTime(var YE, MO, DA, HO, MI: String);

type
   RecBasinTime = record
     SBYE, SBMO, SBDA, SBHO, SBMI: RecString;
   end;

var TimeData: RecBasinTime;

begin
   DialY1:=2; DialY2:=25; MakePlace(9, DialY1, 76, DialY2);
   Dialog:=New(PDialog,Init(R,'Change Basin Time And Date.'));
   Tempor_Interr_Calc;
   ExitDialSeries:=False;
   with Dialog^ do
   begin
      MakePlace(7, 2, 53, 3);
      Insert(New(PgStaticText, Init(R,
	 'The closure job has a fictive time and date.', DefaultOpts)));

      MakePlace(35,4,45,5);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(5,4,35,5);
      Insert(New(PgStaticText, Init(R, 'Job Year: ', DefaultOpts)));

      MakePlace(35,6,45,7);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(5,6,35,7);
      Insert(New(PgStaticText, Init(R, 'Job Month:', DefaultOpts)));

      MakePlace(35,8,45,9);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(5,8,35,9);
      Insert(New(PgStaticText, Init(R, 'Job Day:', DefaultOpts)));

      MakePlace(35,10,45,11);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(5,10,35,11);
      Insert(New(PgStaticText, Init(R, 'Job Hour:', DefaultOpts)));

      MakePlace(35,12,45,13);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(5,12,35,13);
      Insert(New(PgStaticText, Init(R, 'Job Minute:', DefaultOpts)));

      MakePlace(44,DialY2-5,54,DialY2-3);
      Insert(New(PButton, Init(R, '~C~ancel',cmCancel, bfDefault)));
      MakePlace(55,DialY2-5,65,DialY2-3);
      Insert(New(PButton, Init(R, '~O~K',cmOK, bfDefault)));
   end;

   with TimeData do
   begin
      SBYE:=YE;
      SBMO:=MO;
      SBDA:=DA;
      SBHO:=HO;
      SBMI:=MI;
   end;
repeat
   Warning:=False;
   Dialog^.SetData(TimeData);
   Control:=DeskTop^.ExecView(Dialog);
   if Control<>cmCancel
   then
   begin
      Dialog^.GetData(TimeData);
      with TimeData do
      begin
	 YE:=SBYE;
	 MO:=SBMO;
	 DA:=SBDA;
	 HO:=SBHO;
	 MI:=SBMI;
      end;
      if (Value(YE)<1800) or (Value(YE)>2100) then
      begin
	 Warning:=True;
	 U:='YEAR';
      end;
      if (Value(Mo)<1) or (Value(MO)>12) then
      begin
	 Warning:=True;
	 U:='MONTH';
      end;
      if (value(DA)<1) or (Value(DA)>31) then
      begin
	 Warning:=True;
	 U:='DAY';
      end;
      if (Value(HO)<0) or (Value(HO)>24) then
      begin
	 Warning:=True;
	 U:='HOUR'
      end;
      if (Value(MI)<0) or (Value(HO)>59) then
      begin
	 Warning:=True;
	 U:='MINUTE'
      end;
      if (Warning=True) and (Control<>cmCancel) then
	 MessageBox('The input is not correct.'#13+
		    'You should change the '+U+#13+
		    'information!'#13,
		    nil, mfWarning or mfOKButton);

   end;
Until (Warning=False) or (Control=cmCancel);
If Control=cmCancel then ExitDialSeries:=True;
Tempor_Resume_Calc; end;

Function Dial_FileSelect(Title: String; Mask, Try: PathStr; var FT: PathStr): Boolean;

type
   RecFileData = record
      FileName: PathStr;
   end;

var FileData: RecFileData;

begin
   Tempor_Interr_Calc;
   DialY1:=2; DialY2:=25; MakePlace(9, DialY1, 76, DialY2);
   Dialog:=New(PFileDialog,Init(Mask, Title,
    'File Name', fdOpenButton, 100));

   with FileData do
   begin
     FileName:=FT;
   end;
   Dialog^.SetData(FileData);
   Control:=DeskTop^.ExecView(Dialog);
   if Control<>cmCancel
   then
   begin
	 Dialog^.GetData(FileData);
	 with FileData do
	 begin
	    FT:=FileName;
	 end;
	 Dial_FileSelect:=True;
	end
	else
	begin
	   ExitDialSeries:=True;
	   FT:='';
	   Dial_FileSelect:=False;
	end;
     Tempor_Resume_Calc;
end;

procedure Dial_Tide(var TideAmp, TidePeriod, TidePhase0: RealArr);

type
   RecTidalData   = Record
     STA: Array[1..4] of RecString;
     STF: Array[1..4] of RecString;
   end;

var TidalData: RecTidalData;
    TotalAmplitude: Real;

begin
   DialY1:=2; DialY2:=25; MakePlace(4, DialY1, 76, DialY2);
   Dialog:=New(PDialog,Init(R,'Change Tidal Conditions of various factors'));

   Tempor_Interr_Calc;
   ExitDialSeries:=False;
   with Dialog^ do
   begin
      MakePlace(2, 2, 73, 4);
      Insert(New(PgStaticText, Init(R,
	 'The tidal conditions outside of the basin to'^M+
	 'be closed is given by four tidal components.', DefaultOpts)));

      MakePlace(25, 6, 27, 7);
      Insert(New(PgStaticText, Init(R, 'M2', DefaultOpts)));

      MakePlace(35, 6, 37, 7);
      Insert(New(PgStaticText, Init(R, 'S2', DefaultOpts)));

      MakePlace(45, 6, 47, 7);
      Insert(New(PgStaticText, Init(R, 'K1', DefaultOpts)));

      MakePlace(55, 6, 57, 7);
      Insert(New(PgStaticText, Init(R, 'O1', DefaultOpts)));

      MakePlace(3, 8, 18, 9);
      Insert(New(PgStaticText, Init(R, 'Amplitude (m)', DefaultOpts)));

      MakePlace(22, 8, 30, 9);
      Insert(New(PgInputLine, Init(R, 45, DefaultOpts)));

      MakePlace(32, 8, 40, 9);
      Insert(New(PgInputLine, Init(R, 45, DefaultOpts)));

      MakePlace(42, 8, 50, 9);
      Insert(New(PgInputLine, Init(R, 45, DefaultOpts)));

      MakePlace(52, 8, 60, 9);
      Insert(New(PgInputLine, Init(R, 45, DefaultOpts)));

      MakePlace(3, 10, 19, 11);
      Insert(New(PgStaticText, Init(R, 'Phase at t=0 (s)', DefaultOpts)));

      MakePlace(22, 10, 30, 11);
      Insert(New(PgInputLine, Init(R, 45, DefaultOpts)));

      MakePlace(32, 10, 40, 11);
      Insert(New(PgInputLine, Init(R, 45, DefaultOpts)));

      MakePlace(42, 10, 50, 11);
      Insert(New(PgInputLine, Init(R, 45, DefaultOpts)));

      MakePlace(52, 10, 60, 11);
      Insert(New(PgInputLine, Init(R, 45, DefaultOpts)));

      MakePlace(47,DialY2-5,57,DialY2-3);
      Insert(New(PButton, Init(R, '~C~ancel',cmCancel, bfDefault)));
      MakePlace(59,DialY2-5,69,DialY2-3);
      Insert(New(PButton, Init(R, '~O~K',cmOK, bfDefault)));
   end;
   with TidalData do
   begin
      For Counter:=1 to 4 do str(TideAmp[Counter]:6:2,     STA[Counter]);
      For Counter:=1 to 4 do str(TidePhase0[Counter]:6:0,  STF[Counter]);
   end;

   Dialog^.SetData(TidalData);

   repeat
      Warning:=False;
      Control:=DeskTop^.ExecView(Dialog);
      if Control<>cmCancel
      then begin
	 Dialog^.GetData(TidalData);
	 TotalAmplitude:=0;
	 with TidalData do
	 begin
	   for Counter:=1 to 4 do
	   begin
	      val(STA[Counter], TideAmp[Counter],     control);
	      TotalAmplitude := TotalAmplitude+TideAmp[Counter];
	   end;
	   for Counter:=1 to 4 do val(STF[Counter], TidePhase0[Counter],  control);
	 end;
	 if TotalAmplitude=0 then
	 begin
	    Warning:=True;
	    if Control<>cmCancel then
	    MessageBox('The sum of the amplitudes cannot'#13+
		       'be zero: there must be a tide!'#13,
		       nil, mfWarning or mfOKButton);
	 end;
	 if TotalAmplitude>15 then
	 begin
	    Warning:=True;
	    if Control<>cmCancel then
	    MessageBox('The sum of the amplitudes is too'#13+
		       'big: the maximum value is 15 m!'#13,
		       nil, mfWarning or mfOKButton);
	 end;
      end;
   Until (Warning=False) or (Control=cmCancel);
   if Control=cmCancel then ExitDialSeries:=True;
   Tempor_Resume_Calc;
end;

Procedure Dial_Protection1(var LengthProt: RealArr);

type
   RecProtectionData = record
     SLP: RecString;
     SQ: Integer;
   end;

var ProtectionData: RecProtectionData;

begin
   DialY1:=2; DialY2:=25; MakePlace(9, DialY1, 76, DialY2);
   Dialog:=New(PDialog,Init(R,'Length of Bottom Protection'));
   Tempor_Interr_Calc;
   ExitDialSeries:=False;
   with Dialog^ do
   begin
      MakePlace(2, 2, 73, 4);
      Insert(New(PgStaticText, Init(R,
	 'Give the length and quality of the bottom protection;'^M+
	 'a good protection can settle, a bad protection cannot.'
	 , DefaultOpts)));

      MakePlace(15,6,21,7);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(3,6,15,7);
      Insert(New(PgStaticText, Init(R, 'Gap 1 (m): ', DefaultOpts)));

      MakePlace(29, 6, 47, 8);
      Insert(New(PgStaticText, Init(R,
      'good quality'^M+
      ' bad quality', DefaultOpts)));

      MakePlace(47, 6, 52, 8);
      Insert(New(PRadioButtons, Init(R,
      NewSItem('',
      NewSItem('',
      Nil)))));

      MakePlace(44,DialY2-5,54,DialY2-3);
      Insert(New(PButton, Init(R, '~C~ancel',cmCancel, bfDefault)));
      MakePlace(55,DialY2-5,65,DialY2-3);
      Insert(New(PButton, Init(R, '~O~K',cmOK, bfDefault)));
   end;

   with ProtectionData do
   begin
      SLP:=N(LengthProt[1]);
      SQ:=ProtQuality[1];
   end;

   Dialog^.SetData(ProtectionData);
   repeat
   Control:=DeskTop^.ExecView(Dialog);
   if Control<>cmCancel
   then begin
      Dialog^.GetData(ProtectionData);
      with ProtectionData do
      begin
	 val(SLP,LengthProt[1],control);
	 ProtQuality[1]:=SQ;
      end;
      if ((LengthProt[1]<30) or (LengthProt[1]>2000))
	 and (LengthProt[1]<>0) then
      MessageBox(   'The bottom protection should'+U+#13+
		    'be longer than at least 200,'#13+
		    'and not longer than 2000 meters!',
		    nil, mfWarning or mfOKButton);
   end;
   until (LengthProt[1]>35) or (LengthProt[1]=0);
   Tempor_Resume_Calc;
   if Control=cmCancel then ExitDialSeries:=True;
end;

Procedure Dial_Protection2(var LengthProt: RealArr);

type
   RecProtectionData = record
     SLP: Array[1..2] of RecString;
     SQ: Array[1..2] of Integer;
   end;

var ProtectionData: RecProtectionData;

begin
   DialY1:=2; DialY2:=25; MakePlace(9, DialY1, 76, DialY2);
   Dialog:=New(PDialog,Init(R,'Lengths of Bottom Protections'));
   Tempor_Interr_Calc;
   ExitDialSeries:=False;
   with Dialog^ do
   begin
      MakePlace(2, 2, 73, 4);
      Insert(New(PgStaticText, Init(R,
	 'Give the length and quality of the bottom protection;'^M+
	 'a good protection can settle, a bad protection cannot.'
	 , DefaultOpts)));

      MakePlace(15,6,21,7);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(3,6,15,7);
      Insert(New(PgStaticText, Init(R, 'Gap 1 (m): ', DefaultOpts)));

      MakePlace(15,9,21,10);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(3,9,15,10);
      Insert(New(PgStaticText, Init(R, 'Gap 2 (m):', DefaultOpts)));

      MakePlace(29, 6, 47, 8);
      Insert(New(PgStaticText, Init(R,
      'good quality'^M+
      ' bad quality', DefaultOpts)));

      MakePlace(47, 6, 52, 8);
      Insert(New(PRadioButtons, Init(R,
      NewSItem('',
      NewSItem('',
      Nil)))));

      MakePlace(29, 9, 47, 11);
      Insert(New(PgStaticText, Init(R,
      'good quality'^M+
      ' bad quality', DefaultOpts)));

      MakePlace(47, 9, 52, 11);
      Insert(New(PRadioButtons, Init(R,
      NewSItem('',
      NewSItem('',
      Nil)))));

      MakePlace(44,DialY2-5,54,DialY2-3);
      Insert(New(PButton, Init(R, '~C~ancel',cmCancel, bfDefault)));
      MakePlace(55,DialY2-5,65,DialY2-3);
      Insert(New(PButton, Init(R, '~O~K',cmOK, bfDefault)));
   end;

   with ProtectionData do
   begin
      SLP[1]:=N(LengthProt[1]);
      SLP[2]:=N(LengthProt[2]);
      SQ[1]:=ProtQuality[1];
      SQ[2]:=ProtQuality[2];
   end;

   Dialog^.SetData(ProtectionData);
   repeat
   Control:=DeskTop^.ExecView(Dialog);
   if Control<>cmCancel
   then begin
      Dialog^.GetData(ProtectionData);
      with ProtectionData do
      begin
	 val(SLP[1],LengthProt[1],control);
	 val(SLP[2],LengthProt[2],control);
	 ProtQuality[1]:=SQ[1];
	 ProtQuality[2]:=SQ[2];
      end;
      if (((LengthProt[1]<30) or (LengthProt[1]>2000))
	 and (LengthProt[1]<>0))
      or (((LengthProt[2]<30) or (LengthProt[2]>2000))
	 and (LengthProt[2]<>0)) then
      MessageBox(   'The bottom protection should'+U+#13+
		    'be longer than at least 200 meters,'#13+
		    'and not longer than 2000 meters!',
		    nil, mfWarning or mfOKButton);
   end;
   until ((LengthProt[1]>35) or (LengthProt[1]=0))
     and ((LengthProt[2]>35) or (LengthProt[2]=0));
   Tempor_Resume_Calc;
   if Control=cmCancel then ExitDialSeries:=True;
end;

Procedure Dial_Protection3(var LengthProt: RealArr);

type
   RecProtectionData = record
     SLP: Array[1..3] of RecString;
     SQ : Array[1..3] of Integer;
   end;

var ProtectionData: RecProtectionData;

begin
   DialY1:=2; DialY2:=25; MakePlace(9, DialY1, 76, DialY2);
   Dialog:=New(PDialog,Init(R,'Lengths of Bottom Protections'));
   Tempor_Interr_Calc;
   ExitDialSeries:=False;
   with Dialog^ do
   begin
      MakePlace(2, 2, 73, 4);
      Insert(New(PgStaticText, Init(R,
	 'Give the length and quality of the bottom protection;'^M+
	 'a good protection can settle, a bad protection cannot.'
	 , DefaultOpts)));

      MakePlace(15,6,21,7);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(3,6,15,7);
      Insert(New(PgStaticText, Init(R, 'Gap 1 (m): ', DefaultOpts)));

      MakePlace(15,9,21,10);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(3,9,15,10);
      Insert(New(PgStaticText, Init(R, 'Gap 2 (m):', DefaultOpts)));

      MakePlace(15,12,21,13);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(3,12,15,13);
      Insert(New(PgStaticText, Init(R, 'Gap 3 (m):', DefaultOpts)));

      MakePlace(29, 6, 47, 8);
      Insert(New(PgStaticText, Init(R,
      'Quality good'^M+
      '         bad', DefaultOpts)));

      MakePlace(47, 6, 52, 8);
      Insert(New(PRadioButtons, Init(R,
      NewSItem('',
      NewSItem('',
      Nil)))));

      MakePlace(29, 9, 47, 11);
      Insert(New(PgStaticText, Init(R,
      'Quality good'^M+
      '         bad', DefaultOpts)));

      MakePlace(47, 9, 52, 11);
      Insert(New(PRadioButtons, Init(R,
      NewSItem('',
      NewSItem('',
      Nil)))));

      MakePlace(29, 12, 47, 14);
      Insert(New(PgStaticText, Init(R,
      'Quality good'^M+
      '         bad', DefaultOpts)));

      MakePlace(47, 12, 52, 14);
      Insert(New(PRadioButtons, Init(R,
      NewSItem('',
      NewSItem('',
      Nil)))));

      MakePlace(44,DialY2-5,54,DialY2-3);
      Insert(New(PButton, Init(R, '~C~ancel',cmCancel, bfDefault)));
      MakePlace(55,DialY2-5,65,DialY2-3);
      Insert(New(PButton, Init(R, '~O~K',cmOK, bfDefault)));
   end;

   with ProtectionData do
   begin
      SLP[1]:=N(LengthProt[1]);
      SLP[2]:=N(LengthProt[2]);
      SLP[3]:=N(LengthProt[3]);
      SQ[1]:=ProtQuality[1];
      SQ[2]:=ProtQuality[2];
      SQ[3]:=ProtQuality[3];
   end;

   Dialog^.SetData(ProtectionData);
   repeat
   Control:=DeskTop^.ExecView(Dialog);
   if Control<>cmCancel
   then begin
      Dialog^.GetData(ProtectionData);
      with ProtectionData do
      begin
	 val(SLP[1],LengthProt[1],control);
	 val(SLP[2],LengthProt[2],control);
	 val(SLP[3],LengthProt[3],control);
	 ProtQuality[1]:=SQ[1];
	 ProtQuality[2]:=SQ[2];
	 ProtQuality[3]:=SQ[3];
      end;
      if (((LengthProt[1]<30) or (LengthProt[1]>2000))
	 and (LengthProt[1]<>0))
      or (((LengthProt[2]<30) or (LengthProt[2]>2000))
	 and (LengthProt[2]<>0))
      or (((LengthProt[3]<30) or (LengthProt[3]>2000))
	 and (LengthProt[3]<>0))
      then
      MessageBox(   'The bottom protection should'+U+#13+
		    'be longer than at least 200 meters,'#13+
		    'and not longer than 2000 meters!',
		    nil, mfWarning or mfOKButton);
   end;
   until ((LengthProt[1]>35) or (LengthProt[1]=0))
     and ((LengthProt[2]>35) or (LengthProt[2]=0))
     and ((LengthProt[3]>35) or (LengthProt[3]=0));
   Tempor_Resume_Calc;
   if Control=cmCancel then ExitDialSeries:=True;
end;

procedure Dial_DepthsWidths1(var GapWidth, GapDepthAtMSL, GapMu: RealArr);

type
   RecDepthWidthData   = Record
      SGW,
      SGD,
      SGM: RecString;
   end;

var DepthWidthData: RecDepthWidthData;

begin
   DialY1:=2; DialY2:=25; MakePlace(9, DialY1, 76, DialY2);
   Dialog:=New(PDialog,Init(R,'Change Dimensions of Gap to Close'));
   Tempor_Interr_Calc;
   ExitDialSeries:=False;
   with Dialog^ do
   begin
      MakePlace(2, 2, 63, 3);
      Insert(New(PgStaticText, Init(R,
	 'The width and depth of the gaps can be chosen.', DefaultOpts)));

      MakePlace(27,6,35,7);
      Insert(New(PgStaticText, Init(R, ' DAM 1', DefaultOpts)));

      MakePlace(27,8,35,9);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(2,8,27,9);
      Insert(New(PgStaticText, Init(R, 'Width of gap (m): ', DefaultOpts)));

      MakePlace(27,10,35,11);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(2,10,27,11);
      Insert(New(PgStaticText, Init(R, 'Bottom level (m+MSL): ', DefaultOpts)));

      MakePlace(27,12,35,13);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(2,12,27,13);
      Insert(New(PgStaticText, Init(R, 'Contraction (-): ', DefaultOpts)));

      MakePlace(44,DialY2-5,54,DialY2-3);
      Insert(New(PButton, Init(R, '~C~ancel',cmCancel, bfDefault)));
      MakePlace(55,DialY2-5,65,DialY2-3);
      Insert(New(PButton, Init(R, '~O~K',cmOK, bfDefault)));
   end;

   Repeat

   with DepthWidthData do
   begin
	str(GapWidth[1]:6:2,       SGW);
	str(GapDepthAtMSL[1]:6:2,  SGD);
	str(GapMu[1]:6:2,          SGM);
   end;

   Dialog^.SetData(DepthWidthData);

   Control:=DeskTop^.ExecView(Dialog);
   if Control<>cmCancel
   then begin
      Dialog^.GetData(DepthWidthData);
      with DepthWidthData do
      begin
	   val(SGW, GapWidth[1],      control);
	   val(SGD, GapDepthAtMSL[1], control);
	   val(SGM, GapMu[1],         control);
	   OrigGapWidth[1]:=GapWidth[1];
      end;
   end;
   Warning:=False;
   for GCT:=1 to NumOfGaps do if Control<>cmCancel then
   begin
	 if (GapWidth[GCT]<5) then
      begin
	 Warning:=True;
	 U:='Gap width should be '#13'greater than 5.';
      end;
      if (GapDepthAtMSL[GCT]>0) then
      begin
	 Warning:=True;
	 U:='Gap depth should have'#13'a negative value.';
      end;
      if (GapMu[GCT]<0) or (GapMu[GCT]>2) then
      begin
	 Warning:=True;
	 U:='Gap  should be between'#13'0 and 2. '
      end;
   end;
   if (Warning=True) and (Control<>cmCancel) then
	 MessageBox('The input is not correct.'#13+U,
		    nil, mfWarning or mfOKButton);

   Until (Warning=False) or (Control=cmCancel);
   If Control=cmCancel then ExitDialSeries:=True;
   Tempor_Resume_Calc;
end;

procedure Dial_DepthsWidths2(var GapWidth, GapDepthAtMSL, GapMu: RealArr);

type
   RecDepthWidthData   = Record
      SGW,
      SGD,
      SGM: Array[1..2] of RecString;
   end;

var DepthWidthData: RecDepthWidthData;

begin
   DialY1:=2; DialY2:=25; MakePlace(9, DialY1, 76, DialY2);
   Dialog:=New(PDialog,Init(R,'Change Dimensions of Gaps to Close'));
   Tempor_Interr_Calc;
   ExitDialSeries:=False;
   with Dialog^ do
   begin
      MakePlace(2, 2, 63, 3);
      Insert(New(PgStaticText, Init(R,
      'The width and depth of the gaps can be chosen.', DefaultOpts)));

      MakePlace(27,6,35,7);
      Insert(New(PgStaticText, Init(R, ' DAM 1', DefaultOpts)));
      MakePlace(37,6,45,7);
      Insert(New(PgStaticText, Init(R, ' DAM 2', DefaultOpts)));

      MakePlace(2,8,27,9);
      Insert(New(PgStaticText, Init(R, 'Width of gap (m): ', DefaultOpts)));
      MakePlace(27,8,35,9);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(37,8,45,9);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);

      MakePlace(27,10,35,11);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(2,10,27,11);
      Insert(New(PgStaticText, Init(R, 'Bottom level (m+MSL): ', DefaultOpts)));
      MakePlace(37,10,45,11);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);

      MakePlace(27,12,35,13);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(2,12,27,13);
      Insert(New(PgStaticText, Init(R, 'Contraction (-): ', DefaultOpts)));
      MakePlace(37,12,45,13);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);

      MakePlace(44,DialY2-5,54,DialY2-3);
      Insert(New(PButton, Init(R, '~C~ancel',cmCancel, bfDefault)));
      MakePlace(55,DialY2-5,65,DialY2-3);
      Insert(New(PButton, Init(R, '~O~K',cmOK, bfDefault)));
   end;

   Repeat
      with DepthWidthData do
	 for Counter:=1 to 2 do begin
	    str(GapWidth[Counter]:6:2,  SGW[Counter]);
	    str(GapDepthAtMSL[Counter]:6:2,  SGD[Counter]);
	    str(GapMu[Counter]:6:2,  SGM[Counter]);
      end;

      Dialog^.SetData(DepthWidthData);

      Control:=DeskTop^.ExecView(Dialog);
      if Control<>cmCancel
      then begin
	 Dialog^.GetData(DepthWidthData);
	 with DepthWidthData do for Counter:=1 to 2 do
	 begin
	    val(SGW[Counter], GapWidth[Counter],      control);
	    val(SGD[Counter], GapDepthAtMSL[Counter], control);
	    val(SGM[Counter], GapMu[Counter],         control);
	    OrigGapWidth[Counter]:=GapWidth[Counter];
	 end;
	 Warning:=False;
	 for GCT:=1 to NumOfGaps do if Control<>cmCancel then
	 begin
	    if (GapWidth[GCT]<5) then
	    begin
	       Warning:=True;
	       U:='Gap width should be '#13'greater than 5.';
	    end;
	    if (GapDepthAtMSL[GCT]>0) then
	    begin
	       Warning:=True;
	       U:='Gap depth should have'#13'a negative value.';
	    end;
	    if (GapMu[GCT]<0) or (GapMu[GCT]>2) then
	    begin
	       Warning:=True;
	       U:='Gap  should be between'#13'0 and 2. '
	    end;
	 end;
	 if (Warning=True) and (Control<>cmCancel) then
	    MessageBox('The input is not correct.'#13+U,
			nil, mfWarning or mfOKButton);
      end;
   Until (Warning=False) or (Control=cmCancel);
   If Control=cmCancel then ExitDialSeries:=True;
   Tempor_Resume_Calc;
end;

procedure Dial_DepthsWidths3(var GapWidth, GapDepthAtMSL, GapMu: RealArr);

type
   RecDepthWidthData   = Record
      SGW,
      SGD,
      SGM: Array[1..3] of RecString;
   end;

var DepthWidthData: RecDepthWidthData;

begin
   DialY1:=2; DialY2:=25; MakePlace(9, DialY1, 76, DialY2);
   Dialog:=New(PDialog,Init(R,'Change Dimensions of Gaps to Close'));
   Tempor_Interr_Calc;
   ExitDialSeries:=False;
   with Dialog^ do
   begin
      MakePlace(2, 2, 63, 3);
      Insert(New(PgStaticText, Init(R,
      'The width and depth of the gaps can be chosen.', DefaultOpts)));

      MakePlace(27,6,35,7);
      Insert(New(PgStaticText, Init(R, ' DAM 1', DefaultOpts)));
      MakePlace(37,6,45,7);
      Insert(New(PgStaticText, Init(R, ' DAM 2', DefaultOpts)));
      MakePlace(47,6,55,7);
      Insert(New(PgStaticText, Init(R, ' DAM 3', DefaultOpts)));

      MakePlace(27,8,35,9);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(2,8,27,9);
      Insert(New(PgStaticText, Init(R, 'Width of gap (m): ', DefaultOpts)));
      MakePlace(37,8,45,9);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(47,8,55,9);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);

      MakePlace(27,10,35,11);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(2,10,27,11);
      Insert(New(PgStaticText, Init(R, 'Bottom level (m+MSL): ', DefaultOpts)));
      MakePlace(37,10,45,11);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(47,10,55,11);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);

      MakePlace(27,12,35,13);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(2,12,27,13);
      Insert(New(PgStaticText, Init(R, 'Contraction (-): ', DefaultOpts)));
      MakePlace(37,12,45,13);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(47,12,55,13);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);

      MakePlace(44,DialY2-5,54,DialY2-3);
      Insert(New(PButton, Init(R, '~C~ancel',cmCancel, bfDefault)));
      MakePlace(55,DialY2-5,65,DialY2-3);
      Insert(New(PButton, Init(R, '~O~K',cmOK, bfDefault)));
   end;

   Repeat

      with DepthWidthData do
      for Counter:=1 to 3 do
      begin
	   str(GapWidth[Counter]:6:2,  SGW[Counter]);
	   str(GapDepthAtMSL[Counter]:6:2,  SGD[Counter]);
	   str(GapMu[Counter]:6:2,  SGM[Counter]);
      end;

      Dialog^.SetData(DepthWidthData);

      Control:=DeskTop^.ExecView(Dialog);
      if Control<>cmCancel
      then
      begin
	 Dialog^.GetData(DepthWidthData);
	 with DepthWidthData do for Counter:=1 to 3 do
	 begin
	    val(SGW[Counter], GapWidth[Counter],      control);
	    val(SGD[Counter], GapDepthAtMSL[Counter], control);
	    val(SGM[Counter], GapMu[Counter],         control);
	    OrigGapWidth[Counter]:=GapWidth[Counter];
	 end;

	 Warning:=False;
	 for GCT:=1 to NumOfGaps do if Control<>cmCancel then
	 begin
	    if (GapWidth[GCT]<5) then
	    begin
	       Warning:=True;
	       U:='Gap width should be '#13'greater than 5.';
	    end;
	    if (GapDepthAtMSL[GCT]>0) then
	    begin
	       Warning:=True;
	       U:='Gap depth should have'#13'a negative value.';
	    end;
	    if (GapMu[GCT]<0) or (GapMu[GCT]>2) then
	    begin
	       Warning:=True;
	       U:='Gap  should be between'#13'0 and 2. '
	    end;
	 end;
	 if (Warning=True) and (Control<>cmCancel) then
	    MessageBox('The input is not correct.'#13+U,
			nil, mfWarning or mfOKButton);
      end;
   Until (Warning=False) or (Control=cmCancel);
   If Control=cmCancel then ExitDialSeries:=True;
   Tempor_Resume_Calc;
end;

procedure Dial_Dimensions1(var DamTopWidth, DamTop: RealArr);

type
   RecDimensionData   = Record
      SDTW,
      SDT: RecString;
   end;

var DimensionData: RecDimensionData;

begin
   DialY1:=2; DialY2:=25; MakePlace(9, DialY1, 76, DialY2);
   Dialog:=New(PDialog,Init(R,'Change Dimensions of Dams to Build'));
   Tempor_Interr_Calc;
   ExitDialSeries:=False;
   with Dialog^ do
   begin
      MakePlace(2, 2, 63, 3);
      Insert(New(PgStaticText, Init(R,
      'Enter the dam top width and dam top level.', DefaultOpts)));

      MakePlace(27,6,35,7);
      Insert(New(PgStaticText, Init(R, ' DAM 1', DefaultOpts)));

      MakePlace(27,8,35,9);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(2,8,27,9);
      Insert(New(PgStaticText, Init(R, 'Top Width of Dam (m): ', DefaultOpts)));

      MakePlace(27,10,35,11);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(2,10,27,11);
      Insert(New(PgStaticText, Init(R, 'Dam Top Level    (m):', DefaultOpts)));

      MakePlace(44,DialY2-5,54,DialY2-3);
      Insert(New(PButton, Init(R, '~C~ancel',cmCancel, bfDefault)));
      MakePlace(55,DialY2-5,65,DialY2-3);
      Insert(New(PButton, Init(R, '~O~K',cmOK, bfDefault)));
   end;

   with DimensionData do
   begin
	str(DamTopWidth[1]:6:2,  SDTW);
	str(DamTop[1]:6:2,  SDT);
   end;

   Dialog^.SetData(DimensionData);

   Control:=DeskTop^.ExecView(Dialog);
   if Control<>cmCancel
   then begin
      Dialog^.GetData(DimensionData);
      with DimensionData do
      begin
	   val(SDTW,  DamTopWidth[1],     control);
	   val(SDT,   DamTop[1],  control);
      end;
   end;
   if Control=cmCancel then ExitDialSeries:=True;
   Tempor_Resume_Calc;
end;

procedure Dial_Dimensions2(var DamTopWidth, DamTop: RealArr);

type
   RecDimensionData   = Record
      SDTW,
      SDT : Array[1..2] of RecString;
   end;

var DimensionData: RecDimensionData;

begin
   DialY1:=2; DialY2:=25; MakePlace(9, DialY1, 76, DialY2);
   Dialog:=New(PDialog,Init(R,'Change Dimensions of Dams to Build'));
   Tempor_Interr_Calc;
   ExitDialSeries:=False;
   with Dialog^ do
   begin
      MakePlace(2, 2, 63, 3);
      Insert(New(PgStaticText, Init(R,
      'Enter the dam top width and dam top level.', DefaultOpts)));

      MakePlace(27,6,35,7);
      Insert(New(PgStaticText, Init(R, ' DAM 1', DefaultOpts)));
      MakePlace(37,6,45,7);
      Insert(New(PgStaticText, Init(R, ' DAM 2', DefaultOpts)));

      MakePlace(2,8,27,9);
      Insert(New(PgStaticText, Init(R, 'Top Width of Dam: (m)', DefaultOpts)));
      MakePlace(27,8,35,9);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(37,8,45,9);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);

      MakePlace(2,10,27,11);
      Insert(New(PgStaticText, Init(R, 'Dam Top Level (m):', DefaultOpts)));
      MakePlace(27,10,35,11);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(37,10,45,11);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);

      MakePlace(44,DialY2-5,54,DialY2-3);
      Insert(New(PButton, Init(R, '~C~ancel',cmCancel, bfDefault)));
      MakePlace(55,DialY2-5,65,DialY2-3);
      Insert(New(PButton, Init(R, '~O~K',cmOK, bfDefault)));
   end;

   with DimensionData do
   for Counter:=1 to 2 do
   begin
	str(DamTopWidth[Counter]:6:2,  SDTW[Counter]);
	str(DamTop[Counter]:6:2,  SDT[Counter]);
   end;

   Dialog^.SetData(DimensionData);

   Control:=DeskTop^.ExecView(Dialog);
   if Control<>cmCancel
   then begin
      Dialog^.GetData(DimensionData);
      with DimensionData do for Counter:=1 to 2 do
      begin
	   val(SDTW[Counter],  DamTopWidth[Counter],     control);
	   val(SDT[Counter],   DamTop[Counter],  control);
      end;
   end;
   if Control=cmCancel then ExitDialSeries:=True;
   Tempor_Resume_Calc;
end;

procedure Dial_Dimensions3(var DamTopWidth, DamTop: RealArr);

type
   RecDimensionData   = Record
      SDTW,
      SDT: Array[1..3] of RecString;
   end;

var DimensionData: RecDimensionData;

begin
   DialY1:=2; DialY2:=25; MakePlace(9, DialY1, 76, DialY2);
   Dialog:=New(PDialog,Init(R,'Change Dimensions of Dams to Build'));
   Tempor_Interr_Calc;
   ExitDialSeries:=False;
   with Dialog^ do
   begin
      MakePlace(2, 2, 63, 3);
      Insert(New(PgStaticText, Init(R,
      'Enter the dam top width and dam top level.', DefaultOpts)));

      MakePlace(27,6,35,7);
      Insert(New(PgStaticText, Init(R, ' DAM 1', DefaultOpts)));
      MakePlace(37,6,45,7);
      Insert(New(PgStaticText, Init(R, ' DAM 2', DefaultOpts)));
      MakePlace(47,6,55,7);
      Insert(New(PgStaticText, Init(R, ' DAM 3', DefaultOpts)));

      MakePlace(27,8,35,9);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(2,8,27,9);
      Insert(New(PgStaticText, Init(R, 'Top Width of Dam: (m)', DefaultOpts)));
      MakePlace(37,8,45,9);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(47,8,55,9);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);

      MakePlace(2,10,27,11);
      Insert(New(PgStaticText, Init(R, 'Dam Top Level (m):', DefaultOpts)));
      MakePlace(27,10,35,11);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(37,10,45,11);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(47,10,55,11);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);

      MakePlace(44,DialY2-5,54,DialY2-3);
      Insert(New(PButton, Init(R, '~C~ancel',cmCancel, bfDefault)));
      MakePlace(55,DialY2-5,65,DialY2-3);
      Insert(New(PButton, Init(R, '~O~K',cmOK, bfDefault)));
   end;

   with DimensionData do
   for Counter:=1 to 3 do begin
	str(DamTopWidth[Counter]:6:2,  SDTW[Counter]);
	str(DamTop[Counter]:6:2,  SDT[Counter]);
   end;

   Dialog^.SetData(DimensionData);

   Control:=DeskTop^.ExecView(Dialog);
   if Control<>cmCancel
   then begin
      Dialog^.GetData(DimensionData);
      with DimensionData do for Counter:=1 to 3 do
      begin
	   val(SDTW[Counter],  DamTopWidth[Counter], control);
	   val(SDT[Counter],   DamTop[Counter],  control);
      end;
   end;
   if Control=cmCancel then ExitDialSeries:=True;
   Tempor_Resume_Calc;
end;

procedure Dial_Methods1(var WayOfConstruction: IntArr);     {Head and Side angle for 1 gap}
type
   RecmethodData   = Record
      SMAN: Integer;
   end;

var MethodData: RecmethodData;

begin
   DialY1:=2; DialY2:=25; MakePlace(9, DialY1, 76, DialY2);
   Dialog:=New(PDialog,Init(R,'Change Construction Methods'));
   Tempor_Interr_Calc;
   ExitDialSeries:=False;
   with Dialog^ do
   begin
      MakePlace(2, 2, 65, 3);
      Insert(New(PgStaticText, Init(R,
	 'Choose one of the possible construction methods.', DefaultOpts)));

      MakePlace(27,6,35,7);
      Insert(New(PgStaticText, Init(R, '  DAM 1', DefaultOpts)));

      MakePlace(2, 8, 30, 12);
      Insert(New(PgStaticText, Init(R,
      'Dam made by: Dump Trucks'^M+
      '                 Vessels'^M+
      '               Cable Way'^M+
      '            Sand Dumping', DefaultOpts)));

      MakePlace(30, 8, 35, 13);
      Insert(New(PRadioButtons, Init(R,
      NewSItem('',
      NewsItem('',
      NewSItem('',
      NewSItem('',
      Nil)))))));

      MakePlace(44,DialY2-5,54,DialY2-3);
      Insert(New(PButton, Init(R, '~C~ancel',cmCancel, bfDefault)));
      MakePlace(55,DialY2-5,65,DialY2-3);
      Insert(New(PButton, Init(R, '~O~K',cmOK, bfDefault)));
   end;

   with MethodData do
   begin
	SMAN:=WayOfConstruction[1];
   end;

   Dialog^.SetData(MethodData);

   Control:=DeskTop^.ExecView(Dialog);
   if Control<>cmCancel
   then begin
      Dialog^.GetData(MethodData);
      with MethodData do
      begin
	   WayOfConstruction[1]:=SMAN;
	   if WayOfConstruction[1]=csCableWay then OnceCableWay[GCT]:=cmYes;
      end;
   end;
   if Control=cmCancel then ExitDialSeries:=True;
   Tempor_Resume_Calc;
end;

procedure Dial_Methods2(var WayOfConstruction: IntArr);    {Head and Side angle for 2 gaps}

type
   RecmethodData   = Record
      SMAN: Array[1..2] of Integer;
   end;

var MethodData: RecmethodData;

begin
   DialY1:=2; DialY2:=25; MakePlace(9, DialY1, 76, DialY2);
   Dialog:=New(PDialog,Init(R,'Change Construction Methods'));
   Tempor_Interr_Calc;
   ExitDialSeries:=False;
   with Dialog^ do
   begin
      MakePlace(2, 2, 65, 3);
      Insert(New(PgStaticText, Init(R,
	 'Choose one of the possible construction methods.', DefaultOpts)));

      MakePlace(27,6,35,7);
      Insert(New(PgStaticText, Init(R, '  DAM 1', DefaultOpts)));
      MakePlace(37,6,45,7);
      Insert(New(PgStaticText, Init(R, '  DAM 2', DefaultOpts)));

      MakePlace(2, 8, 30, 12);
      Insert(New(PgStaticText, Init(R,
      'Dam made by: Dump Trucks'^M+
      '                 Vessels'^M+
      '               Cable Way'^M+
      '            Sand Dumping', DefaultOpts)));

      MakePlace(30, 8, 35, 12);
      Insert(New(PRadioButtons, Init(R,
      NewSItem('',
      NewsItem('',
      NewSItem('',
      NewSItem('',
      Nil)))))));
      MakePlace(40, 8, 45, 12);
      Insert(New(PRadioButtons, Init(R,
      NewSItem('',
      NewsItem('',
      NewSItem('',
      NewSItem('',
      Nil)))))));

      MakePlace(44,DialY2-5,54,DialY2-3);
      Insert(New(PButton, Init(R, '~C~ancel',cmCancel, bfDefault)));
      MakePlace(55,DialY2-5,65,DialY2-3);
      Insert(New(PButton, Init(R, '~O~K',cmOK, bfDefault)));
   end;

   with MethodData do
   for Counter:=1 to 2 do begin
	SMAN[Counter]:=WayOfConstruction[Counter];
	if WayOfConstruction[Counter]=csCableWay then OnceCableWay[Counter]:=cmYes;
   end;

   Dialog^.SetData(MethodData);

   Control:=DeskTop^.ExecView(Dialog);
   if Control<>cmCancel
   then begin
      Dialog^.GetData(MethodData);
      with MethodData do for Counter:=1 to 2 do
      begin
	   WayOfConstruction[Counter]:=SMAN[Counter];
      end;
   end
   else ExitDialSeries:=True;
   Tempor_Resume_Calc;
end;

procedure Dial_Methods3(var WayOfConstruction: IntArr);    {Head and Side angle for 3 gaps}
type
   RecmethodData   = Record
      SMAN: Array[1..3] of Integer;
   end;

var MethodData: RecmethodData;

begin
   DialY1:=2; DialY2:=25; MakePlace(9, DialY1, 76, DialY2);
   Dialog:=New(PDialog,Init(R,'Change Methods of Dams to Build'));
   Tempor_Interr_Calc;
   ExitDialSeries:=False;
   with Dialog^ do
   begin
      MakePlace(2, 2, 65, 3);
      Insert(New(PgStaticText, Init(R,
	 'Choose one of the possible construction methods.', DefaultOpts)));

      MakePlace(27,6,35,7);
      Insert(New(PgStaticText, Init(R, '  DAM 1', DefaultOpts)));
      MakePlace(37,6,45,7);
      Insert(New(PgStaticText, Init(R, '  DAM 2', DefaultOpts)));
      MakePlace(47,6,55,7);
      Insert(New(PgStaticText, Init(R, '  DAM 3', DefaultOpts)));

      MakePlace(2, 8, 30, 12);
      Insert(New(PgStaticText, Init(R,
      'Dam made by: Dump Trucks'^M+
      '                 Vessels'^M+
      '               Cable Way'^M+
      '            Sand Dumping', DefaultOpts)));

      MakePlace(30, 8, 35, 12);
      Insert(New(PRadioButtons, Init(R,
      NewSItem('',
      NewsItem('',
      NewSItem('',
      NewSItem('',
      Nil)))))));
      MakePlace(40, 8, 45, 12);
      Insert(New(PRadioButtons, Init(R,
      NewSItem('',
      NewsItem('',
      NewSItem('',
      NewSItem('',
      Nil)))))));
      MakePlace(50, 8, 55, 12);
      Insert(New(PRadioButtons, Init(R,
      NewSItem('',
      NewsItem('',
      NewSItem('',
      NewSItem('',
      Nil)))))));

      MakePlace(44,DialY2-5,54,DialY2-3);
      Insert(New(PButton, Init(R, '~C~ancel',cmCancel, bfDefault)));
      MakePlace(55,DialY2-5,65,DialY2-3);
      Insert(New(PButton, Init(R, '~O~K',cmOK, bfDefault)));
   end;

   with MethodData do
   for Counter:=1 to 3 do begin
	SMAN[Counter]:=WayOfConstruction[Counter];
	if WayOfConstruction[Counter]=csCableWay then OnceCableWay[Counter]:=cmYes;
   end;

   Dialog^.SetData(MethodData);

   Control:=DeskTop^.ExecView(Dialog);
   if Control<>cmCancel
   then begin
      Dialog^.GetData(MethodData);
      with MethodData do for Counter:=1 to 3 do
      begin
	   WayOfConstruction[Counter]:=SMAN[Counter];
      end;
   end
   else ExitDialSeries:=True;
   Tempor_Resume_Calc;
end;

procedure Dial_Angles1(var DSS, DSH: RealArr);

type
   RecAngleData   = Record
      SDSH,
      SDSS: RecString;
   end;

var AngleData: RecAngleData;

begin
   DialY1:=2; DialY2:=25; MakePlace(9, DialY1, 76, DialY2);
   Dialog:=New(PDialog,Init(R,'Change Angles of Dams to Build'));
   Tempor_Interr_Calc;
   ExitDialSeries:=False;
   with Dialog^ do
   begin
      MakePlace(2, 2, 65, 3);
      Insert(New(PgStaticText, Init(R,
	 'Enter the head angle and side angle of the dam, in degrees.', DefaultOpts)));

      MakePlace(2,6,27,7);
      Insert(New(PgStaticText, Init(R, 'Head Slope: ('')', DefaultOpts)));
      MakePlace(27,6,35,7);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);

      MakePlace(2,8,27,9);
      Insert(New(PgStaticText, Init(R, 'Sectional Slope: ('')', DefaultOpts)));
      MakePlace(27,8,35,9);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);

      MakePlace(44,DialY2-5,54,DialY2-3);
      Insert(New(PButton, Init(R, '~C~ancel',cmCancel, bfDefault)));
      MakePlace(55,DialY2-5,65,DialY2-3);
      Insert(New(PButton, Init(R, '~O~K',cmOK, bfDefault)));
   end;

   with AngleData do
   begin
	str(DSH[1]:6:2,  SDSH);
	str(DSS[1]:6:2,  SDSS);
   end;

   Dialog^.SetData(AngleData);

   Control:=DeskTop^.ExecView(Dialog);
   if Control<>cmCancel
   then begin
      Dialog^.GetData(AngleData);
      with AngleData do
      begin
	   val(SDSH,  DSH[1],  control);
	   val(SDSS,  DSS[1],  control);
      end;
   end
   else ExitDialSeries:=True;
   Tempor_Resume_Calc;
end;

procedure Dial_Angles2(var DSS, DSH: RealArr);

type
   RecAngleData   = Record
      SDSH,
      SDSS: Array[1..2] of RecString;
   end;

var AngleData: RecAngleData;

begin
   DialY1:=2; DialY2:=25; MakePlace(9, DialY1, 76, DialY2);
   Dialog:=New(PDialog,Init(R,'Change Angles of Dams to Build'));
   Tempor_Interr_Calc;
   ExitDialSeries:=False;
   with Dialog^ do
   begin
      MakePlace(2, 2, 65, 3);
      Insert(New(PgStaticText, Init(R,
	 'Enter the head angle and side angle of the dam, in degrees.', DefaultOpts)));

      MakePlace(27,4,35,5);
      Insert(New(PgStaticText, Init(R, ' DAM 1', DefaultOpts)));
      MakePlace(37,4,45,5);
      Insert(New(PgStaticText, Init(R, ' DAM 2', DefaultOpts)));

      MakePlace(2,6,27,7);
      Insert(New(PgStaticText, Init(R, 'Sectional Slope (''):', DefaultOpts)));
      MakePlace(27,6,35,7);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(37,6,45,7);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);

      MakePlace(2,8,27,9);
      Insert(New(PgStaticText, Init(R, 'Head Slope: ('')', DefaultOpts)));
      MakePlace(27,8,35,9);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(37,8,45,9);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);

      MakePlace(44,DialY2-5,54,DialY2-3);
      Insert(New(PButton, Init(R, '~C~ancel',cmCancel, bfDefault)));
      MakePlace(55,DialY2-5,65,DialY2-3);
      Insert(New(PButton, Init(R, '~O~K',cmOK, bfDefault)));
   end;

   with AngleData do
   for Counter:=1 to 2 do begin
	str(DSH[Counter]:6:2,  SDSH[Counter]);
	str(DSS[Counter]:6:2,  SDSS[Counter]);
   end;

   Dialog^.SetData(AngleData);

   Control:=DeskTop^.ExecView(Dialog);
   if Control<>cmCancel
   then begin
      Dialog^.GetData(AngleData);
      with AngleData do for Counter:=1 to 2 do
      begin
	   val(SDSH[Counter],  DSH[Counter],  control);
	   val(SDSS[Counter],  DSS[Counter],  control);
      end;
   end
   else ExitDialSeries:=True;
   Tempor_Resume_Calc;
end;

procedure Dial_Angles3(var DSS, DSH: RealArr);

type
   RecAngleData   = Record
      SDSH,
      SDSS: Array[1..3] of RecString;
   end;

var AngleData: RecAngleData;

begin
   DialY1:=2; DialY2:=25; MakePlace(9, DialY1, 76, DialY2);
   Dialog:=New(PDialog,Init(R,'Change Angles of Dams to Build'));
   Tempor_Interr_Calc;
   ExitDialSeries:=False;
   with Dialog^ do
   begin
      MakePlace(2, 2, 65, 3);
      Insert(New(PgStaticText, Init(R,
	 'Enter the head angle and side angle of the dam, in degrees.', DefaultOpts)));

      MakePlace(27,4,35,5);
      Insert(New(PgStaticText, Init(R, ' DAM 1', DefaultOpts)));
      MakePlace(37,4,45,5);
      Insert(New(PgStaticText, Init(R, ' DAM 2', DefaultOpts)));
      MakePlace(47,4,55,5);
      Insert(New(PgStaticText, Init(R, ' DAM 3', DefaultOpts)));

      MakePlace(2,6,27,7);
      Insert(New(PgStaticText, Init(R, 'Sectional Slope: ('')', DefaultOpts)));
      MakePlace(27,6,35,7);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(37,6,45,7);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(47,6,55,7);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);

      MakePlace(2,8,27,9);
      Insert(New(PgStaticText, Init(R, 'Head Slope: ('')', DefaultOpts)));
      MakePlace(27,8,35,9);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(37,8,45,9);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(47,8,55,9);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);

      MakePlace(44,DialY2-5,54,DialY2-3);
      Insert(New(PButton, Init(R, '~C~ancel',cmCancel, bfDefault)));
      MakePlace(55,DialY2-5,65,DialY2-3);
      Insert(New(PButton, Init(R, '~O~K',cmOK, bfDefault)));
   end;

   with AngleData do
   for Counter:=1 to 3 do begin
	str(DSH[Counter]:6:2,  SDSH[Counter]);
	str(DSS[Counter]:6:2,  SDSS[Counter]);
   end;

   Dialog^.SetData(AngleData);

   Control:=DeskTop^.ExecView(Dialog);
   if Control<>cmCancel
   then begin
      Dialog^.GetData(AngleData);
      with AngleData do for Counter:=1 to 3 do
      begin
	   val(SDSH[Counter],  DSH[Counter],  control);
	   val(SDSS[Counter],  DSS[Counter],  control);
      end;
   end
   else ExitDialSeries:=True;
   Tempor_Resume_Calc;
end;

procedure Dial_GradualClose1(var GradualLeft, GradualRight, GradualUp, UpMaxLevel, DamD50: RealArr);

type
   RecActivitiesData   = Record
      SGL,
      SGR,
      SGU,
      SVI,
      SUM,
      SDD50: RecString;
   end;

var ActivitiesData: RecActivitiesData;

begin
   SetDialogGradual;
   DialY1:=2; DialY2:=25; MakePlace(9, DialY1, 76, DialY2);
   Dialog:=New(PDialog,Init(R,'Information on Gradual Closure'));
   Tempor_Interr_Calc;
   ExitDialSeries:=False;
   with Dialog^ do
   begin
      MakePlace(27,2,35,3);
      Insert(New(PgStaticText, Init(R, ' DAM 1', DefaultOpts)));

      MakePlace(27,4,27+HorOn[1],5);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(1,4,27,5);
      Insert(New(PgStaticText, Init(R, 'Horizontal Left  (m3/h): ', DefaultOpts)));

      MakePlace(27,6,27+HorOn[1],7);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(1,6,27,7);
      Insert(New(PgStaticText, Init(R, 'Horizontal Right (m3/h):', DefaultOpts)));

      MakePlace(27,8,27+VerOn[1],9);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(1,8,27,9);
      Insert(New(PgStaticText, Init(R, 'Vertical (m3/h):', DefaultOpts)));

      MakePlace(27,10,27+VerOn[1],11);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(1,10,27,11);
      Insert(New(PgStaticText, Init(R, 'Vertical Inaccuracy (m):', DefaultOpts)));

      MakePlace(27,12,35,13);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(1,12,27,13);
      Insert(New(PgStaticText, Init(R, 'Interrupt Level (m):', DefaultOpts)));

      MakePlace(27,14,35,15);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(1,14,27,15);
      Insert(New(PgStaticText, Init(R, 'D50 (mm):', DefaultOpts)));

      MakePlace(44,DialY2-5,54,DialY2-3);
      Insert(New(PButton, Init(R, '~C~ancel',cmCancel, bfDefault)));
      MakePlace(55,DialY2-5,65,DialY2-3);
      Insert(New(PButton, Init(R, '~O~K',cmOK, bfDefault)));
   end;

   with ActivitiesData do
   for Counter:=1 to 1 do begin
	str(GradualLeft[Counter]:0:0,    SGL);
	str(GradualRight[Counter]:0:0,   SGR);
	str(GradualUp[Counter]:0:0,      SGU);
	str(VerticalInacc[Counter]:0:0,  SVI);
	str(UpMaxLevel[Counter]:0:1,     SUM);
	str(DamD50[Counter]:0:2, SDD50);
   end;

   Dialog^.SetData(ActivitiesData);

   repeat

   Control:=DeskTop^.ExecView(Dialog);
   if Control<>cmCancel
   then begin
      Dialog^.GetData(ActivitiesData);
      with ActivitiesData do for Counter:=1 to 1 do
      begin
	   val(SGL,   GradualLeft[Counter],     control);
	   val(SGR,   GradualRight[Counter],    control);
	   val(SGU,   GradualUp[Counter],       control);
	   val(SVI,   VerticalInAcc[Counter],   control);
	   val(SUM,   UpMaxLevel[Counter],      control);
	   val(SDD50, DamD50[Counter],          control);
      end;
      Warning:=False;
      if (DamD50[1]<=0) then
      begin
      Warning:=True;
      MessageBox('The material size should be'#13+
		 'bigger than zero.'+U+#13,
		    nil, mfWarning or mfOKButton);
      end;
      if (VerticalinAcc[1]<MAX(0.002*DamD50[1],2))
      and ((WayOfConstruction[1]=csVessels) or
	   (WayOfConstruction[1]=csCableWay)) then
      begin
      Warning:=True;
      MessageBox('The material can''t be dumped so'#13+
		 'accurate. The inaccuracy'+#13+
		 'is 2 x D50 or two meters.',
		    nil, mfWarning or mfOKButton);
      end;
      if (OnceCableWay[1]=cmYes) and
      ((GradualLeft[1]<>0) or (GradualRight[1]<>0)) then
      begin
      {Warning:=True;
      MessageBox('When dumping horizontally after'#13+
		 'cable way dumping the dam'+#13+
		 'volumes should be re-calculated..',
		    nil, mfWarning or mfOKButton);}
      end;
   end;
   until (Warning=False) or (Control=cmCancel);
   If Control=cmCancel then ExitDialSeries:=True;
   Tempor_Resume_Calc;
end;


procedure Dial_GradualClose2(var GradualLeft, GradualRight, GradualUp, UpMaxLevel, DamD50: RealArr);

type
   RecActivitiesData   = Record
      SGL,
      SGR,
      SGU,
      SVI,
      SUM,
      SDD50: Array[1..2] of RecString;
   end;

var ActivitiesData: RecActivitiesData;

begin
   SetDialogGradual;
   DialY1:=2; DialY2:=25; MakePlace(9, DialY1, 76, DialY2);
   Dialog:=New(PDialog,Init(R,'Information on Gradual Closure'));
   Tempor_Interr_Calc;
   ExitDialSeries:=False;
   with Dialog^ do
   begin

      MakePlace(27,2,35,3);
      Insert(New(PgStaticText, Init(R, ' DAM 1', DefaultOpts)));
      MakePlace(37,2,45,3);
      Insert(New(PgStaticText, Init(R, ' DAM 2', DefaultOpts)));

      MakePlace(1,4,27,5);
      Insert(New(PgStaticText, Init(R, 'Horizontal Left (m3/h): ', DefaultOpts)));
      MakePlace(27,4,27+HorOn[1],5);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(37,4,37+HorOn[2],5);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);

      MakePlace(1,6,27,7);
      Insert(New(PgStaticText, Init(R, 'Horizontal Right (m3/h):', DefaultOpts)));
      MakePlace(27,6,27+HorOn[1],7);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(37,6,37+HorOn[2],7);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);

      MakePlace(1,8,27,9);
      Insert(New(PgStaticText, Init(R, 'Vertical (m3/h):', DefaultOpts)));
      MakePlace(27,8,27+VerOn[1],9);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(37,8,37+VerOn[2],9);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);

      MakePlace(1,10,27,11);
      Insert(New(PgStaticText, Init(R, 'Vertical Inaccuracy (m):', DefaultOpts)));
      MakePlace(27,10,27+VerOn[1],11);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(37,10,37+VerOn[2],11);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);

      MakePlace(1,12,27,13);
      Insert(New(PgStaticText, Init(R, 'Interrupt level (m):', DefaultOpts)));
      MakePlace(27,12,35,13);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(37,12,45,13);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);

      MakePlace(1,14,27,15);
      Insert(New(PgStaticText, Init(R, 'D50 (mm):', DefaultOpts)));
      MakePlace(27,14,35,15);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(37,14,45,15);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);

      MakePlace(44,DialY2-5,54,DialY2-3);
      Insert(New(PButton, Init(R, '~C~ancel',cmCancel, bfDefault)));
      MakePlace(55,DialY2-5,65,DialY2-3);
      Insert(New(PButton, Init(R, '~O~K',cmOK, bfDefault)));
   end;

   with ActivitiesData do
   for Counter:=1 to 2 do begin
	str(GradualLeft[Counter]:0:0,   SGL[Counter]);
	str(GradualRight[Counter]:0:0,  SGR[Counter]);
	str(GradualUp[Counter]:0:0,     SGU[Counter]);
	str(VerticalInAcc[Counter]:0:1, SVI[Counter]);
	str(UpMaxLevel[Counter]:0:1,    SUM[Counter]);
	str(DamD50[Counter]:0:2,      SDD50[Counter]);
   end;

   Dialog^.SetData(ActivitiesData);

   repeat

   Control:=DeskTop^.ExecView(Dialog);
   if Control<>cmCancel
   then begin
      Dialog^.GetData(ActivitiesData);
      with ActivitiesData do for Counter:=1 to 2 do
      begin
	   val(SGL[Counter],  GradualLeft[Counter],     control);
	   val(SGR[Counter],  GradualRight[Counter],    control);
	   val(SGU[Counter],  GradualUp[Counter],       control);
	   val(SVI[Counter],  VerticalInAcc[Counter],   control);
	   val(SUM[Counter], UpMaxLevel[Counter],       control);
	   val(SDD50[Counter], DamD50[Counter],         control);
      end;
      Warning:=False;
      if (DamD50[1]<=0) or (DamD50[2]<=0) then
      begin
      Warning:=True;
      MessageBox('The material size should be'#13+
		 'bigger than zero.'+U+#13,
		    nil, mfWarning or mfOKButton);
      end;
      if ((VerticalinAcc[1]<MAX(0.002*DamD50[1],2))
      and ((WayOfConstruction[1]=csVessels)    or
	   (WayOfConstruction[1]=csCableWay))) OR
	 ((VerticalinAcc[2]<MAX(0.002*DamD50[2],2))
      and ((WayOfConstruction[2]=csVessels)     or
	   (WayOfConstruction[2]=csCableWay))) then
      begin
      Warning:=True;
      MessageBox('The material can not be dumped that'#13+
		 'accurate. The minimum inaccuracy is'+#13+
		 'two times the D50 or two meters.',
		    nil, mfWarning or mfOKButton);
      end;
      if
      (OnceCableWay[1]=cmYes) and ((GradualLeft[1]<>0) or (GradualRight[1]<>0)) or
      (OnceCableWay[2]=cmYes) and ((GradualLeft[2]<>0) or (GradualRight[2]<>0)) then
      begin
      MessageBox('When dumping horizontally after'#13+
		 'cable way dumping the dam'+#13+
		 'volumes should be re-calculated.',
		    nil, mfWarning or mfOKButton);
      end;
   end;
   until (Warning=False) or (Control=cmCancel);
   If Control=cmCancel then ExitDialSeries:=True;
   Tempor_Resume_Calc;
end;

procedure Dial_GradualClose3(var GradualLeft, GradualRight, GradualUp, UpMaxLevel, DamD50: RealArr);

type
   RecActivitiesData   = Record
      SGL,
      SGR,
      SGU,
      SVI,
      SUM,
      SDD50: Array[1..3] of RecString;
   end;

var ActivitiesData: RecActivitiesData;

begin
   SetDialogGradual;
   DialY1:=2; DialY2:=25; MakePlace(9, DialY1, 76, DialY2);
   Dialog:=New(PDialog,Init(R,'Information on Gradual Closure'));
   Tempor_Interr_Calc;
   ExitDialSeries:=False;
   with Dialog^ do
   begin
      MakePlace(27,2,35,3);
      Insert(New(PgStaticText, Init(R, ' DAM 1', DefaultOpts)));
      MakePlace(37,2,45,3);
      Insert(New(PgStaticText, Init(R, ' DAM 2', DefaultOpts)));
      MakePlace(47,2,55,3);
      Insert(New(PgStaticText, Init(R, ' DAM 3', DefaultOpts)));

      MakePlace(1,4,27,5);
      Insert(New(PgStaticText, Init(R, 'Horizontal Left (m3/h): ', DefaultOpts)));
      MakePlace(27,4,27+HorOn[1],5);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(37,4,37+HorOn[2],5);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(47,4,47+HorOn[3],5);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);

      MakePlace(1,6,27,7);
      Insert(New(PgStaticText, Init(R, 'Horizontal Right (m3/h):', DefaultOpts)));
      MakePlace(27,6,27+HorOn[1],7);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(37,6,37+HorOn[2],7);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(47,6,47+HorOn[3],7);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);

      MakePlace(1,8,27,9);
      Insert(New(PgStaticText, Init(R, 'Vertical (m3/h):', DefaultOpts)));
      MakePlace(27,8,27+VerOn[1],9);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(37,8,37+VerOn[2],9);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(47,8,47+VerOn[3],9);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);

      MakePlace(1,10,27,11);
      Insert(New(PgStaticText, Init(R, 'Vertical Inaccuracy (m):', DefaultOpts)));
      MakePlace(27,10,27+VerOn[1],11);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(37,10,37+VerOn[2],11);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(47,10,47+VerOn[3],11);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);

      MakePlace(1,12,27,13);
      Insert(New(PgStaticText, Init(R, 'Interrupt level (m):', DefaultOpts)));
      MakePlace(27,12,35,13);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(37,12,45,13);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(47,12,55,13);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);

      MakePlace(1,14,27,15);
      Insert(New(PgStaticText, Init(R, 'D50 (mm):', DefaultOpts)));
      MakePlace(27,14,35,15);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(37,14,45,15);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(47,14,55,15);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);

      MakePlace(44,DialY2-5,54,DialY2-3);
      Insert(New(PButton, Init(R, '~C~ancel',cmCancel, bfDefault)));
      MakePlace(55,DialY2-5,65,DialY2-3);
      Insert(New(PButton, Init(R, '~O~K',cmOK, bfDefault)));
   end;

   with ActivitiesData do
   for Counter:=1 to 3 do begin
	str(GradualLeft[Counter]:0:0,   SGL[Counter]);
	str(GradualRight[Counter]:0:0,  SGR[Counter]);
	str(GradualUp[Counter]:0:0,     SGU[Counter]);
	str(VerticalInAcc[Counter]:0:1, SVI[Counter]);
	str(UpMaxLevel[Counter]:0:1,    SUM[Counter]);
	str(DamD50[Counter]:0:2,   SDD50[Counter]);
   end;

   Dialog^.SetData(ActivitiesData);

   repeat

   Control:=DeskTop^.ExecView(Dialog);
   if Control<>cmCancel
   then begin
      Dialog^.GetData(ActivitiesData);
      with ActivitiesData do for Counter:=1 to 3 do
      begin
	   val(SGL[Counter],   GradualLeft[Counter],     control);
	   val(SGR[Counter],   GradualRight[Counter],    control);
	   val(SGU[Counter],   GradualUp[Counter],       control);
	   val(SVI[Counter],   VerticalInAcc[Counter],   control);
	   val(SUM[Counter],   UpMaxLevel[Counter],      control);
	   val(SDD50[Counter], DamD50[Counter],          control);
      end;
      Warning:=False;
      if (DamD50[1]<=0) or (DamD50[2]<=0) or (DamD50[3]<=0) then
      begin
      Warning:=True;
      MessageBox('The material size should be'#13+
		 'bigger than zero.'+U+#13,
		    nil, mfWarning or mfOKButton);
      end;
      if ((VerticalinAcc[1]<MAX(0.002*DamD50[1],2)) and
	  ((WayOfConstruction[1]=csVessels)    or
	   (WayOfConstruction[1]=csCableWay))) OR
	 ((VerticalinAcc[2]<MAX(0.002*DamD50[2],2)) and
	  ((WayOfConstruction[2]=csVessels)    or
	   (WayOfConstruction[2]=csCableWay))) OR
	 ((VerticalinAcc[3]<MAX(0.002*DamD50[3],2)) and
	  ((WayOfConstruction[3]=csVessels)    or
	   (WayOfConstruction[3]=csCableWay))) then
      begin
      Warning:=True;
      MessageBox('The material can not be dumped that'#13+
		 'accurate. The minimum inaccuracy is'+#13+
		 'two times the D50 or two meters.',
		    nil, mfWarning or mfOKButton);
      end;
      if
      (OnceCableWay[1]=cmYes) and ((GradualLeft[1]<>0) or (GradualRight[1]<>0)) or
      (OnceCableWay[2]=cmYes) and ((GradualLeft[2]<>0) or (GradualRight[2]<>0)) or
      (OnceCableWay[3]=cmYes) and ((GradualLeft[3]<>0) or (GradualRight[3]<>0)) then
      begin
      MessageBox('When dumping horizontally after'#13+
		 'cable way dumping the dam'+#13+
		 'volumes should be re-calculated.',
		    nil, mfWarning or mfOKButton);
      end;
   end;
   Until (Warning=False) or (Control=cmCancel);
   If Control=cmCancel then ExitDialSeries:=True;
   Tempor_Resume_Calc;
end;

procedure Dial_Basin(var KomDepth, KomSur: RealArr);

type
   RecBasinData   = Record
      S10,S11,S12,S13,S14,
      S15,S16,S17,S18,S19: RecString;
   end;

var BasinData: RecBasinData;

begin

   DialY1:=2; DialY2:=25; MakePlace(9, DialY1, 76, DialY2);
   Dialog:=New(PDialog,Init(R,'Basin Surface at Different Levels'));
   Tempor_Interr_Calc;
   ExitDialSeries:=False;
   with Dialog^ do
   begin
      MakePlace(2, 2, 73, 4);
      Insert(New(PgStaticText, Init(R,
	 'The basin storage surface is a function of the basin level.'^M+
	 'Of this function, five data points must be entered here.',
	  DefaultOpts)));

      {Depths}
      MakePlace(27,6,35,7);
      Insert(New(PgStaticText, Init(R, 'Level (m)', DefaultOpts)));
      MakePlace(27,8,35,9);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(4,8,27,9);
      Insert(New(PgStaticText, Init(R, 'Data 1: ', DefaultOpts)));

      MakePlace(27,10,35,11);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(4,10,27,11);
      Insert(New(PgStaticText, Init(R, 'Data 2:', DefaultOpts)));

      MakePlace(27,12,35,13);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(4,12,27,13);
      Insert(New(PgStaticText, Init(R, 'Data 3:', DefaultOpts)));

      MakePlace(27,14,35,15);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(4,14,27,15);
      Insert(New(PgStaticText, Init(R, 'Data 4:', DefaultOpts)));

      MakePlace(27,16,35,17);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(4,16,27,17);
      Insert(New(PgStaticText, Init(R, 'Data 5:', DefaultOpts)));

      {Surfaces}
      MakePlace(40,6,53,7);
      Insert(New(PgStaticText, Init(R, 'Surface (m)', DefaultOpts)));
      MakePlace(40,8,53,9);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(37,8,40,9);
      Insert(New(PgStaticText, Init(R, '', DefaultOpts)));

      MakePlace(40,10,53,11);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(37,10,40,11);
      Insert(New(PgStaticText, Init(R, '', DefaultOpts)));

      MakePlace(40,12,53,13);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(37,12,40,13);
      Insert(New(PgStaticText, Init(R, '', DefaultOpts)));

      MakePlace(40,14,53,15);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(37,14,40,15);
      Insert(New(PgStaticText, Init(R, '', DefaultOpts)));

      MakePlace(40,16,53,17);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(37,16,40,17);
      Insert(New(PgStaticText, Init(R, '', DefaultOpts)));

      MakePlace(44,DialY2-5,54,DialY2-3);
      Insert(New(PButton, Init(R, '~C~ancel',cmCancel, bfDefault)));
      MakePlace(55,DialY2-5,65,DialY2-3);
      Insert(New(PButton, Init(R, '~O~K',cmOK, bfDefault)));
   end;

   with BasinData do
   begin
      str(KomDepth[1]:0:2,S10);
      str(KomDepth[2]:0:2,S11);
      str(KomDepth[3]:0:2,S12);
      str(KomDepth[4]:0:2,S13);
      str(KomDepth[5]:0:2,S14);
      str(  KomSur[1]:0:0,S15);
      str(  KomSur[2]:0:0,S16);
      str(  KomSur[3]:0:0,S17);
      str(  KomSur[4]:0:0,S18);
      str(  KomSur[5]:0:0,S19);
   end;

   repeat
   Warning:=False;

   Dialog^.SetData(BasinData);

   Control:=DeskTop^.ExecView(Dialog);
   if Control<>cmCancel
   then begin
      Dialog^.GetData(BasinData);
      with BasinData do
      begin
	 val(S10,KomDepth[1],control);
	 val(S11,KomDepth[2],control);
	 val(S12,KomDepth[3],control);
	 val(S13,KomDepth[4],control);
	 val(S14,KomDepth[5],control);
	 val(S15,KomSur[1],control);
	 val(S16,KomSur[2],control);
	 val(S17,KomSur[3],control);
	 val(S18,KomSur[4],control);
	 val(S19,KomSur[5],control);
      end;
      if (KomSur[1]>KomSur[2]) or
	 (KomSur[2]>KomSur[2]) or
	 (KomSur[3]>KomSur[4]) or
	 (KomSur[4]>KomSur[5]) then
	 begin
	 Warning:=True;
	 MessageBox('The input is not correct.'#13+
		    'The surface values should be'+U+#13+
		    'in successive order!'#13,
		    nil, mfWarning or mfOKButton);
	 end;
      if (KomSur[1]<500000) or
	 (KomSur[2]<500000) or
	 (KomSur[3]<500000) or
	 (KomSur[4]<500000) or
	 (KomSur[5]<500000) then
	 begin
	 Warning:=True;
	 MessageBox('The basin is too small.'#13+#13+
		    'Please adapt the values.'#13,
		    nil, mfWarning or mfOKButton);
	 end;
      if (KomDepth[1]>KomDepth[2]) or
	 (KomDepth[2]>KomDepth[2]) or
	 (KomDepth[3]>KomDepth[4]) or
	 (KomDepth[4]>KomDepth[5]) then
	 begin
	 Warning:=True;
	 MessageBox('The input is not correct.'#13+
		    'The level values should be'+U+#13+
		    'in successive order!'#13,
		    nil, mfWarning or mfOKButton);
	 end;
      if (KomDepth[1]>-10) or (KomDepth[5]<10) then
      begin
	 Warning:=True;
	 MessageBox('The first and the last values'#13+
		    'should be defined for very low'+U+#13+
		    'and high levels.'#13,
		    nil, mfWarning or mfOKButton);

      end;
      if (KomSur[1]<=0) or
	 (KomSur[2]<=0) or
	 (KomSur[3]<=0) or
	 (KomSur[4]<=0) or
	 (KomSur[5]<=0) then
      begin
	 Warning:=True;
	 MessageBox('One of the surfaces is zero. This'#13+
		    'can never be the case!'+U+#13+
		    'Please change data.'#13,
		    nil, mfWarning or mfOKButton);
      end;
   end
   else ExitDialSeries:=True;
   until Warning=False;
   Tempor_Resume_Calc;
end;

Procedure Dial_Closure(                          {Dialog box with general}
	  var NumOfGaps:Integer;                             {information}
	  var Chezy,
	      BottomD50, TimeStep: Real);

type
   RecClosureData = record                    {Input in dialog box occurs}
     SNUM, SCH, SBD50, STS: RecString;                {in temporal record}
   end;

var ClosureData: RecClosureData;

begin
   DialY1:=2;					       {Top of Dialog Box}
   DialY2:=25;                                      {Bottom of Dialog Box}
   MakePlace(9, DialY1, 76, DialY2);                  {Reserve View Space}
   Dialog:=New(PDialog,                                {Insert Dialog Box}
   Init(R,'General Information on Closure'));           {Dialog Box Title}
   Tempor_Interr_Calc;                            {Interrupt Calculations}
   ExitDialSeries:=False;            {Reset Exit Flag for Series of boxes}
   with Dialog^ do				  {Within dialog box, do:}
   begin
      MakePlace(2, 2, 63, 4);		     {Reserve relative view space}
      Insert(New(PgStaticText, Init(R,                 {for comment text:}
	 'Enter the number of gaps and the bottom conditions.',
	  DefaultOpts)));

      MakePlace(35,5,45,6);                                {Reserve space}
      B:=New(PgInputLine, Init(R,45,DefaultOpts));       {for input field}
      Insert(B);
      MakePlace(5,5,35,6);
      Insert(New(PgStaticText, Init(R, 'Number of Gaps: ',        {Add label}
			       DefaultOpts)));

      MakePlace(35,7,45,8);                                {Reserve space}
      B:=New(PgInputLine, Init(R,45,DefaultOpts));       {for input field}
      Insert(B);
      MakePlace(5,7,35,8);
      Insert(New(PgStaticText, Init(R, 'Chezy Value:',            {Add Label}
			       DefaultOpts)));

      MakePlace(35,9,45,10);			           {Reserve Space}
      B:=New(PgInputLine, Init(R,45,DefaultOpts));       {for input field}
      Insert(B);
      MakePlace(5,9,35,10);
      Insert(New(PgStaticText, Init(R, 'D50 Bottom Material:',    {Add Label}
			       DefaultOpts)));

      MakePlace(35,11,45,12);			           {Reserve Space}
      B:=New(PgInputLine, Init(R,45,DefaultOpts));       {for input field}
      Insert(B);
      MakePlace(5,11,35,12);
      Insert(New(PgStaticText, Init(R, 'Time Step:',           {Add Label}
			       DefaultOpts)));

      MakePlace(44,DialY2-5,54,DialY2-3);	       {Reserve space for}
      Insert(New(PButton,                              {Cancel button and}
      Init(R, '~C~ancel',cmCancel, bfDefault)));              {insert it;}
      MakePlace(55,DialY2-5,65,DialY2-3);              {Reserve space for}
      Insert(New(PButton,                                  {OK button and}
      Init(R, '~O~K',cmOK, bfDefault)));                       {insert it}
   end;

   with ClosureData do
   begin
      SNUM:=N(NumOfGaps);			  {Put data to be changed}
      SCh:=N(Chezy);                                         {into record}
      SBD50:=N(BottomD50);
      STS:=N(TimeStep);
   end;
   repeat

   Dialog^.SetData(ClosureData);              {Put record into Dialog Box}

   Control:=DeskTop^.ExecView(Dialog);	      {Execute Defined Dialog Box}

   if Control<>cmCancel                                 {If not canceled,}
   then begin
      Dialog^.GetData(ClosureData);      {Put data dialog box into Record}
      with ClosureData do
      begin
	 val(SNUM,NumOfGaps,control);         {Retrieve changed variables}
	 val(SCh,Chezy,control);                             {from record}
	 val(SBD50, BottomD50, control);
	 val(STS, TimeStep, control);
      end;
      if NumOfGaps>3 then NumOfGaps:=3;
      if NumOfGaps<1 then NumOfGaps:=1;
      Warning:=False;
      if (Chezy<20) or (Chezy>90) then
      begin
	 Warning:=True;
	 MessageBox('The Chezy value must be between'#13+
		    '20 and 90! Please change.'#13,
		    nil, mfWarning or mfOKButton);
      end;
      if BottomD50<0.01 then
      begin
	 Warning:=True;
	 MessageBox('The bottom material should have a'#13+
		    'grain size bigger than 0.01 mm!'#13,
		    nil, mfWarning or mfOKButton);
      end;
   end
   else ExitDialSeries:=True;          {If canceled, in a series of boxes}
				     {the entire series should be stopped}
   until warning=false;

   if NumOfGaps=3 then Warn_SlowProcess;

   Tempor_Resume_Calc;                     {Resume calculations if needed}

   InitTimeStep:=TimeStep;
end;

Procedure Dial_VesselDraft(var VesselDraft: Real);

type
   RecVesselDraftData = record
     SVD: RecString;
   end;

var VesselDraftData: RecVesselDraftData;

begin
   DialY1:=2; DialY2:=25; MakePlace(9, DialY1, 76, DialY2);
   Dialog:=New(PDialog,Init(R,'Draft of Vessels'));
   Tempor_Interr_Calc;
   ExitDialSeries:=False;
   with Dialog^ do
   begin
      MakePlace(2, 2, 65, 5);
      Insert(New(PgStaticText, Init(R,
      'When you choose to close the gap using vessels,'^M+
      'you should enter their draft. At a certain depth,'^M+
      'construction with vessels is not possible.', DefaultOpts)));

      MakePlace(35,7,45,8);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(5,7,35,8);
      Insert(New(PgStaticText, Init(R, 'Draft of Vessels (m): ', DefaultOpts)));

      MakePlace(44,DialY2-5,54,DialY2-3);
      Insert(New(PButton, Init(R, '~C~ancel',cmCancel, bfDefault)));
      MakePlace(55,DialY2-5,65,DialY2-3);
      Insert(New(PButton, Init(R, '~O~K',cmOK, bfDefault)));
   end;

   with VesselDraftData do
   begin
      SVD:=N(VesselDraft);
   end;

   Dialog^.SetData(VesselDraftData);
   Control:=DeskTop^.ExecView(Dialog);
   if Control<>cmCancel
   then begin
      Dialog^.GetData(VesselDraftData);
      with VesselDraftData do
      begin
	 val(SVD,VesselDraft,control);
      end;
   end
   else ExitDialSeries:=True;
   Tempor_Resume_Calc;
end;

Procedure Dial_DefStorm(var StormSurge,
			    WaveDuringStorm, StormPeriod, StormChance: Real);

type
   RecStormData = record
     SS, SW, SP, SO: RecString;
   end;

var StormData: RecStormData;

begin
   DialY1:=2; DialY2:=25; MakePlace(9, DialY1, 76, DialY2);
   Dialog:=New(PDialog,Init(R,'Data on Storms to Occur'));
   Tempor_Interr_Calc;
   ExitDialSeries:=False;
   with Dialog^ do
   begin

      MakePlace(6,2,54,5);
      Insert(New(PgStaticText, Init(R,
      'Data on storms to occur will be entered'#13+
      'as a storm surge level, a storm duration'#13+
      'and a chance for the storm to occur.', DefaultOpts)));

      MakePlace(35,7,45,8);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(5,7,35,8);
      Insert(New(PgStaticText, Init(R, 'Storm Surge (m): ', DefaultOpts)));

      MakePlace(35,9,45,10);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(5,9,35,10);
      Insert(New(PgStaticText, Init(R, 'Wave Height (m): ', DefaultOpts)));

      MakePlace(35,11,45,12);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(5,11,35,12);
      Insert(New(PgStaticText, Init(R, 'Storm Duration (h): ', DefaultOpts)));

      MakePlace(35,13,45,14);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(5,13,35,14);
      Insert(New(PgStaticText, Init(R, 'Storm Probability (-): ', DefaultOpts)));

      MakePlace(44,DialY2-5,54,DialY2-3);
      Insert(New(PButton, Init(R, '~C~ancel',cmCancel, bfDefault)));
      MakePlace(55,DialY2-5,65,DialY2-3);
      Insert(New(PButton, Init(R, '~O~K',cmOK, bfDefault)));
   end;

   with StormData do
   begin
      SS:=N(StormSurge);
      SW:=N(WaveDuringStorm);
      SP:=N(StormPeriod);
      Str(StormChance:0:6, SO);
   end;

   Dialog^.SetData(StormData);
   repeat
   Warning:=False;
   Control:=DeskTop^.ExecView(Dialog);
   if Control<>cmCancel
   then begin
      Dialog^.GetData(StormData);
      with StormData do
      begin
	 val(SS,StormSurge,control);
	 val(SW,WaveDuringStorm, control);
	 val(SP,StormPeriod,control);
	 val(SO,StormChance,control);
      end;
      if (WaveDuringStorm<0) or (WaveDuringStorm>15)
      or (StormSurge<0) or (StormSurge>10) then
      begin
	 Warning:=True;
      end;
      if (Warning=True) then
	 MessageBox('The storm setup should be'#13+
		    'between 0 and 10 meters....',
		    nil, mfWarning or mfOKButton);

   end;
   until (Warning=False) or (Control=cmCancel);
   If Control=cmCancel then ExitDialSeries:=True;
   Tempor_Resume_Calc;
end;

Procedure Dial_Culvert(var CulvertSurface: Real);

type
   RecCulvertData = record
     SCS: RecString;
   end;

var CulvertData: RecCulvertData;

begin
   DialY1:=2; DialY2:=25; MakePlace(9, DialY1, 76, DialY2);
   Dialog:=New(PDialog,Init(R,'Culvert Surface'));
   Tempor_Interr_Calc;
   ExitDialSeries:=False;
   with Dialog^ do
   begin
      MakePlace(2, 2, 75, 5);
      Insert(New(PgStaticText, Init(R,
      'When a river flows into the basin, the culvert surface'^M+
      'should be big enough to spill the accumulating water.', DefaultOpts)));

      MakePlace(35,7,45,8);
      B:=New(PgInputLine, Init(R,45,DefaultOpts));
      Insert(B);
      MakePlace(5,7,35,8);
      Insert(New(PgStaticText, Init(R, 'Culvert Surface (m2): ', DefaultOpts)));

      MakePlace(44,DialY2-5,54,DialY2-3);
      Insert(New(PButton, Init(R, '~C~ancel',cmCancel, bfDefault)));
      MakePlace(55,DialY2-5,65,DialY2-3);
      Insert(New(PButton, Init(R, '~O~K',cmOK, bfDefault)));

   end;

   with CulvertData do
   begin
      SCS:=N(CulvertSurface);
   end;

   Dialog^.SetData(CulvertData);
   Control:=DeskTop^.ExecView(Dialog);
   if Control<>cmCancel
   then begin
      Dialog^.GetData(CulvertData);
      with CulvertData do
      begin
	 val(SCS,CulvertSurface,control);
      end;
   end
   else ExitDialSeries:=True;
   Tempor_Resume_Calc;
end;

procedure Warn_OnlyFullProcess;

begin
      Tempor_Interr_Calc;
      MessageBox('So soon in the construction'#13+
		 'process you cannot change the'+#13+
		 'particle size!'#13,
		    nil, mfWarning or mfOKButton);
      Tempor_Resume_Calc;
end;

procedure Warn_CableWayDamTopWidth;

begin
      Tempor_Interr_Calc;
      MessageBox('With Cable Way Construction the'#13+
		 'maximum dam top width is 10 m.',
		    nil, mfWarning or mfOKButton);
      Tempor_Resume_Calc;
end;

procedure Warn_NextDamTopWidth;

begin
      Tempor_Interr_Calc;
      MessageBox('The sill you have made has a'#13+
		 'crest width which is too small'#13+
		 'for this construction.',
		    nil, mfWarning or mfOKButton);
      Tempor_Resume_Calc;
end;

procedure Warn_BotProt;

begin
      Tempor_Interr_Calc;
      MessageBox('The bottom protection is too'#13+
		 'short for the final structure.'#13+
		 'Create a new protection.',
		    nil, mfWarning or mfOKButton);
      Tempor_Resume_Calc;
end;

procedure Warn_SlowProcess;

begin
      Tempor_Interr_Calc;
      MessageBox('You should realize, that the'#13+
		 'calculation of three gaps on'+#13+
		 'this computer can be slow.'#13,
		    nil, mfWarning or mfOKButton);
      Tempor_Resume_Calc;
end;

procedure Warn_SkippedNoChange;

begin
      Tempor_Interr_Calc;
      MessageBox('Wait with changing activities'#13+
		 'until the skipped material has'+#13+
		 'been entered the closure!'#13,
		    nil, mfWarning or mfOKButton);
      Tempor_Resume_Calc;
end;

procedure Warn_HelpOn;

begin
      Tempor_Interr_Calc;
      MessageBox('Help has been put on.'#13+
		 'You may now select any option'+#13+
		 'to obtain information.'#13,
		    nil, mfInformation or mfOKButton);
      Tempor_Resume_Calc;
end;

procedure Warn_Zipped;

begin
      Tempor_Interr_Calc;
      MessageBox('Your construction has collapsed'#13+
		 'because of inaccurate vertical '+#13+
		 'dumping of material.....'#13,
		    nil, mfWarning or mfOKButton);
      Tempor_Resume_Calc;
end;

procedure Warn_VesselDraft;             {Warning: Construction by vessels}
					   {cannot continue at this depth}
begin
      Tempor_Interr_Calc;	    {Interrupt calculations during dialog}

      MessageBox(                                   {MessageBox Procedure}
	 'construction by vessels is not'#13+
	 'possible because of their draft.'+#13+
	 'Choose another method.'#13,                       {Warning box,}
	 nil, mfWarning or mfOKButton);         {containing one OK button}

      Tempor_Resume_Calc;                {Resume interrupted calculations}
end;


procedure Warn_OnlySmallToBig;

begin
      Tempor_Interr_Calc;
      MessageBox('You are only allowed to select'#13+
		 'bigger grains than those which'+#13+
		 'have been used till now.'#13,
		    nil, mfWarning or mfOKButton);
      Tempor_Resume_Calc;
end;

procedure Warn_Protection;
begin
      Tempor_Interr_Calc;
      MessageBox('Caution: you should not try to'#13+
		 'apply this construction method'+#13+
		 'without a bottom protection!'#13,
		    nil, mfWarning or mfOKButton);
      Tempor_Resume_Calc;
end;

procedure Warn_DepthWidthFact;
begin
      Tempor_Interr_Calc;
      MessageBox('Caution: the depth of the gap'#13+
		 'is much too big in comparison'+#13+
		 'to its width!'#13,
		    nil, mfWarning or mfOKButton);
      Tempor_Resume_Calc;
end;

function Dial_ReallyChange: Boolean;

begin
   Tempor_Interr_Calc;
   Control:=(MessageBox(#3'This change will reset'#13+
	     #3'all closure activities.'#13+
	     #3'Do you want to make the change?',
			nil, mfWarning or mfCancelButton or mfOKButton));
   if Control=cmCancel then Dial_ReallyChange:=False
		       else Dial_ReallyChange:=True;
   Tempor_Resume_Calc;
end;

function Dial_EquilizeOrNot: Boolean;

begin
   Tempor_Interr_Calc;
   Control:=(MessageBox(#3'Do you want to set the'#13+
	     #3'gap dimensions to equilibrium?'#13,
			nil, mfInformation or mfYesButton or mfNoButton));
   if Control=cmNo     then Dial_EquilizeOrNot:=False
		       else Dial_EquilizeOrNot:=True;
   Tempor_Resume_Calc;
end;

procedure Warn_Material(MaterialSize, GapNo: Integer);

var ms: String[5];

begin
   Tempor_Interr_Calc;
   if MaterialSize=1 then ms:='big';
   if MaterialSize=2 then ms:='small';

   Control:=(MessageBox('In gap #'+I(GapNo)+' the material'^M+
			  'is too '+ms+' for such a'^M+
			  'construction activity...',
			nil, mfWarning or mfOKButton));
   GradualLeft[GapNo]:=0;
   GradualRight[GapNo]:=0;
   GradualUp[GapNo]:=0;
   Tempor_Resume_Calc;
end;

procedure Dial_ControleFile;

begin
   MCur.SelectStdCursor;
   Control:=(MessageBox(#3'Wrong file format...',
			nil, mfWarning or mfOKButton));
end;

procedure Warn_CaissonClosure;
begin
   Tempor_Interr_Calc;
   Control:=(MessageBox('A caisson closure isn''t possible'^M+
			'yet. It might be implemented into'^M+
			'later versions of the program.',
			nil, mfWarning or mfOKButton));
   Tempor_Resume_Calc;
end;

procedure HelpBox(S: String);

begin
  DialY1:=2; DialY2:=25; MakePlace(9, DialY1, 76, DialY2);
  Dialog:=New(PDialog,Init(R,'Help on Options'));
  Tempor_Interr_Calc; with Dialog^ do
  begin
      MakePlace(2, 2, 65, 9);
      Insert(New(PgStaticText, Init(R,
      s, DefaultOpts)));

      MakePlace(55,DialY2-5,65,DialY2-3);
      Insert(New(PButton, Init(R, '~O~K', cmOK, bfDefault)));
   end;

   Control:=DeskTop^.ExecView(Dialog);
   Tempor_Resume_Calc;

end;

procedure Dial_Intro;

var s: String;

begin
  DialY1:=2; DialY2:=25; MakePlace(9, DialY1, 76, DialY2);
  Dialog:=New(PDialog,Init(R,'CLOSIM v 1.0'));
  Tempor_Interr_Calc; with Dialog^ do
  begin
      MakePlace(2, 2, 65, 6);
      Insert(New(PgStaticText, Init(R,
      'CLOSIM v 1.0  is a simulation program for the Closure'^M+
      'of Tidal Basins. The default situation, loaded when the'^M+
      'program is started, can be edited with the options from'^M+
      'the menu at the top of the screen.'
      , DefaultOpts)));

      MakePlace(2, 7, 65, 11);
      Insert(New(PgStaticText, Init(R,
      'The calculations are started by pressing the stopwatch'^M+
      'button on the left side of the screen - with the same'^M+
      'button they can be stopped. With the option ''Log Files'''^M+
      'from the main menu, log files of the results are made.'^M
      , DefaultOpts)));

      MakePlace(2, 12, 65, 16);
      Insert(New(PgStaticText, Init(R,
      'If you want to enter a new closure situation, you can'^M+
      'choose the option ''New Closure'' from the File Menu.'^M+
      'You can also adapt the closure after starting.',
      DefaultOpts)));

      MakePlace(55,DialY2-5,65,DialY2-3);
      Insert(New(PButton, Init(R, '~O~K', cmOK, bfDefault)));
   end;

   Control:=DeskTop^.ExecView(Dialog);
   Tempor_Resume_Calc;

end;

Function Dial_Startup: Boolean;

var s: String;

begin
  DialY1:=2; DialY2:=25; MakePlace(9, DialY1, 76, DialY2);
  Dialog:=New(PDialog,Init(R,'Closure Information'));
  Tempor_Interr_Calc; with Dialog^ do
  begin
      s:=
      'You just started the process of the closure'^M+
      'of the tidal basin, named '+FTS+'.'^M+
      ''^M+
      'The closure is actually made by ';
      if WayOfConstruction[GCT]=csTrucks  then s:=s+'trucks.';
      if WayOfConstruction[GCT]=csVessels then s:=s+'vessels.';
      if WayOfConstruction[GCT]=csCableWay then s:=s+'cable way.';
      if WayOfConstruction[GCT]=csSandDump then s:=s+'dumping of sand.';

      s:=s+^M^M+
      'The closure consists of '+I(NumOfGaps)+' gaps.'^M^M;

      MakePlace(2, 2, 65, 6);
      Insert(New(PgStaticText, Init(R,
      s, DefaultOpts)));
      s:='';

      for GCT:=1 to NumOfGaps do
      s:=s+'Data Gap #'+I(GCT)+': Width '+N(GapWidth[GCT])+
      'm, Depth '+N(GapDepthAtMSL[GCT])+'m, Prot. '+
      N(StandLengthProt[GCT])+' m.'^M;

      s:=s+^M+'The tidal range is '+N(TotalAmplitude*2)+' meters;';
      s:=s+^M+'The storage surface at MSL is '+N(StorageSurface(0)/1000000)+' million m2.';

      s:=s+^M^M+'Pressing the Adapt button, you can still adapt data.';

      MakePlace(2, 7, 65, 15);
      Insert(New(PgStaticText, Init(R,
      s, DefaultOpts)));

      {MakePlace(32,DialY2-5,43,DialY2-3);
      Insert(New(PButton, Init(R, 'Cancel',cmCancel, bfDefault)));}
      MakePlace(44,DialY2-5,54,DialY2-3);
      Insert(New(PButton, Init(R, 'Adapt',cmOK, bfDefault)));
      MakePlace(55,DialY2-5,65,DialY2-3);
      Insert(New(PButton, Init(R, 'Start',cmCancel, bfDefault)));
   end;

   Control:=DeskTop^.ExecView(Dialog);

   if Control=cmOK  then Dial_StartUp:=True
		    else Dial_Startup:=False;

   {if Control=cmCancel then StartupCanceled:=True
		       else} StartupCanceled:=False;

   Tempor_Resume_Calc;

end;

procedure Dial_Logfiles(var ErosLog, VeloLog, LevelLog, GapLog: Boolean);
type
  RecLogFile = record
    EW : Word;
  end;

var LogFile: RecLogFile;
    Check: PCheckBoxes;

begin
   DialY1:=2; DialY2:=25; MakePlace(9, DialY1, 76, DialY2);
   Dialog:=New(PDialog,Init(R,'Results Stored in Log Files'));
   Tempor_Interr_Calc;
   with Dialog^ do
   begin
      MakePlace(7, 2, 63, 4);
      Insert(New(PgStaticText, Init(R,
	  'The results of the calculations can be written to file.'+^M+
	  'Choose the results to be written:', DefaultOpts)));

      MakePlace(20, 6, 50, 10);

      Check := New(PCheckBoxes, Init(R,
	  NewSItem('Erosion and Production',
	  NewSItem('Velocities in gaps',
	  NewSItem('Sea and Basin level',
	  NewSItem('Depths and Widths',
	  nil))))));
      Insert(Check);

      MakePlace(44,DialY2-5,54,DialY2-3);
      Insert(New(PButton, Init(R, '~C~ancel',cmCancel, bfDefault)));
       MakePlace(55,DialY2-5,65,DialY2-3);
      Insert(New(PButton, Init(R, '~O~K',cmOK, bfDefault)));
   end;

   With LogFile do
   begin
      EW:=0;
      if ErosLog  then EW := EW or $01;
      if VeloLog  then EW := EW or $02;
      if LevelLog then EW := EW or $04;
      if GapLog   then EW := EW or $08;
   end;

   Dialog^.SetData(LogFile);

   Control:=DeskTop^.ExecView(Dialog);
   if Control<>cmCancel
   then begin
      Dialog^.GetData(LogFile);
      ErosLog:=False;
      VeloLog:=False;
      LevelLog:=False;
      GapLog:=False;
      case LogFile.EW of
         1: ErosLog  := True;
         2: VeloLog  := True;
         3: begin VeloLog:=True;  ErosLog:=True; end;
         4: LevelLog := True;
         5: begin LevelLog:=True; ErosLog:=True; end;
         6: begin LevelLog:=True; VeloLog:=True; end;
         7: begin ErosLog:=True; VeloLog:=True; LevelLog:=True; end;
         8: GapLog   := True;
         9: begin GapLog:=True;   ErosLog:=True; end;
        10: begin GapLog:=True;   VeloLog:=True; end;
        11: begin GapLog:=True;   VeloLog:=True; ErosLog:=True; end;
        12: begin GapLog:=True;  LevelLog:=True; end;
        13: Begin GapLog:=True; LevelLog:=True; ErosLog:=True; end;
        14: Begin GapLog:=True; LevelLog:=True; VeloLog:=True; end;
        15: Begin GapLog:=True; LevelLog:=True; VeloLog:=True; ErosLog:=True; end;
      end;
   end;
   Tempor_Resume_Calc;
end;
end.

