{**********************************************************}
{            CLOSIM v 1.00  --  MENU OPTION UNIT           }
{**********************************************************}
{ Containing the menu options of the Turbo Vision Graphics }
{ User Interface for the simulation program on the Closure }
{ of Tidal Basins. Mark Middag, TUDelft, 1994.             }
{**********************************************************}

Unit GSimOpts;

Interface

uses Crt, Dos, Graph, MCursor2, GApp,
     SIMVARS, SIMCALC, SIMTOOLS, GSIMDIAL, SIMDRAWS;

var P: Boolean;

procedure Opt_Load(FTL: FileString);
procedure Opt_Save(FTS: FileString);
procedure Opt_InitProcess;
procedure Opt_AdaptAll;
procedure Opt_Start;
procedure Opt_DateTime;
procedure Opt_Basin;
procedure Opt_RiverData;
procedure Opt_Closure;
procedure Opt_DefStorm;
procedure Opt_DepthsWidths;
procedure Opt_Tide;
procedure Opt_Dimensions;
procedure Opt_Methods;
procedure Opt_VesselDraft;
procedure Opt_Angles;
procedure Opt_Protection;
procedure Opt_GradualClose;
procedure Opt_Culvert;

Implementation                             {Definition of written procedures}

Procedure Opt_InitProcess;

var x,y: Integer;
    fc: Boolean;

begin
 fc:=False;
 {begin fc:=True; Warn_FinCol; end;}
 if fc=false then
 begin
  Started:=False;                                       {Process interrupted}
  if Dial_EquilizeOrNot then
  begin
     for GCT:=1 to NumOfGaps do GapWidth[GCT]:=OrigGapWidth[GCT];
     Equilize_Profiles;                        {Restore profiles to equilibrium}
  end;
  For GCT:=1 to NumOfGaps do
  if (Construction[GCT]=Finished) then
  begin
     Construction[GCT]:=Busy;
     GapDepthAtMSL[GCT]:=OrigGapDepthAtMSL[GCT];
     GapWidth[GCT]:=OrigGapWidth[GCT];
  end;
  JobHours:=0;                     {After, restore all building activities}
  JobDayNo:=1;
  Zipped[GCT]:=False;
  NumOfKenterings:=0;
  OrigTotalGapSurface:=0;
  OrigTotalWidth:=0;
  BasinLevel:=MeanSeaLevel;
  OldBasinLevel:=MeanSeaLevel;
  StartDrawX[1]:=10;
  for GCT:=1 to NumOfGaps do
  begin
      OnceCableWay[GCT]:=cmNo;
      ProcessLeft[GCT]	     :=  NotBegun;
      ProcessRight[GCT]	     :=  NotBegun;
      OrigGapWidth[GCT]      :=  GapWidth[GCT];
      OrigGapDepthAtMSL[GCT] :=  GapDepthAtMSL[GCT];
      OrigGapSurface[GCT]    :=  abs(OrigGapWidth[GCT]*OrigGapDepthAtMSL[GCT]);
      GapSurface[GCT]        :=  OrigGapSurface[GCT];
      OrigTotalGapSurface    :=  OrigTotalGapSurface+OrigGapSurface[GCT];
      OrigTotalWidth         :=  OrigTotalWidth+GapWidth[GCT];
      DamYL[GCT]             :=  OrigGapDepthAtMSL[GCT];
      NumOfSnaps[GCT]        :=  T(Min(GapWidth[GCT]/15,39)+1);
      if NumOfSnaps[GCT]<>0 then SnapWidth[GCT]         :=  GapWidth[GCT]/NumOfSnaps[GCT];
      DamYR[GCT]             :=  OrigGapDepthAtMSL[GCT];
      YDR[GCT]               :=  OrigGapDepthAtMSL[GCT];       {Sill to zero}
      XDRL[GCT]              :=  0;                        {Toes to extremes}
      XDRR[GCT]              :=  OrigGapWidth[GCT];
      DumpedLeft[GCT]        :=  0;                      {No material dumped}
      DumpedRight[GCT]       :=  0;
      DumpedUp[GCT]          :=  0;
      UpMaxLevel[GCT]        :=  100;
      ErodedLeft[GCT]        :=  0;
      ErodedRight[GCT]       :=  0;
      ErodedUp[GCT]          :=  0;
      TotalEroded[GCT]       :=  0;                      {No material eroded}
      ActualVolume[GCT]      :=  0;
      TotalDumped[GCT]	     :=  0;
      ProcessLeft[GCT]       :=  Start;       {Processes left in start phase}
      ProcessRight[GCT]      :=  Start;
      Construction[GCT]      :=  Busy;
      MaxInHole[GCT]         :=  0;
      MaxOutHole[GCT]        :=  0;
      MaxInHolePlace[GCT]    :=  0;
      MaxOutHolePlace[GCT]   :=  0;
      GapMu[GCT]             :=  1;
      SkippedVolumeLeft[GCT] :=  0;
      SkippedVolumeRight[GCT]:=  0;
      for SC:=0 to NumOfSnaps[GCT] do
	for Counter:=1 to 20 do
	begin
	   InProtY[GCT, SC, Counter]:=0;
	   OutProtY[GCT, SC, Counter]:=0;
	end;
      StandLengthProt[GCT]:=ProtSection[GCT]*40;
      DamHeight[GCT]:=DamTop[GCT]-OrigGapDepthAtMSL[GCT];
      for SC:=0 to NumOfSnaps[GCT] do
      begin
	 for Counter:=0 to 20 do InProtY[GCT,SC,Counter]:=0;
	 for Counter:=0 to 20 do OutProtY[GCT,SC,Counter]:=0;
	 LastProtIn[GCT, SC]   := 20;
	 LastProtOut[GCT, SC]  := 20;
	 InHoleScour[GCT, SC]  := 0;              {Restore Scour Processes}
	 InHoleDepth[GCT, SC]  := 0;
	 OutHoleScour[GCT, SC] := 0;
	 OutHoleDepth[GCT, SC] := 0;
      end;
  end;
  TotalGapSurface:=OrigTotalGapSurface;

  for GCT:=1 to NumOfGaps do if GCT<>1 then
    StartDrawX[GCT]:=StartDrawX[GCT-1]+10+GapWidth[GCT-1]*WidthFact;

  TidePeriod[1]:=PeriodM2;
  TidePeriod[2]:=PeriodS2;
  TidePeriod[3]:=PeriodK1;
  TidePeriod[4]:=PeriodO1;

  DetermineMaxima;

  DataChanged:=False;

  Zipped[GCT]:=False;

  ProcessInited:=True;

  CalculateRequiredVolume(OrigGapWidth);

  {NoActivities}

 end;
end;

Procedure Opt_IntGaps;
begin
   for GCT:=1 to 3 do
   begin
      begin
      WayOfConstruction[GCT]:=csTrucks;
      WeirSituation[GCT]:=InComplete;
      Construction[GCT]:=Busy;
      OnceCableWay[GCT]:=cmNo;
      OrigGapWidth[GCT]:=300;
      GapWidth[GCT]:=300;
      OrigGapDepthAtMSL[GCT]:=-10;
      OrigGapSurface[GCT]:=3000;
      GapFlow[GCT]:=0;
      Velocity[GCT]:=0;
      GapMu[GCT]:=0;
      DumpedLeft[GCT]:=0;
      DumpedRight[GCT]:=0;
      DumpedUp[GCT]:=0;
      ProcessLeft[GCT]:=Start;
      ProcessRight[GCT]:=Start;
      ActualVolume[GCT]:=0;
      XDRL[GCT]:=000;
      XDRR[GCT]:=000;
      YDR[GCT]:=-10;
      DamYL[GCT]:=000;
      DamYR[GCT]:=000;
      GapDepthAtMSL[GCT]:=-10;
      DamTopWidth[GCT]:=25;
      DamTop[GCT]:=5;
      DamHeight[GCT]:=0;
      DSH[GCT]:=0.3;
      DSS[GCT]:=0.3;
      DamD50[GCT]:=100;
      GradualLeft[GCT]:=0;
      GradualUp[GCT]:=0;
      UpMaxLevel[GCT]:=100;
      VerticalInAcc[GCT]:=2;
      GradualRight[GCT]:=0;
      StartDrawX[GCT]:=0;
      StandLengthProt[GCT]:=600;
      ProtSection[GCT]:=30;
      SkippedVolumeLeft[GCT]:=0;
      SkippedVolumeRight[GCT]:=0;
      SnapWidth[GCT]:=25;
      MaxOutHole[GCT]:=0;
      MaxInHole[GCT]:=0;
      MaxInHolePlace[GCT]:=0;
      MaxOutHolePlace[GCT]:=0;
      NumOfSnaps[GCT]:=24;
      GapMu[GCT]:=1;
      for SC:=1 to NumOfSnaps[GCT] do
      begin
	 InHoleScour[GCT, SC]:=0;
	 InHoleDepth[GCT, SC]:=0;
	 oInHoleDepth[GCT, SC]:=0;
	 OutHoleScour[GCT, SC]:=0;
	 OutHoleDepth[GCT, SC]:=0;
	 oOutHoleDepth[GCT, SC]:=0;
	 LastProtIn[GCT, SC]:=0;
	 LastProtOut[GCT, SC]:=0;
	 AUUC34[GCT, SC]:=0;
	 for Counter:=1 to 20 do
	 begin
	    InProtY[GCT, SC, Counter]:=0;
	    OutProtY[GCT, SC, Counter]:=0;
	 end;
     end;
   end;
   end;
end;


Procedure Opt_Load(FTL: FileString);

var  InCh: Text;
     ControleString: String[10];

begin
   MCur.SelectHourGlass;
   MessageBar^.ShowText('Now Loading File '+FTL);
   Opt_IntGaps;
   RememProfLev:=False;
   Assign(InCh, FTL); reset(InCh);
   ReadLn(InCh, ControleString);
   if ControleString='CTBFILE' then
   begin
   ReadLn(InCh, BasinYear);
   ReadLn(InCh, BasinMonth);
   ReadLn(InCh, BasinDay);
   ReadLn(InCh, BasinHour);
   ReadLn(InCh, BasinMinute);
   ReadLn(InCh, JobDayNo);
   ReadLn(InCh, YearDay);
   ReadLn(InCh, DayS);
   ReadLn(InCh, JobHours);
   ReadLn(InCh, RiverFlow);
   ReadLn(InCh, CulvertSurface);
   ReadLn(InCh, Chezy);
   ReadLn(InCh, BottomD50);
   ReadLn(InCh, MeanSeaLevel);
   ReadLn(InCh, ActSeaLevel);
   ReadLn(InCh, OSeal);
   ReadLn(InCh, OldBasinLevel);
   ReadLn(InCh, BasinLevel);
   ReadLn(InCh, TotalFlow);
   ReadLn(InCh, LevelFactY);
   ReadLn(InCh, LevelDrX);
   ReadLn(InCh, NumOfKenterings);
   ReadLn(InCh, StormSurge);
   ReadLn(InCh, StormPeriod);
   ReadLn(InCh, StormChance);
   ReadLn(InCh, VesselDraft);
   for Counter:=1 to 4 do
   begin
      ReadLn(InCh, TideAmp[Counter]);
      ReadLn(InCh, TidePeriod[Counter]);
      ReadLn(InCh, TidePhase0[Counter]);
   end;
   ReadLn(InCh, TotalAmplitude);
   ReadLn(InCh, EquiTotalGapSurface);
   ReadLn(InCh, OrigMaxHeight);
   ReadLn(InCh, OrigTotalWidth);
   ReadLn(InCh, WidthFact);
   ReadLn(InCh, FlowDirection);
   ReadLn(InCh, OldFlowDirection);
   for Counter:=1 to 5 do
   begin
      ReadLn(InCh,KomDepth[Counter]);
      ReadLn(InCh,KomSur[Counter]);
   end;
   ReadLn(InCh, NumOfGaps);
   for GCT:=1 to NumOfGaps do
   begin
      ReadLn(InCh, WayOfConstruction[GCT]);
      ReadLn(InCh, WeirSituation[GCT]);
      ReadLn(InCh, Construction[GCT]);
      ReadLn(InCh, OnceCableWay[GCT]);
      ReadLn(InCh, OrigGapWidth[GCT]);
      ReadLn(InCh, GapWidth[GCT]);
      ReadLn(InCh, OrigGapDepthAtMSL[GCT]);
      ReadLn(InCh, OrigGapSurface[GCT]);
      ReadLn(InCh, GapFlow[GCT]);
      ReadLn(InCh, Velocity[GCT]);
      ReadLn(InCh, GapMu[GCT]);
      ReadLn(InCh, DumpedLeft[GCT]);
      ReadLn(InCh, DumpedRight[GCT]);
      ReadLn(InCh, DumpedUp[GCT]);
      ReadLn(InCh, ProcessLeft[GCT]);
      ReadLn(InCh, ProcessRight[GCT]);
      ReadLn(InCh, ActualVolume[GCT]);
      ReadLn(InCh, XDRL[GCT]);
      ReadLn(InCh, XDRR[GCT]);
      ReadLn(InCh, YDR[GCT]);
      ReadLn(InCh, DamYL[GCT]);
      ReadLn(InCh, DamYR[GCT]);
      ReadLn(InCh, GapDepthAtMSL[GCT]);
      ReadLn(InCh, DamTopWidth[GCT]);
      ReadLn(InCh, DamTop[GCT]);
      ReadLn(InCh, RequiredVolume[GCT]);
      ReadLn(InCh, DamHeight[GCT]);
      ReadLn(InCh, DSH[GCT]);
      ReadLn(InCh, DSS[GCT]);
      ReadLn(InCh, DamD50[GCT]);
      ReadLn(InCh, GradualLeft[GCT]);
      ReadLn(InCh, GradualUp[GCT]);
      ReadLn(InCh, UpMaxLevel[GCT]);
      ReadLn(InCh, VerticalInAcc[GCT]);
      ReadLn(InCh, GradualRight[GCT]);
      ReadLn(InCh, StartDrawX[GCT]);
      ReadLn(InCh, StandLengthProt[GCT]);
      ReadLn(InCh, ProtSection[GCT]);
      ReadLn(InCh, ProtQuality[GCT]);
      ReadLn(InCh, SkippedVolumeLeft[GCT]);
      ReadLn(InCh, SkippedVolumeRight[GCT]);
      ReadLn(InCh, SnapWidth[GCT]);
      ReadLn(InCh, MaxOutHole[GCT]);
      ReadLn(InCh, MaxInHole[GCT]);
      ReadLn(InCh, MaxInHolePlace[GCT]);
      ReadLn(InCh, MaxOutHolePlace[GCT]);
      ReadLn(InCh, NumOfSnaps[GCT]);
      for SC:=1 to NumOfSnaps[GCT] do
      begin
	 ReadLn(InCh, InHoleScour[GCT, SC]);
	 ReadLn(InCh, InHoleDepth[GCT, SC]);
	 ReadLn(InCh, oInHoleDepth[GCT, SC]);
	 ReadLn(InCh, OutHoleScour[GCT, SC]);
	 ReadLn(InCh, OutHoleDepth[GCT, SC]);
	 ReadLn(InCh, oOutHoleDepth[GCT, SC]);
	 ReadLn(InCh, LastProtIn[GCT, SC]);
	 ReadLn(InCh, LastProtOut[GCT, SC]);
	 ReadLn(InCh, AUUC34[GCT, SC]);
	 for Counter:=1 to 20 do
	 begin
	    ReadLn(InCh, InProtY[GCT, SC, Counter]);
	    ReadLn(InCh, OutProtY[GCT, SC, Counter]);
	 end;
     end;
   end;
   ReadLn(InCh, TotalGapSurface);
   ReadLn(InCh, OrigTotalGapSurface);
   ReadLn(InCh, TidalPrism);
   ReadLn(InCh, U02);
   ReadLn(InCh, ReducPerM);
   ReadLn(InCh, TimeSinceKent);
   close(InCh);
   DataChanged:=False;
   Zipped[GCT]:=False;
   MCur.SelectStdCursor;
   Delay(1000);
   MessageBar^.Hide;
   end
   else
   begin
      Dial_ControleFile;
   end;
end;

procedure Opt_Save(FTS: FileString);

var Outch: Text;

begin
   if DataChanged then Opt_InitProcess;
   MCur.SelectHourGlass;
   MessageBar^.ShowText('Now Saving File '+FTS);
   Assign(OutCh, FTS); rewrite(OutCh);
   WriteLn(OutCh, 'CTBFILE');
   WriteLn(OutCh, BasinYear);
   WriteLn(OutCh, BasinMonth);
   WriteLn(OutCh, BasinDay);
   WriteLn(OutCh, BasinHour);
   WriteLn(OutCh, BasinMinute);
   WriteLn(OutCh, JobDayNo:5, 			  '  Job Day Number        ');
   WriteLn(OutCh, YearDay,                        '  Day of Year           ');
   WriteLn(OutCh, DayS);
   WriteLn(OutCh, JobHours:5:5,                   '  Hours of Process    ');
   WriteLn(OutCh, RiverFlow:5:5,                  '  River Flow            ');
   WriteLn(OutCh, CulvertSurface:5:5,             '  Culvert Surface       ');
   WriteLn(OutCh, Chezy:5:5,                      '  Chezy Value           ');
   WriteLn(OutCh, BottomD50:5:5,                  '  BottomD50             ');
   WriteLn(OutCh, MeanSeaLevel:5:5,               '  Mean Sea Level        ');
   WriteLn(OutCh, ActSeaLevel:5:5,                '  Actual Sea Level      ');
   WriteLn(OutCh, OSeal:5:5,                      '  Old Sea Level         ');
   WriteLn(OutCh, OldBasinLevel:5:5,              '  Old Basin Level       ');
   WriteLn(OutCh, BasinLevel:5:5,                 '  Actual Basin Level    ');
   WriteLn(OutCh, TotalFlow:5:5,                  '  Total Flow throug Gaps');
   WriteLn(OutCh, LevelFactY:5:5,                 '  Y factor LevelDrawing ');
   WriteLn(OutCh, LevelDrX:5:5,                   '  Coord X Level Drawing ');
   WriteLn(OutCh, NumOfKenterings:5,              '  Kenterings Till Now   ');
   WriteLn(OutCh, StormSurge:5:5,		  '  Maximum Storm Surge   ');
   WriteLn(OutCh, StormPeriod:5:5,	          '  Storm Duration        ');
   WriteLn(OutCh, StormChance:5:5,		  '  Chance of Storm       ');
   WriteLn(OutCh, VesselDraft:5:5, 		  '  Draft of Vessels      ');
   for Counter:=1 to 4 do
   begin
      WriteLn(OutCh, TideAmp[Counter]:5:5,     '     Tidal Amplitude Factor');
      WriteLn(OutCh, TidePeriod[Counter]:5:5,  '     Tidal Period          ');
      WriteLn(OutCh, TidePhase0[Counter]:5:5,  '     Tidal Phase at T=0    ');
   end;
   WriteLn(OutCh, TotalAmplitude:5:5,             '  Max Amplitude Possible');
   WriteLn(OutCh, EquiTotalGapSurface:5:5,        '  Gap Surf. Equilibrium ');
   WriteLn(OutCh, OrigMaxHeight:5:5,              '  Original Maximum Depth');
   WriteLn(OutCh, OrigTotalWidth:5:5,             '  Original Total Width  ');
   WriteLn(OutCh, WidthFact:5:5,                  '  Drawing Width Factor  ');
   WriteLn(OutCh, FlowDirection:5,                '  Actual Flow Direction ');
   WriteLn(OutCh, OldFlowDirection:5,             '  Last Flow Direction   ');
   for Counter:=1 to 5 do
   begin
      WriteLn(OutCh,KomDepth[Counter]:5:5,     '     Level in Basin        ');
      WriteLn(OutCh,KomSur[Counter]:5:5,       '     with Surface in Basin ');
   end;
   WriteLn(OutCh, NumOfGaps:5,                    '  Number of Gaps to Close');
   for GCT:=1 to NumOfGaps do
   begin
      WriteLn(OutCh, WayOfConstruction[GCT]:5,    '  Way of Construction   ');
      WriteLn(OutCh, WeirSituation[GCT]:5,        '  Actual Weir Situation ');
      WriteLn(OutCh, Construction[GCT]:5,         '  Construction Status   ');
      WriteLn(OutCh, OnceCableWay[GCT]:5,         '  Once Cable Way?       ');
      WriteLn(OutCh, OrigGapWidth[GCT]:5:5,       '  Original Width of Gap ');
      WriteLn(OutCh, GapWidth[GCT]:5:5,           '  Actual Width of Gap   ');
      WriteLn(OutCh, OrigGapDepthAtMSL[GCT]:5:5,  '  Original Depth of Gap ');
      WriteLn(OutCh, OrigGapSurface[GCT]:5:5,     '  Original Gap Surface  ');
      WriteLn(OutCh, GapFlow[GCT]:5:5,            '  Actual Gap Flow       ');
      WriteLn(OutCh, Velocity[GCT]:5:5,		  '  Actual Velocity in Gap');
      WriteLn(OutCh, GapMu[GCT]:5:5,              '  Contraction in Gap    ');
      WriteLn(OutCh, DumpedLeft[GCT]:5:5,         '  Volume Dumped Left    ');
      WriteLn(OutCh, DumpedRight[GCT]:5:5,        '                Right   ');
      WriteLn(OutCh, DumpedUp[GCT]:5:5,           '                Vertical');
      WriteLn(OutCh, ProcessLeft[GCT]:5,          '  Process Left          ');
      WriteLn(OutCh, ProcessRight[GCT]:5,         '  Process Right         ');
      WriteLn(OutCh, ActualVolume[GCT]:5:5,       '  Actual Volume of Dam  ');
      WriteLn(OutCh, XDRL[GCT]:5:5,               '  X left of Apron       ');
      WriteLn(OutCh, XDRR[GCT]:5:5,               '  X right of Apron      ');
      WriteLn(OutCh, YDR[GCT]:5:5,                '  Apron Level           ');
      WriteLn(OutCh, DamYL[GCT]:5:5,              '  Dam Level Left        ');
      WriteLn(OutCh, DamYR[GCT]:5:5,              '  Dam Level Right       ');
      WriteLn(OutCh, GapDepthAtMSL[GCT]:5:5,      '  Actual Gap Depth      ');
      WriteLn(OutCh, DamTopWidth[GCT]:5:5,        '  Top Width of Dam      ');
      WriteLn(OutCh, DamTop[GCT]:5:5,             '  Required Top Level    ');
      WriteLn(OutCh, RequiredVolume[GCT]:5:5,     '  Required Dam Volume   ');
      WriteLn(OutCh, DamHeight[GCT]:5:5,          '  => Required Dam Height');
      WriteLn(OutCh, DSH[GCT]:5:5,                '  Slope of Dam Head     ');
      WriteLn(OutCh, DSS[GCT]:5:5,                '  Slope of Section      ');
      WriteLn(OutCh, DamD50[GCT]:5:5,             '  D50 of Dam Material   ');
      WriteLn(OutCh, GradualLeft[GCT]:5:5,        '  Speed Closure Left    ');
      WriteLn(OutCh, GradualUp[GCT]:5:5,          '                Right   ');
      WriteLn(OutCh, UpMaxLevel[GCT]:5:5,         '  Level Limit Vertical  ');
      WriteLn(OutCh, VerticalInAcc[GCT]:5:5,      '  Vertical Inaccuracy   ');
      WriteLn(OutCh, GradualRight[GCT]:5:5,       '                 UpSide ');
      WriteLn(OutCh, StartDrawX[GCT]:5:5,         '  Drawing of Sections; X');
      WriteLn(OutCh, StandLengthProt[GCT]:5:5,    '  Length of Protection  ');
      WriteLn(OutCh, ProtSection[GCT]:5:5,        '  Length of BP section  ');
      WriteLn(OutCh, ProtQuality[GCT],		  '  Quality of BP         ');
      WriteLn(OutCh, SkippedVolumeLeft[GCT]:5:5,  '  Lately Skipped Left   ');
      WriteLn(OutCh, SkippedVolumeRight[GCT]:5:5, '  Lately Skipped Right  ');
      WriteLn(OutCh, SnapWidth[GCT]:5:5,          '  Width between Scour SC');
      WriteLn(OutCh, MaxOutHole[GCT]:5:5,         '  Maximum Scour Outside ');
      WriteLn(OutCh, MaxInHole[GCT]:5:5,          '  Maximum Scour Inside  ');
      WriteLn(OutCh, MaxInHolePlace[GCT]:5:5,     '  Place Mx Scour Inside ');
      WriteLn(OutCh, MaxOutHolePlace[GCT]:5:5,    '  Place Mx Scour Outside');
      WriteLn(OutCh, NumOfSnaps[GCT]:5,           '  Number of Scour Snaps ');
      for SC:=1 to NumOfSnaps[GCT] do
      begin
	 WriteLn(OutCh, InHoleScour[GCT,SC]:5:5,  '      Scour Hole Inside ');
	 WriteLn(OutCh, InHoleDepth[GCT,SC]:5:5,  '      Reduced Scour     ');
	 WriteLn(OutCh, oInHoleDepth[GCT,SC]:5:5, '      Last Scour Depth  ');
	 WriteLn(OutCh, OutHoleScour[GCT,SC]:5:5, '      Scour Hole Outside');
	 WriteLn(OutCh, OutHoleDepth[GCT,SC]:5:5, '      Reduced Scour     ');
	 WriteLn(OutCh, oOutHoleDepth[GCT,SC]:5:5,'      Last Scour Depth  ');
	 WriteLn(OutCh, LastProtOut[GCT,SC]:5:5,  '      Last protect   OUT');
	 WriteLn(OutCh, LastProtIn[GCT,SC]:5:5,   '      Last protect    IN');
	 WriteLn(OutCh, AUUC34[GCT,SC]:5:5,       '      Scour Integral    ');
	 for Counter:=1 to 20 do
	 begin
	    WriteLn(OutCh, InProtY[GCT, SC, Counter]:5:5,        '  Protection Level InFl ');
	    WriteLn(OutCh, OutProtY[GCT, SC, Counter]:5:5,       '  Protection Level OutFl');
	 end;
      end;
   end;
   WriteLn(OutCh, TotalGapSurface:5:5,            '  Actual Gap Surface    ');
   WriteLn(OutCh, OrigTotalGapSurface:5:5,        '  Original Total Surface');
   WriteLn(OutCh, TidalPrism:5:5,                 '  Tidal Prism           ');
   WriteLn(OutCh, U02:5:5,                        '  Square Velocity Integr');
   WriteLn(OutCh, ReducPerM:5:5,                  '  Velocity^5 Integral   ');
   WriteLn(OutCh, TimeSinceKent:5:5,              '  Time since Last Kent  ');
   close(OutCh);
   Delay(1000);
   MessageBar^.Hide;
   MCur.SelectStdCursor;
end;

procedure Opt_DepthsWidths;

begin
   P:=True;
   if (ProcessInited=False) and
      (DialSeriesOn=False)  and
      (SomethingDumped) then P:=Dial_ReallyChange;
   if P then begin
   Case NumOfGaps of
      1: Dial_DepthsWidths1(GapWidth, GapDepthAtMSL, GapMu);
      2: Dial_DepthsWidths2(GapWidth, GapDepthAtMSL, GapMu);
      3: Dial_DepthsWidths3(GapWidth, GapDepthAtMSL, GapMu);
   end;
   MaxCheck;
   for GCT:=1 to NumOfGaps do OrigGapWidth[GCT]:=GapWidth[GCT];
   DataChanged:=True; Started:=False; end;
end;

procedure Opt_Tide;
begin
   P:=True;
   if (ProcessInited=False) and
      (DialSeriesOn=False) and
      SomethingDumped then P:=Dial_ReallyChange;
   if P then begin
   Dial_Tide(TideAmp, TidePeriod, TidePhase0);
   DataChanged:=True; Started:=False; end;
end;

procedure Opt_Protection;

var Warning: Boolean;

begin
   if NumOfGaps=1 then Dial_Protection1(StandLengthProt);
   if NumOfGaps=2 then Dial_Protection2(StandLengthProt);
   if NumOfGaps=3 then Dial_Protection3(StandLengthProt);
   Warning:=False;
   for GCT:=1 to NumOfGaps do
   begin
      ProtSection[GCT]:=StandLengthProt[GCT]/40;
      if (ProtSection[GCT]=0) and (WayOfConstruction[GCT]<>csSandDump) then
	 Warning:=True;
   end;

   if Warning then Warn_Protection;
end;

procedure Opt_GradualClose;

var OldDamD50: RealArr;

begin
   for GCT:=1 to NumOfGaps do OldDamD50[GCT]:=DamD50[GCT];
   case NumOfGaps of
	1: Dial_GradualClose1(GradualLeft, GradualRight,
	   GradualUp, UpMaxLevel, DamD50);
	2: Dial_GradualClose2(GradualLeft, GradualRight,
	   GradualUp, UpMaxLevel, DamD50);
	3: Dial_GradualClose3(GradualLeft, GradualRight,
	   GradualUp, UpMaxLevel, DamD50);
   end;
   MaxCheck;
   for GCT:=1 to NumOfGaps do
   begin
      if ((ProcessInited=False) and (DamD50[GCT]<>OldDamD50[GCT])) and
	 ((DumpedLeft[GCT]<>0)  and (DumpedRight[GCT]<>0)) and
	 ((ProcessLeft[GCT]=Start)     or (ProcessRight[GCT]=Start) or
	  (ProcessLeft[GCT]=StartToes) or (ProcessRight[GCT]=StartToes)) then
      begin
	 Warn_OnlyFullProcess;
	 DamD50[GCT]:=OldDamD50[GCT];
      end;
      if (DamD50[GCT]<OldDamD50[GCT])
	  and ((DumpedLeft[GCT]<>0) or (DumpedRight[GCT]<>0))
	  and (DataChanged=False) then
      begin
	 Warn_OnlySmallToBig;
	 DamD50[GCT]:=OldDamD50[GCT];
      end;
      CalculateAngles(WayOfConstruction, DSS, DSH);
   end;
   for GCT:=1 to NumOfGaps do
   begin
      If DumpedLeft[GCT]=0  then DamYL[GCT]:=YDR[GCT];
      If DumpedRight[GCT]=0 then DamYR[GCT]:=YDR[GCT];
   end;
end;

procedure Opt_Dimensions;

var ODamTop: RealArr;

begin
   for GCT:=1 to NumOfGaps do ODamTopWidth[GCT]:=DamTopWidth[GCT];
   for GCT:=1 to NumOfGaps do ODamTop[GCT]:=DamTop[GCT];
   if NumOfGaps=1 then Dial_Dimensions1(DamTopWidth, DamTop);
   if NumOfGaps=2 then Dial_Dimensions2(DamTopWidth, DamTop);
   if NumOfGaps=3 then Dial_Dimensions3(DamTopWidth, DamTop);
   MaxCheck;
   for GCT:=1 to NumOfGaps do
   begin
      if Started then DamTop[GCT]:=ODamTop[GCT];
      If (WayOfConstruction[GCT]=csCableWay) and (DamTopWidth[GCT]>10) then
      begin
	 DamTopWidth[GCT]:=10;
	 Warn_CableWayDamTopWidth;
      end;
   end;
end;

procedure Opt_Methods;

var VesselsChosen,
    Warning: Boolean;
    OWayOfConstruction: IntArr;

begin
   P:=True;
   {if (ProcessInited=False) and
      (DialSeriesOn=False)  and
      SomethingDumped then P:=Dial_ReallyChange;}
   if P then
   begin
      for GCT:=1 to NumOfGaps do
      OWayOfConstruction[GCT]:=WayOfConstruction[GCT];
      ExitDialSeries:=False;
      DialSeriesOn:=True;
      if NumOfGaps=1 then Dial_Methods1(WayOfConstruction);
      if NumOfGaps=2 then Dial_Methods2(WayOfConstruction);
      if NumOfGaps=3 then Dial_Methods3(WayOfConstruction);
      VesselsChosen:=False;
      for GCT:=1 to NumOfGaps do if WayOfConstruction[GCT]=csVessels then
	  VesselsChosen:=True;
      if ExitDialSeries=False then
      if VesselsChosen=True then Dial_VesselDraft(VesselDraft);
      MaxCheck;
      Warning:=False;
      for GCT:=1 to NumOfGaps do
      if (ProtSection[GCT]=0) and (WayOfConstruction[GCT]<>csSandDump) then
	 Warning:=True;
      if Warning then Warn_Protection;
   end;
   case WayOfConstruction[GCT] of
	csTrucks: GradualUp[GCT]:=0;
	csVessels: begin GradualLeft[GCT]:=0; GradualRight[GCT]:=0; end;
	csSandDump: GradualUp[GCT]:=0;
	csCableWay: begin GradualLeft[GCT]:=0; GradualRight[GCT]:=0; end;
   end;
   CalculateAngles(WayOfConstruction, DSS, DSH);
   if Adapting=False then Opt_Dimensions;
   if SomethingDumped then
   for GCT:=1 to NumOfGaps do
   if (OWayOfConstruction[GCT]=csVessels) or
      (OWayOfConstruction[GCT]=csCableWay) then
   if (2*(DamTop[GCT]-YDR[GCT])/Tan(DSS[GCT])+DamTopWidth[GCT])>
	 ODamTopWidth[GCT] then
	 begin
	    {Warn_NextDamTopWidth;
	    WayOfConstruction[GCT]:=OWayOfConstruction[GCT];
	    DamTopWidth[GCT]:=ODamTopWidth[GCT];
	    CalculateAngles(WayOfConstruction, DSS, DSH);
	    }
	 end;
end;

procedure Opt_VesselDraft;
begin
   Dial_VesselDraft(VesselDraft);
   MaxCheck;
end;

procedure Opt_Angles;
begin
   P:=True;
   if (ProcessInited=False) and
      (DialSeriesOn=False)  and
      SomethingDumped then P:=Dial_ReallyChange;
   if P then begin
   for Counter:=1 to NumOfGaps do
   begin
{      DSH[Counter]:=DSH[Counter]*PiToDeg;
      DSS[Counter]:=DSS[Counter]*PiToDeg;
}   end;
   CalculateAngles(WayOfConstruction, DSS, DSH);
   if NumOfGaps=1 then Dial_Angles1(DSS, DSH);
   if NumOfGaps=2 then Dial_Angles2(DSS, DSH);
   if NumOfGaps=3 then Dial_Angles3(DSS, DSH);
   MaxCheck;
   for Counter:=1 to NumOfGaps do
   begin
{      DSH[Counter]:=DSH[Counter]*DegToPi;
      DSS[Counter]:=DSS[Counter]*DegToPi;
}   end;
   CalculateAngles(WayOfConstruction, DSS, DSH);
   DataChanged:=True; Started:=False; end;
end;

procedure Opt_Basin;
begin
   P:=True;
   if (ProcessInited=False) and
      (DialSeriesOn=False)  and
      SomethingDumped then P:=Dial_ReallyChange;
   if P then begin
   Dial_Basin(KomDepth, KomSur);
   MaxCheck;
   DataChanged:=True; Started:=False; end;
end;

procedure Opt_RiverData;
begin
   Dial_RiverData(RiverFlow);
   MaxCheck;
end;

procedure Opt_DefStorm;
begin
   Dial_DefStorm(StormSurge, WaveDuringStorm, StormPeriod, StormChance);
   MaxCheck;
end;

procedure Opt_Closure;

begin
   P:=True;
   if (ProcessInited=False) and
      (DialSeriesOn=False)  and
      SomethingDumped then P:=Dial_ReallyChange;
   ONOG:=NumOfGaps;
   if P then
   begin
      ExitDialSeries:=False;
      DialSeriesOn:=True;
      Dial_Closure(NumOfGaps, Chezy, BottomD50, TimeStep);
      MaxCheck;
      if ExitDialSeries=False then
      if NumOfGaps>ONOG then Opt_AdaptAll;
   end;
end;

procedure Opt_Culvert;
begin
   Dial_Culvert(CulvertSurface);
   MaxCheck;
end;

procedure Opt_DateTime;
begin
   Dial_DateTime(BasinYear, BasinMonth, BasinDay, BasinHour, BasinMinute);
end;

procedure Opt_AdaptAll;

begin
   DataChanged:=True;
   ExitDialSeries:=False;
   DialSeriesOn:=True;
   Started:=False;

   if ExitDialSeries=False then Opt_Tide;
   if ExitDialSeries=False then Opt_Basin;
   if ExitDialSeries=False then Opt_RiverData;
   if ExitDialSeries=False then
   begin
      if NumOfGaps=1 then Dial_Protection1(StandLengthProt);
      if NumOfGaps=2 then Dial_Protection2(StandLengthProt);
      if NumOfGaps=3 then Dial_Protection3(StandLengthProt);
   end;
   for GCT:=1 to NumOfGaps do
   begin
      ProtSection[GCT]:=StandLengthProt[GCT]/40;
   end;
   Adapting:=True;
   if ExitDialSeries=False then Opt_Methods;
   Adapting:=False;
   if ExitDialSeries=False then Opt_GradualClose;
   if ExitDialSeries=False then Opt_DepthsWidths;
   Adapting:=True;
   if ExitDialSeries=False then Opt_Dimensions;
   Adapting:=False;
   if ExitDialSeries=False then Opt_Angles;
   if ExitDialSeries=False then Opt_Culvert;

   DialSeriesOn:=False;

end;

procedure Opt_Start;

begin
   if Dial_Startup=True then
   if StartupCanceled=False then
   begin
      Dial_Closure(NumOfGaps, Chezy, BottomD50, TimeStep);
      MaxCheck;
      if (ExitDialSeries=False) then Opt_AdaptAll;
   end;
   if StartUpCanceled=False then
   begin
   Warning:=False;
   for GCT:=1 to NumOfGaps do
   begin
      if (StandLengthProt[GCT]<>0) then
      if StandLengthProt[GCT] < (DamTopWidth[GCT]+
	 2*(DamTop[GCT]-OrigGapDepthAtMSL[GCT])/Tan(DSS[GCT])) then
	 begin Warning:=True; StandLengthProt[GCT]:=0; end;
   end;
   if Warning=True then Warn_BotProt;
   ONOG:=NumOfGaps;
   if DataChanged=True then
   begin
      Opt_InitProcess;
   end;
   ProcessInited:=False;
   ActSeaLevel:=SeaLevel(MeanSeaLevel, TideAmp, TidePeriod, TidePhase0, JobHours);
  end;
end;

end.