{**********************************************************}
{            CLOSIM v 1.00  --  CALCULATION UNIT           }
{**********************************************************}
{ Containing the calculation procedures for the simulation }
{ program on the Closure of Tidal Basins, written in Turbo }
{ Pascal 7.0 by Mark Middag, TUDelft, 1994.                }
{**********************************************************}

Unit SimCalc;

Interface

uses Crt, Dos, Graph, App,
     SIMVARS, GSIMDIAL, SIMTOOLS, SIMDRAWS;

procedure Calculate;
procedure DamDestruction;
procedure BedDestruction;
procedure Kentering;
procedure Equilize_Profiles;
procedure DetermineMaxima;
procedure CalculateAngles(WayOfConstruction: IntArr; Var DSS, DSH: RealArr);

Implementation                             {Definition of written procedures}

procedure Determine_EquilibriumProfile;   {DETERMINE EQUILIBRIUM GAP PROFILE}

var CalcAmplitude,  {reduced sum of amplitudes}
    Slide: Real;    {thickness of a slice of water}

begin
  TidalPrism:=0;                                          {RESET accumulator}
  CalcAmplitude:=0.7*(TideAmp[1]
                     +TideAmp[2]            {calculation is executed using a}
                     +TideAmp[3]                  {REDUCED SUM of amplitudes}
                     +TideAmp[4]);            {reader is referred to manuals}

  For Counter:=1 to 50 do                               {DIVIDE tidal volume}
  begin                                                          {into fifty}
      Slide:=2*CalcAmplitude/50;                         {calculation slides}

      TidalPrism:=TidalPrism+     {INCREASE tidal prism with volume of slide}

      StorageSurface(MeanSeaLevel-(25+Counter)*Slide)*Slide;
  end;
  EquiTotalGapSurface:=TidalPrism/16500;      {CALCULATE equilibrium profile}

                                   {Reader is referred to volume I, page ###}
end;

procedure DetermineMaxima;                         {CALCULATE MAXIMUM VALUES}

begin

  TotalAmplitude:=0;             {Calculate Maximum Tidal Amplitude Possible}
  For Counter:=1 to 4 do
     TotalAmplitude:=TotalAmplitude+TideAmp[Counter];

  OrigMaxHeight:=-1000;
  for GCT:=1 to NumOfGaps do
  if (DamTop[GCT]-OrigGapDepthAtMSL[GCT]>OrigMaxHeight) then
     OrigMaxHeight:=Abs(DamTop[GCT]-OrigGapDepthAtMSL[GCT]);

  OrigTotalHeight:=0;
  for GCT:=1 to NumOfGaps do
     OrigTotalHeight:=OrigTotalHeight+Abs(DamTop[GCT]-OrigGapDepthAtMSL[GCT]);

end;

procedure Equilize_Profiles; {CHANGE ACTUAL PROFILE INTO EQUILIBRIUM PROFILE}

var ProfileChangeFactor: Real; {multiplication FACTOR for profile adaptation}
    Warning: Boolean;		             {Warning for Depth/Width factor}
    Teller: Integer;

begin

   if TotalGapSurface=0 then               {there should at least be one gap}
   begin
      GapWidth[1]:=OrigGapWidth[1];
   end;

   Determine_EquilibriumProfile;
   Teller:=0;

   repeat
      if TotalGapSurface<EquiTotalGapSurface {IF actual profile is too small}
	 then ProfileChangeFactor:=1.001              {THEN increase profile}
	 else ProfileChangeFactor:=0.999;             {ELSE decrease profile}

      TotalGapSurface:=0;                         {calculate new gap surface}
      for GCT:=1 to NumOfGaps do
      begin
	 GapDepthAtMSL[GCT] := GapDepthAtMSL[GCT]*ProfileChangeFactor;
	 GapSurface[GCT]    := Abs(MeanSeaLevel-GapDepthAtMSL[GCT])*GapWidth[GCT];
	 TotalGapSurface    := TotalGapSurface+GapSurface[GCT];
      end;
      TotalGapSurface:=TotalGapSurface+CulvertSurface;
      Teller:=Teller+1;
   until (abs(TotalGapSurface-EquiTotalGapSurface)<1) or (Teller>10000);
   {repeat adaptation until actual gap profile == equilibrium profile}

   Warning:=False;
   for GCT:=1 to NumOfGaps do
   if GapDepthAtMSL[GCT]>10*GapWidth[GCT] then Warning:=True;

   if Warning then Warn_DepthWidthFact;

end;

Procedure AdvanceTime(Seconds: Integer);         {ADMINISTRATION OF JOB TIME}

var Minutes,             {number of minutes of time advance}
    byear,               {integer for basin hour}
    bmonth,              {integer for basin month}
    bday,                {integer for basin day}
    bhour,               {integer for basin hour}
    bminute,             {integer for basin minute}
    MaxDays,             {maximum number of days in a month}
    code,                {control variable}
    WeekDay: integer;    {number of day in week (1-7)}

begin
   Minutes:=T(Seconds/60);
   JobHours:=JobHours+Seconds/3600;       {CALCULATE number of process hours}
   val(BasinYear,BYear,code);
   val(BasinMonth,BMonth,code);          {CONVERT time strings into integers}
   val(BasinDay,BDay,code);
   val(BasinHour,BHour,code);
   val(BasinMinute,BMinute,code);
   BMinute:=BMinute+Minutes;                  {ADD number of minutes to time}
   if BMinute>59 then
   begin
      repeat BMinute:=BMinute-60 until BMinute<60;   {ADMINISTRATION of time}
      BHour:=BHour+1;
      if BHour>24 then
      begin
	 DayChanged:=True;
	 BHour:=BHour-24;
	 BDay:=BDay+1;
	 JobDayNo:=JobDayNo+1;
	 YearDay:=0;
	 for Counter:=1 to BMonth-1 do                {CALCULATE DAY OF YEAR}
	 begin
	    if Counter in [1,3,5,7,8,10,12]         {NUMBER OF DAYS in month}
               then YearDay:=YearDay+31
	       else YearDay:=YearDay+30;
	    if Counter=2 then
            if BYear/4 = Int(BYear/4)              {FEBRUARI is special case}
	       then YearDay:=YearDay+29
	       else Yearday:=Yearday+28;
	 end;

	 YearDay:=YearDay+BDay;

	 WeekDay:=
             BYear-1900 +                             {CALCULATE day of week}
             Trunc((BYear-1900)/4 + YearDay) + 1;

	 WeekDay:=t((WeekDay/7-Trunc(WeekDay/7))*7+1);

	 if WeekDay=1 then DayS:='Sunday';                  {ADD NAME OF DAY}
	 if WeekDay=2 then DayS:='Monday';
	 if WeekDay=3 then DayS:='Tuesday';
	 if WeekDay=4 then DayS:='Wednesday';
	 if WeekDay=5 then DayS:='Thursday';
	 if WeekDay=6 then DayS:='Friday';
	 if WeekDay=7 then DayS:='Saturday';
	 if BMonth in [1,3,5,7,8,10,12]              {CALCULATE month length}
	    then MaxDays:=31
	    else MaxDays:=30;
	 if BMonth=2 then if BYear/4 = Int(BYear/4) then MaxDays:=29
						    else MaxDays:=28;
	 if BDay>MaxDays then
	 begin
	    BDay:=1;
	    BMonth:=BMonth+1;
	    if BMonth>12 then
	   begin
	       BMonth:=1;
	       BYear:=BYear+1;
	    end;
	 end;
      end;
   end;                                      {CONVERT time back into strings}
   str(BMinute, BasinMinute);
   if length(BasinMinute)=1 then BasinMinute:='0'+BasinMinute;
   str(BHour, BasinHour);
   if length(BasinHour)=1 then BasinHour:='0'+BasinHour;
   str(BDay, BasinDay);
   if length(BasinDay)=1 then BasinDay:='0'+BasinDay;
   str(BMonth, BasinMonth);
   if length(BasinMonth)=1 then BasinMonth:='0'+BasinMonth;
   str(BYear, BasinYear);
end;

Procedure Calcul_ScoAngle;                   {CALCULATE ANGLE IN SCOUR HOLES}

begin
   beta := 0.0003 *                       {SCOUR FORMULA, volume I, page ###}
	   (U02/(TimeSinceKent))
	   / (Delta*Gravity*(BottomD50/1000))
	   + ( 0.11 + 0.75 * 0.3 ) * Chezy / 40;

   if 1-Beta >0.001 then Beta := ArcSin(Beta)                    {ERROR TRAP}
		    else Beta := 1;

   U02:=0;                            {RESET accumulator for square velocity}

end;

procedure StabilizeScourHoles;       {CALCULATE (IN)STABILITY OF SCOUR HOLES}

var HoleDepth,         {height of slope only}
    RelaDepth,         {height of slope + settlement difference protection}
    RelaTanBeta,       {tangent of various possible slide slopes}
    B,                 {horizontal length of slide slopes}
    ProtYLastUnch,     {last unsettled section of bottom protection}
    NewDown: Real;     {new depth of scour hole after instability}

const MaxDepth = 10;                             {if this depth is exceeded,}
      MaxTanAngle = 0.14;       {AND this angle is exceeded, collapse occurs}
      EffectZone=3;                           {length of scour hole collapse}

      {these constants could be changed,         }
      {reader is referred to page ### of volume 1}

begin

   for GCT:=1 to NumOfGaps do               {FOR all gaps and width sections}
   for SC:=0 to NumOfSnaps[GCT] do

   if (Construction[GCT]<>Collapsed)           {ONLY if not collapsed and if}
   and (ProtSection[GCT]<>0) then              {there is a bottom protection}

   begin

	for PSC:=T(LastProtIn[GCT, SC]) downto 1 do    {various slide slopes}

	begin

	   HoleDepth:=InProtY[GCT, SC,                      {calculate DEPTH}
	   T(LastProtIn[GCT, SC])]+InHoleDepth[GCT, SC];
	   RelaDepth:=HoleDepth-InProtY[GCT, SC, PSC];

	   B:=(InHoleDepth[GCT, SC]/Tan(Beta)+              {calculate ANGLE}
	   (LastProtIn[GCT, SC]-PSC)*ProtSection[GCT]);
	   if B<>0 then RelaTanBeta:=RelaDepth/B;

	   if  (RelaDepth>MaxDepth)            {if maximum depth is exceeded}
           and (RelaTanBeta>MaxTanAngle)      {AND maximum angle is exceeded}
           then begin
	      if PSC-EffectZone*RelaDepth/ProtSection[GCT]<        {COLLAPSE}
		 (DamTopWidth[GCT]/2+(DamTop[GCT]-
		 OrigGapDepthAtMSL[GCT])/Tan(DSS[GCT]))
                 /ProtSection[GCT] then
		 begin                     {if protection settles below dam,}
		    Construction[GCT]:=Collapsed;  {construction has failed.}
		    DataChanged:=False;
		 end;
	      Counter2:=0;
                                       {determine new profile after collapse}

	      ProtYLastUnch:=InProtY[GCT, SC, T(
		  Max(2,PSC-EffectZone*RelaDepth/
                  ProtSection[GCT]))];

              NewDown:=0.4*ProtYLastUnch+0.6*RelaDepth;      {new hole depth}

	      for Counter:=T(PSC-EffectZone*RelaDepth/ProtSection[GCT])
                        to T(LastProtIn[GCT, SC]) do

	      begin                        {adapt all sections of protection}

	          InProtY[GCT, SC, Counter]:=
		      ProtYLastUnch+(NewDown-ProtYLastUnch)*
		      Counter2/(LastProtIn[GCT, SC]-PSC+
                      EffectZone*RelaDepth/ProtSection[GCT]);

		  Counter2:=Counter2+1;

		  if ProtQuality[GCT]=Bad then      {if quality is bad, then}
						 {decrease protection length}
		  begin
		     LastProtIn[GCT, SC]:=
                         T(Max(1,PSC-EffectZone*RelaDepth/ProtSection[GCT]));
		  end;

	      end;
	      InHoleDepth[GCT,SC]:=MaxDepth/4;     {new depths, values could}
              InHoleScour[GCT,SC]:=MaxDepth/4;     {be adapted by programmer}
	   end;
	end;
	for PSC:=T(LastProtOut[GCT, SC]) downto 1 do
	begin
	   HoleDepth:=OutProtY[GCT, SC, T(LastProtOut[GCT, SC])]+OutHoleDepth[GCT, SC];
	   RelaDepth:=HoleDepth-OutProtY[GCT, SC, PSC];
	   B:=(OutHoleDepth[GCT, SC]/Tan(Beta)+(LastProtOut[GCT, SC]-PSC)*ProtSection[GCT]);
	   if B<>0 then RelaTanBeta:=RelaDepth/B;
	   if (RelaDepth>MaxDepth) and (RelaTanBeta>MaxTanAngle) then
	   begin
	      if PSC-EffectZone*RelaDepth/ProtSection[GCT]<
		 (DamTopWidth[GCT]/2+(DamTop[GCT]-
		 OrigGapDepthAtMSL[GCT])/Tan(DSS[GCT]))/ProtSection[GCT] then
		 begin
		    Construction[GCT]:=Collapsed;
		    DataChanged:=False;
		 end;
	      Counter2:=0;
	      ProtYLastUnch:=OutProtY[GCT, SC, T(Max(2,PSC-EffectZone*RelaDepth/ProtSection[GCT]))];
	      NewDown:=0.3*ProtYLastUnch+0.7*RelaDepth;
	      for Counter:=T(PSC-EffectZone*RelaDepth/ProtSection[GCT])
		   to T(LastProtOut[GCT, SC]) do
		   begin
		      OutProtY[GCT, SC, Counter]:=
		      ProtYLastUnch+(NewDown-ProtYLastUnch)*
		      Counter2/(LastProtOut[GCT, SC]-PSC+EffectZone*RelaDepth/ProtSection[GCT]);
		      Counter2:=Counter2+1;
		      if ProtQuality[GCT]=Bad then
		      begin
			 LastProtOut[GCT, SC]:=T(Max(1,PSC-EffectZone*RelaDepth/ProtSection[GCT]));
		      end;
		   end;
	    OutHoleDepth[GCT,SC]:=MaxDepth/4;
	    OutHoleScour[GCT,SC]:=MaxDepth/4;
	   end;
	end;
   OutProtY[GCT,SC,1]:=OutProtY[GCT,SC,3];
   InProtY[GCT,SC,1]:=InProtY[GCT,SC,3];
   end;
end;

procedure Kentering;                     {This procedure is called each time}
				    {the inside and outside levels are equal}

var P,              {part of scour formula}
    Scf1,           {part of scour formula}
    Scf2: Real;     {part of scour formula}
    SC  : Integer;  {width section counter}

begin

  NumOfKenterings:=NumOfKenterings+1;     {number of equal levels is counted}

					{flow calculation is not correct yet}
  if NumOfKenterings>1 then            {not the first time, because then the}
  begin
     for GCT:=1 to NumOfGaps do                                {for all gaps}
      if (TimeSinceKent-TimeStep) *      {none of these should equal zero!}
      GapDepthAtMSL[GCT] *
      GapSurface[GCT] <> 0 then
      if (Construction[GCT]=Finished) or
	 (Construction[GCT]=Collapsed) then
	 delay(50)
      else
      begin
      for SC:=0 to NumOfSnaps[GCT] do                {for all width sections}
       begin
	 Scf1:=0;
	 Scf2:=0;
	 P:=(AUUC34[GCT, SC]/(TimeSinceKent-TimeStep)) {scour formula, see}
	    *Power(abs(OrigGapDepthAtMSL[GCT]),0.2)      {volume I, page ###}
	    /(10*Power(Delta, 0.7));
	 if P<>0 then
	 begin
	    if (FlowDirection=Inflow)           {if water flowing into basin}
	    or (StaticsOn) then      {StaticsOn is for programmer's use only}
	    begin
	       FictiveTime{in hours}:=       {calculate fictive process time}
	       Power(InHoleScour[GCT, SC]/  {see scour description in manual}
		     P,1/0.4);
	       InHoleScour[GCT, SC]:=
	       P*Power((FictiveTime*3600+
	       TimeSinceKent-TimeStep)/3600, 0.4);
	       if StaticsOn then ReducPerM:=0;
	       Scf1:=SQR(InHoleScour[GCT, SC]) -            {scour reduction}
		     Abs(ReducPerM)*SnapWidth[GCT]/FormFact;
	       if Scf1>=0 then InHoleDepth[GCT, SC]:=Sqrt(SCF1)
			  else InHoleDepth[GCT, SC]:=0;
	       {InHoleDepth[GCT, SC]:=InHoleScour[GCT, SC];}

			    {InHoleScour is the unreduced scour depth, while}
			    {InHoleDepth is the reduced scour depth         }

	    end
	    else
	    begin
	       FictiveTime{in hours}:=         {if water flows out of basin}
	       Power(OutHoleScour[GCT, SC]/   {the same calculation is done}
		     P,1/0.4);
	       OutHoleScour[GCT, SC]:=
	       P*Power((FictiveTime*3600+
	       TimeSinceKent-TimeStep)/3600, 0.4);
	       Scf2:=SQR(OutHoleScour[GCT, SC]) -
		     Abs(ReducPerM)*SnapWidth[GCT]/FormFact;
	       if Scf2>=0 then OutHoleDepth[GCT, SC]:=Sqrt(SCF2)
			  else OutHoleDepth[GCT, SC]:=0;
	       {OutHoleDepth[GCT, SC]:=OutHoleScour[GCT, SC];}
	       {if SC=5 then
	       WriteLn(OutP, OutHoleDepth[GCT,SC],
			     OutHoleScour[GCT,SC],
			     SQR(OutHoleScour[GCT,SC]),
			     Abs(ReducPerM)*SnapWidth[GCT]/FormFact);}
	    end;

	    if (InHoleDepth[GCT, SC]>MaxInHole[GCT])
	    or (MaxInHolePlace[GCT]=0) then
	    begin
	       MaxInHole[GCT]:=                {remember place and depth of}
		   InHoleDepth[GCT, SC];                {deepest scour hole}
	       MaxInHolePlace[GCT]:=SC;                      {at basin side}
	    end;
	    if (OutHoleDepth[GCT, SC]>MaxOutHole[GCT])
	    or (MaxOutHolePlace[GCT]=0) then
	    begin
	       MaxOutHole[GCT]:=               {remember place and depth of}
		   OutHoleDepth[GCT, SC];               {deepest scour hole}
	       MaxOutHolePlace[GCT]:=SC;        {at sea side (for drawings)}
	    end;
	 end;
       end;
     end;
     Calcul_ScoAngle;           {call procedure for scour angle calculation}
  end;

  TimeSinceKent:=TimeStep;     {reset counter for time since last kentering}

  ReducPerM:=0;             {reset reduction counter and Breuser's integral}
  for GCT:=1 to NumOfGaps do
  for Counter:=0 to NumOfSnaps[GCT] do AUUC34[GCT, Counter]:=0;

  if Beta<>0 then begin                                         {error trap}
     StabilizeScourHoles;              {verify stability of new scour holes}
     JustKentered:=True;                              {set flag for drawing}
  end;
end;

procedure Calcul_Komberg;       {CALCULATION OF LEVELS, FLOWS AND VELOCITIES}

var A, B, C, C2,       {elements of A-B-C formulas for root calculation}
    D,  D2,            {determinants of A-B-C formulas]}
    LevDif,
    LD, LD2,           {level difference and increased level difference}
    MinLevel,          {one of the two levels is lower }
    CalcMinLevel,      {restricted minimum in case of clear overfall}
    CalcSeaLevel,      {average of actual sealevel and that of next timestep}
    OverTop: Real;     {height of water above the sill}
    ItCount: Integer;  {Iteration Counter}
    WDS: Real;	       {Wave height during storm in actual situation}
    Teller: Integer;

begin

    OldBasinLevel:=BasinLevel;                    {remember last basin level}

    SeaLevel2:=SeaLevel(MeanSeaLevel,       {calculate sealevel with respect}
			TideAmp,               {to several actual conditions}
			TidePeriod,
			TidePhase0,
			JobHours+TimeStep/3600);

    CalcSeaLevel:=(ActSeaLevel + SeaLevel2)/2;  {calculation with average of}
					    {actual sealevel and sealevel of}
				       {next timestep, see volume I page ###}

    if OldBasinLevel>=CalcSeaLevel then         {Look which level is maximum}
       begin
	  FlowDirection:=Outflow;    {in case water flowing out of the basin}
	  MaxLevel:=OldBasinLevel;
	  MinLevel:=CalcSeaLevel;
       end
    else
       begin
	  FlowDirection:=InFlow;       {in case water flowing into the basin}
	  MaxLevel:=CalcSeaLevel;
	  MinLevel:=OldBasinLevel;
       end;

  ItCount:=0;

  repeat                                                  {NUMERIC ITERATION}

    for Counter:=1 to NumOfGaps do
    LastGapFlow[Counter]:=                        {start value for iteration}
    GapFlow[Counter];
    TotalFlow:=0;                                           {reset variables}
    TotalGapSurface:=0;
    for GCT:=1 to NumOfGaps do

    begin

       GapDepthAtMSL[GCT]:=YDR[GCT];    {depth acording to MSL is sill level}

       InaccuracyLevel:=                   {at one place though, the sill is}
       GapDepthAtMSL[GCT]-       {lower with respect to dumping inaccuracies}
       VerticalInAcc[GCT];

       if (MinLevel-InAccuracyLevel)<             {in case of clear overfall}
						      {at dumping inaccuricy}
       (2/3)*(MaxLevel-InAccuracyLevel) then
	  InAccMinLevel:=
	  (2/3)*(MaxLevel-InAccuracyLevel)+InAccuracyLevel

       else InAccMinLevel:=MinLevel;               {if overfall is not clear}

       if (MinLevel-GapDepthAtMSL[GCT])<
       (2/3)*(MaxLevel-GapDepthAtMSL[GCT]) then   {in case of clear overfall}
						   {in the whole closure gap}
       begin
	 CalcMinLevel:=                          {then, the level difference}
	 (2/3)*(MaxLevel-GapDepthAtMSL[GCT])        {does only depend on the}
	 +GapDepthAtMSL[GCT];                        {upstream energy height}
	 WeirSituation[GCT]:=Complete;
	 OverTop:=CalcMinLevel-GapDepthAtMSL[GCT];
	 if OverTop>0 then                             {in case of high dam,}
	 if (OverTop/(Delta*DamD50[GCT]/1000)<4) and  {velocities are higher}
	    (OverTop/(Delta*DamD50[GCT]/1000)>0) and
	    (2.4-0.35*OverTop/(Delta*DamD50[GCT]/1000)>0)
	    then CrestMult[GCT]:=
	       SQRT(2.4-0.35*OverTop/
	       (Delta*DamD50[GCT]/1000))
	    else CrestMult[GCT]:=1
	 else CrestMult[GCT]:=1;
       end
       else                                   {if the overfall is not clear,}
       begin                              {the dam is never regarded as high}
	 CrestMult[GCT]:=1;
	 CalcMinLevel:=MinLevel;
	 WeirSituation[GCT]:=InComplete;
       end;

       if CalcMinLevel-GapDepthAtMSL[GCT]<0 then      {Gap Vertically Closed}
       begin
	  CalcMinLevel:=GapDepthAtMSL[GCT];
       end;

       GapSurface[GCT]:=                             {calculate flow surface}
       Abs(CalcMinLevel-                             {which is width * depth}
       GapDepthAtMSL[GCT])*GapWidth[GCT];

       if GapSurface[GCT]<0.5 then GapSurface[GCT]:=0;           {error trap}

       If GapSurface[GCT]=0 then
	  WeirSituation[GCT] := Closed;

       TotalGapSurface:=              {for calculation of total flow surface}
	  TotalGapSurface+GapSurface[GCT];

       if WeirSituation[GCT] <> Closed then

       begin

	  {see appendix A of program description, volume I}

	  A  := 1/SQR(GapMu[GCT]*GapSurface[GCT]);
	  B  := Gravity * TimeStep / StorageSurface(OldBasinLevel);
	  LD := MaxLevel - CalcMinLevel;
	  C  := ABS(gravity * 2 * LD) - FlowDirection*
				  0 * B * (LastTotalFlow - LastGapFlow[GCT]);
	  D  := SQR(B) + abs(4 * A * C);
	  GapFlow[GCT] := FlowDirection * (-B + SQRT(D)) / (2*A);

	  if (ClosureScheme[GCT]=Vertical) and  {for the dumping inaccuracy,}
	     (WeirSituation[GCT]=Complete) and   {only if flows are critical}
	     (InAccuracyLevel<MinLevel) then    {the calculation is repeated}

	  begin
	     LD2:= MaxLevel - InAccMinLevel;
	     VeloInAcc[GCT]:= ABS(SQRT(2*Gravity*LD2));
	     CritVelo[GCT] := 1.3*SQRT(2*Delta*Gravity*(DamD50[GCT]/1000));
	     if (VeloInAcc[GCT] > CritVelo[GCT]) then
	     begin
		Zipped[GCT]:=True;
		JustKentered:=True;
		Construction[GCT]:=Collapsed;
	     end;
	  end;
	end
	else
	begin
	   GapFlow[GCT]:=0;            {if the gap is closed, these are zero}
	   Velocity[GCT]:=0;
	end;
	TotalFlow:=TotalFlow+GapFlow[GCT];
    end;

    TotalGapSurface:=                          {a culvert flow is calculated}
    TotalGapSurface+CulvertSurface;

    if CulvertSurface <> 0 then                     {if a culvert is present}

    begin
       A  := 1/Power(1*CulvertSurface, 2);
       B  := Gravity * TimeStep / StorageSurface(OldBasinLevel);
       LD := MaxLevel - MinLevel;
       C  := - gravity * 2 * LD + B * (TotalFlow+RiverFlow);
       D  := Power(abs(B),2) + abs(4 * A * C);
       CulvertFlow := FlowDirection * (-B + SQRT(D)) / (2*A)
    end
    else CulvertFlow:=0;

    TotalFlow:=TotalFlow+CulvertFlow;          {the total flow is calculated}

    {ItCount:=ItCount+1;
    if ItCount>100 then begin exit; end;}
  until         {the iteration is repeated till certain exactness is reached}

	  (Abs(LastGapFlow[1]-GapFlow[1])<0.01)
     and ((Abs(LastGapFlow[2]-GapFlow[2])<0.01) or (NumOfGaps<2))
     and ((Abs(LastGapFlow[3]-GapFlow[2])<0.01) or (NumOfGaps<3)) or true;

  levdif:=Round(100*(maxlevel-calcminlevel))/100;

    {write(OutP,Int(100*(MaxLevel-GapDepthAtMSL[1]))/100:2:2,'  ',
		   Round(100*(MinLevel-GapDepthAtMSL[1]))/100:2:2,'  ',
		   Round(100*(CalcMinLevel-GapDepthAtMSL[1]))/100:2:2,'   ',
		   Round(100*SQRT(2*gravity*(levdif)))/100:2:2,'   ',
		   levdif:2:2);

    if (WeirSituation[GCT]=Complete) then writeln(OutP, '  CRIT')
				     else writeln(OutP, '  NORM');}

  if TotalGapSurface<>0 then TotalVelocity:=TotalFlow/TotalGapSurface
			else TotalVelocity:=0;

  for GCT:=1 to NumOfGaps do
  begin
     if (Construction[GCT]<>Finished) and
	(GapSurface[GCT]<>0) and
	(WeirSituation[GCT]<>Complete) then
	begin
	   Velocity[GCT]:=TotalVelocity;
	   GapFlow[GCT]:=TotalVelocity*GapSurface[GCT];
	end;
     {Here storm wave height has been implemented}
     if TimeToStorm<>0 then
     begin
	WDS:=WaveDuringStorm/3;
	Velocity[GCT]:=FlowDirection*SQRT(Abs(
				  2*Gravity*(MaxLevel+WDS-CalcMinLevel)));
     end;
  end;

  BasinLevel:=OldBasinLevel+                {the flow causes the basin level}
  TimeStep * (TotalFlow+RiverFlow)/            {to change. Also a river flow}
  StorageSurface(OldBasinLevel);                      {is taken into account}

  If TotalGapSurface<>0                                          {error trap}
     then Velocity0:=                          {calculate velocity at end of}
	  TotalFlow/OrigTotalGapSurface               {the bottom protection}
     else Velocity0:=0;

  if (FlowDirection <> OldFlowDirection) then     {if the flow direction has}
  begin                             {changed, call the equal-level procedure}
     Kentering;
     OldFlowDirection:=FlowDirection;
  end;
end;

procedure CalculateAngles(WayOfConstruction: IntArr; Var DSS, DSH: RealArr);

var OldDSS: RealArr;
    CoTanAngle,
    W, H, T0, T1: Real;

const TooBig=1; TooSmall=2; SizeOK=3;

var Teller: Integer;

begin
   Teller:=0;
   for GCT:=1 to NumOfGaps do
   for GCT:=1 to NumOfGaps do
   repeat
      OldDSS[GCT]:=DSS[GCT];
      MaterialSize:=SizeOK;
      Case WayOfConstruction[GCT] of
	 csTrucks: begin
	     if DamD50[GCT]<0.5 then MaterialSize:=TooSmall;
	     if (DamD50[GCT]>=0.5) and (DamD50[GCT]<=50) then
	     CoTanAngle:=5-(5-2)*(DamD50[GCT]-0.5)/(50-0.5);
	     if (DamD50[GCT]>=50) and (DamD50[GCT]<=2000) then
	     CoTanAngle:=2-(2-1.5)*(DamD50[GCT]-50)/(2000-50);
	   end;
	 csVessels: begin
	     if DamD50[GCT]<0.5 then MaterialSize:=TooSmall;
	     if (DamD50[GCT]>=0.5) and (DamD50[GCT]<=50) then
	     CoTanAngle:=10-(10-4)*(DamD50[GCT]-0.5)/(50-0.5);
	     if (DamD50[GCT]>=50) and (DamD50[GCT]<=2000) then
	     CoTanAngle:=4-(4-1.5)*(DamD50[GCT]-50)/(2000-50);
	   end;
	 csCableWay: begin
	     if DamD50[GCT]<100 then MaterialSize:=TooSmall;
	     CoTanAngle:=2-(2-1.5)*(DamD50[GCT]-50)/(2000-50);
	   end;
	 csSandDump: begin
	     if DamD50[GCT]<0.15 then begin MaterialSize:=TooSmall; end;
	     if DamD50[GCT]>50  then MaterialSize:=TooBig;
	     if (DamD50[GCT]>=0.15) and (DamD50[GCT]<=0.25) then
	     CoTanAngle:=40-(40-25)*(DamD50[GCT]-0.15)/(0.25-0.15);
	     if (DamD50[GCT]>=0.25) and (DamD50[GCT]<=0.5) then
	     CoTanAngle:=25-(25-10)*(DamD50[GCT]-0.25)/(0.5-0.25);
	     if (DamD50[GCT]>=0.5) and (DamD50[GCT]<=50) then
	     CoTanAngle:=10-(10-4)*(DamD50[GCT]-0.5)/(50-0.5);
	   end;
	 end;
	 if DamD50[GCT]=9999 then Halt;
	 if DamD50[GCT]>2000 then MaterialSize:=TooBig;
	 if (MaterialSize<>SizeOK) and (Adapting=False) then
	    begin
	       Warn_Material(MaterialSize,GCT);
	       case NumOfGaps of
		    1: Dial_GradualClose1(GradualLeft, GradualRight,
		       GradualUp, UpMaxLevel, DamD50);
		    2: Dial_GradualClose2(GradualLeft, GradualRight,
		       GradualUp, UpMaxLevel, DamD50);
		    3: Dial_GradualClose3(GradualLeft, GradualRight,
		       GradualUp, UpMaxLevel, DamD50);
	       end;
	    end
	    else
	    if WayOfConstruction[GCT]=1 then begin DSS[GCT]:=Min(ArcTan(1/CoTanAngle), DSS[GCT]);
						   DSH[GCT]:=Min(ArcTan(1/CoTanAngle), DSH[GCT]);
					     end
					else begin DSS[GCT]:=ArcTan(1/CoTanAngle);
						   DSH[GCT]:=DSS[GCT];
					     end;
   if Teller>10000 then Exit;
   until (MaterialSize=SizeOK) or (Adapting);
   for GCT:=1 to NumOfGaps do
   if (TotalDumped[GCT]<>0) and (ClosureScheme[GCT]=Horizontal) then
   begin
      W:=DamTopWidth[GCT];   H:=DamHeight[GCT];
      T0:=Tan(OLDDSS[GCT]); T1:=Tan(DSS[GCT]);
      if (t0<>0) and (t1<>0) then
      begin
	 SkippedVolumeLeft[GCT]:=(W+H/T0)*
	 (H*H*T1/(T0*T0) - H*H/T0 - SQR(H*T1/T0 - H)/T1);
	 SkippedVolumeRight[GCT]:=SkippedVolumeLeft[GCT];
      end
      else
      begin
	 SkippedVolumeLeft[GCT]:=0;
	 SkippedVolumeRight[GCT]:=0;
      end;
   end;
   CalculateRequiredVolume(GapWidth);
end;



procedure Activities;

var Dt,                       {width between toes of dam heads}
    Bb,                       {averaged width of dam section}
    A,                        {variables for A-B-C formula}
    B,
    C,
    D,                        {determinant for A-B-C formula}
    dH,                       {advance of sill top level}
    dX,                       {advance of dam head}
    OXDRL,                    {old location of  left toe, relative}
    OXDRR,                    {old location of right toe, relative}
    OYDR,                     {old sill top level}
    GapLeft,                  {location of left toe}
    GapRight,                 {location of right toe}
    ErosionLengthLeft,        {length of erosion area,  left slope}
    ErosionLengthRight,       {length of erosion area, right slope}
    ErosionLengthUp,          {length of erosion area, sill top}
    TotalErosionLength,       {Total length of erosion areas}
    ErosionLeft,              {eroded volume taken from  left slope}
    ErosionRight,             {eroded volume taken from right slope}
    ErosionUp,                {eroded volume taken from sill top}
    BotFact,		      {Factor for difference in grain diameters}
    AddFill,                  {added volume to construction area}
    SubFill,                  {eroded volume, taken from construction area}
    TotFill:                  {total volume, added or eroded from area}
    Real;
    LastProcessLeft,          {last construction phase,  left side}
    LastProcessRight,         {last construction phase, right side}
    LastProcessUp: Integer;   {last construction phase, on sill}

begin
  for GCT:=1 to NumOfGaps do
  begin
      if Construction[GCT]=Collapsed   {if construction collapsed, then stop}
	 then NoActivities;                     {all construction activities}
      if  (YDR[GCT]>=UpMaxLevel[GCT])                {if top of sill reached}
      and (GradualUp[GCT]<>0) then                {and if vertically dumping}
      begin
	 GradualUp[GCT]:=0;                   {then stop vertical activities}
      end;

						    {Erosion of Gap Material}

      if (YDR[GCT]<MaxLevel) then      {if sill top lower than maximum level}
					   {then calculate eroded quantities}
      begin
	 if DumpedLeft[GCT]<>0   then ErosionLengthLeft:=(DamYL[GCT]-YDR[GCT])/Sin(DSH[GCT])
				 else ErosionLengthLeft:=0;
	 if DumpedRight[GCT]<>0  then ErosionLengthRight:=(DamYR[GCT]-YDR[GCT])/Sin(DSH[GCT])
				 else ErosionLengthRight:=0;
	 ErosionLengthUp:=XDRR[GCT]-XDRL[GCT];
	 BotFact:=1;
	 If YDR[GCT]<OrigGapDepthAtMSL[GCT] then
	    if (StandLengthProt[GCT]<200) and
	       (ErosionPerMPerS[GCT]<>0) then
	       BotFact:=BotErosPerMPerS[GCT]/ErosionPerMPerS[GCT]
	       else BotFact:=0.0001;
	 TotalErosionLength:=ErosionLengthLeft+
			     ErosionLengthUp*BotFact+
			     ErosionLengthRight;
	 TotalErosion[GCT] :=TotalErosionLength*ErosionPerMPerS[GCT];
	 ErosionLeft  := TotalErosion[GCT]*(ErosionLengthLeft /TotalErosionLength);
	 ErosionRight := TotalErosion[GCT]*(ErosionLengthRight/TotalErosionLength);
	 ErosionUp    := TotalErosion[GCT]*(ErosionLengthUp*BotFact/TotalErosionLength);
      end
      else
      begin
	 ErosionLeft:=0;            {if both water levels are lower than the}
	 ErosionRight:=0;           {deepest construction activity, then the}
	 ErosionUp:=0;                         {erosion at all sides is zero}
	 TotalErosion[GCT]:=0;
      end;
      if (Construction[GCT]=Finished) or
	 (Construction[GCT]=Collapsed) then
	 delay(50);

      if ((GradualUp[GCT]<>0) or (ErosionUp<>0))       {if on sill something}
      and (Construction[GCT]<>Finished)                 {is dumped or eroded}
      and (YDR[GCT]<UpMaxLevel[GCT]) then        {and sill not completed yet}
      begin
							   {Vertical Closure}
	AddFill:=(GradualUp[GCT]/3600)*TimeStep;              {volume dumped}
	SubFill:=ErosionUp*TimeStep;                          {volume eroded}
	TotFill:=AddFill-SubFill;                              {total volume}
	OYDR:=YDR[GCT];
	Dt:=XDRR[GCT]-XDRL[GCT]; if Dt<0 then Dt:=0;
	Bb:=DamTopWidth[GCT]+2*(DamTop[GCT]-YDR[GCT])/Tan(DSS[GCT]);
	if YDR[GCT]<OrigGapDepthAtMSL[GCT] then
	BB:=5*OrigGapWidth[GCT];
	if WayOfConstruction[GCT]=csCableWay then          {remember whether}
						     {cableway has been used}

	begin                                     {if cableway construction:}
	   Bb:=DamTopWidth[GCT]+2*ActDamHeight[GCT]/Tan(DSS[GCT]);
	   OnceCableWay[GCT]:=cmYes;
	end;

                                         {calculate dam advance from volume.}
                                           {See manual volume I, chapter ###}
	A:=-Dt/Tan(DSS[GCT]);
	if (DumpedLeft[GCT]<>0) then A:=A+0.5*Bb/Tan(DSH[GCT]);
	if (DumpedRight[GCT]<>0) then A:=A+0.5*Bb/Tan(DSH[GCT]);
	B:=Dt*Bb;
	C:=-TotFill;
	D:=B*B-4*A*C;
	if D>=0 then
	if A<>0 then dH:=(-B+SQRT(D))/(2*A)
		 else begin dH:=0; end;
	if Sgn(dH)<>Sgn(TotFill) then dH:=0;
	YDR[GCT]:=YDR[GCT]+dH;
	if YDR[GCT]>=DamTop[GCT]-0.01 then
	begin
	   Construction[GCT]:=Finished;       {in case dam has been finished}
	   ActualVolume[GCT]:=RequiredVolume[GCT];
	   MultiBeep;                                             {play tune}
	   if (YDR[GCT]-OYDR)<>0 then if YDR[GCT]-OYDR<>0 then
	   begin
	      AddFill:=AddFill*(DamTop[GCT]-OYDR)/(YDR[GCT]-OYDR);
	      SubFill:=SubFill*(DamTop[GCT]-OYDR)/(YDR[GCT]-OYDR);
	      TotFill:=TotFill*(DamTop[GCT]-OYDR)/(YDR[GCT]-OYDR);
	   end;
	   YDR[GCT]:=DamTop[GCT];
	end;
                                              {vertical dumping also effects}
	if (Construction[GCT]<>Finished) then                {locations toes}
	begin
	  if  (DumpedLeft[GCT]<>0) then XDRL[GCT]:=XDRL[GCT]-(dH/Tan(DSH[GCT]));
	  if (DumpedRight[GCT]<>0) then XDRR[GCT]:=XDRR[GCT]+(dH/Tan(DSH[GCT]));
	end;
	DumpedUp[GCT]:=DumpedUp[GCT]+AddFill;             {add dumped volume}
	ErodedUp[GCT]:=ErodedUp[GCT]+SubFill;       {substract eroded volume}

						{if toes originally touched,}
	if TotFill>0 then              {after vertical dumping they will not}
	begin
	   if ProcessLeft[GCT] =Toes      then ProcessLeft[GCT] :=Full;
	   if ProcessLeft[GCT] =StartToes then ProcessLeft[GCT] :=Start;
	   if ProcessLeft[GCT] =Reached   then ProcessLeft[GCT] :=Full;
	   if ProcessRight[GCT]=Toes      then ProcessRight[GCT]:=Full;
	   if ProcessRight[GCT]=StartToes then ProcessRight[GCT]:=Start;
	   if ProcessRight[GCT]=Reached   then ProcessRight[GCT]:=Full;
	end;
    end;
    if (Construction[GCT]=Finished) or
	 (Construction[GCT]=Collapsed) then
	 delay(50);

    if ((GradualRight[GCT]<>0) or (ErosionRight<>0))
    and (Construction[GCT]<>Finished) then
    begin
       {Horizontal Closure from RIGHT Side}
       AddFill:=(GradualRight[GCT]/3600)*TimeStep;  {volume to be skipped is}
       AddFill:=AddFill-SkippedVolumeRight[GCT];   {extracted, process waits}
       if AddFill<0 then begin
			    SkippedVolumeRight[GCT]:=Abs(AddFill);
			    AddFill:=0;
			 end
			 else SkippedVolumeRight[GCT]:=0;
       SubFill:=ErosionRight*TimeStep;                     {calculate sum of}
       TotFill:=AddFill-SubFill;                       {constructing volumes}
       OXDRR:=XDRR[GCT]; OYDR:=YDR[GCT];
       Bb:= DamTopWidth[GCT]+
	 (DamTop[GCT]-DamYR[GCT])/Tan(DSS[GCT])+
	 (DamTop[GCT]-  YDR[GCT])/Tan(DSS[GCT]);  {A-B-C formula, see manual}
       if Bb<>0 then C:=-TotFill/Bb;
       if (ProcessRight[GCT]=Full)
       or (ProcessRight[GCT]=StartReached) then A:=0;
       if ProcessRight[GCT]=Start        then
	  A:= 0.5*(Sin(DSH[GCT])*Cos(DSH[GCT]) + SQR(Sin(DSH[GCT]))*Tan(DSH[GCT]));
       if ProcessRight[GCT]=StartToes    then
	  A:= 0.5*(Sin(DSH[GCT])*Cos(DSH[GCT]) + SQR(Sin(DSH[GCT]))*Tan(DSH[GCT])) -0.25*Tan(DSH[GCT]);
       if ProcessRight[GCT]=Reached      then A:=-0.5*Sqr(Sin(DSH[GCT]))*Tan(DSH[GCT])-0.5*(Sin(DSH[GCT])*Cos(DSH[GCT]))
						 ;
       if ProcessRight[GCT]=Toes         then A:=-0.25*Tan(DSH[GCT]);
       B:=DamYR[GCT]-YDR[GCT];
       if B<0 then B:=0;
       D:=B*B-4*A*C;
       if D<0 then begin D:=0; if a<>0 then C:=B*B/(4*A) end;
       if (A=0) and (B<>0) then dX:=-C/B
			   else if a<>0 then dX:=(-B+SQRT(D))/(2*A);

       if ProcessRight[GCT]=Start then  {application dam advance, see manual}
       begin
	  DamYR[GCT]:=DamYR[GCT]+dX*Tan(DSH[GCT]);
	  if DamYR[GCT]>DamTop[GCT] then DamYR[GCT]:=DamTop[GCT];
	  XDRR[GCT]:=XDRR[GCT]-dX;
       end;
       if ProcessRight[GCT]=StartToes then
       begin
	 DamYR[GCT]:=DamYR[GCT]+dX*Tan(DSH[GCT]);
	 if DamYR[GCT]>DamTop[GCT] then DamYR[GCT]:=DamTop[GCT];
	 YDR[GCT]:=YDR[GCT]+0.5*dX*Tan(DSH[GCT]);
	 XDRR[GCT]:=XDRR[GCT]-0.5*dX;
	 XDRL[GCT]:=XDRR[GCT];
       end;
       if ProcessRight[GCT]=StartReached then
       begin
	 DamYR[GCT]:=DamYR[GCT]+dX*Tan(DSH[GCT]);
	 if DamYR[GCT]>DamTop[GCT] then DamYR[GCT]:=DamTop[GCT]
	 else YDR[GCT]:=YDR[GCT]+dX*Tan(DSH[GCT]);
       end;
       if ProcessRight[GCT]=Full then
       begin
	 XDRR[GCT]:=XDRR[GCT]-dX;
       end;
       if ProcessRight[GCT]=Reached then
       begin
	 YDR[GCT]:=YDR[GCT]+dX*Tan(DSH[GCT]);
	 DamYL[GCT]:=YDR[GCT];
	 if DamYL[GCT]>DamTop[GCT] then DamYL[GCT]:=DamTop[GCT];
       end;
       if ProcessRight[GCT]=Toes then
       begin
	 YDR[GCT]:=YDR[GCT]+0.5*dX*Tan(DSH[GCT]);
	 XDRR[GCT]:=XDRR[GCT]-0.5*dX;
       end;

       if YDR[GCT]>=DamTop[GCT]-0.01 then        {if location where toes touch is}
			      {higher than dam top, construction is finished}
       begin
	  Construction[GCT]:=Finished;
	  ActualVolume[GCT]:=RequiredVolume[GCT];
	  MultiBeep;
	  if YDR[GCT]-OYDR<>0 then
	   begin
	      AddFill:=AddFill*(DamTop[GCT]-OYDR)/(YDR[GCT]-OYDR);
	      SubFill:=SubFill*(DamTop[GCT]-OYDR)/(YDR[GCT]-OYDR);
	      TotFill:=TotFill*(DamTop[GCT]-OYDR)/(YDR[GCT]-OYDR);
	   end;
	  YDR[GCT]:=DamTop[GCT];
       end;

       DumpedRight[GCT]:=DumpedRight[GCT]+AddFill;
       ErodedRight[GCT]:=ErodedRight[GCT]+SubFill;

      end;

      if (Construction[GCT]=Finished) or
	 (Construction[GCT]=Collapsed) then
	 delay(50);

      if ((GradualLeft[GCT]<>0) or (ErosionLeft<>0))
      and (Construction[GCT]<>Finished) then
      begin
	{Horizontal Closure from LEFT Side}
	AddFill:=(GradualLeft[GCT]/3600)*TimeStep;
	AddFill:=AddFill-SkippedVolumeLeft[GCT];
	if AddFill<0 then begin
			     SkippedVolumeLeft[GCT]:=Abs(AddFill);
			     AddFill:=0;
			  end
			  else SkippedVolumeLeft[GCT]:=0;
	SubFill:=ErosionLeft*TimeStep;
	TotFill:=AddFill-SubFill;
	OXDRL:=XDRL[GCT];
	Bb:= DamTopWidth[GCT]+
	      (DamTop[GCT]-DamYL[GCT])/Tan(DSH[GCT])+
	      (DamTop[GCT]-  YDR[GCT])/Tan(DSH[GCT]);
	if Bb<>0 then C:=-TotFill/Bb;
	if (ProcessLeft[GCT]=Full)
	or (ProcessLeft[GCT]=StartReached) then A:=0;
	if ProcessLeft[GCT]=Start          then
	   A:= 0.5*(Sin(DSH[GCT])*Cos(DSH[GCT]) + SQR(Sin(DSH[GCT]))*Tan(DSH[GCT]));
	if ProcessLeft[GCT]=StartToes    then
	   A:= 0.5*(Sin(DSH[GCT])*Cos(DSH[GCT]) + SQR(Sin(DSH[GCT]))*Tan(DSH[GCT])) -0.25*Tan(DSH[GCT]);
	if ProcessLeft[GCT]=Reached      then A:=-0.5*Sqr(Sin(DSH[GCT]))*Tan(DSH[GCT])-0.5*(Sin(DSH[GCT])*Cos(DSH[GCT]));
	if ProcessLeft[GCT]=Toes         then A:=-0.25*Tan(DSH[GCT]);
	B:=DamYL[GCT]-YDR[GCT];
	if B<0 then B:=0;

	D:=B*B-4*A*C;
	if D<0 then begin D:=0; if A<>0 then C:=B*B/(4*A) end;
	if (A=0) and (B<>0) then dX:=-C/B
	       else if A<>0 then dX:=(-B+SQRT(D))/(2*A);

	if ProcessLeft[GCT]=Start then
	begin
	   DamYL[GCT]:=DamYL[GCT]+dX*Tan(DSH[GCT]);
	   if DamYL[GCT]>DamTop[GCT] then DamYL[GCT]:=DamTop[GCT];
	   XDRL[GCT]:=XDRL[GCT]+dX;
	end;
	if ProcessLeft[GCT]=StartToes then
	begin
	   DamYL[GCT]:=DamYL[GCT]+dX*Tan(DSH[GCT]);
	   if DamYL[GCT]>DamTop[GCT] then DamYL[GCT]:=DamTop[GCT];
	   YDR[GCT]:=YDR[GCT]+0.5*dX*Tan(DSH[GCT]);
	   XDRL[GCT]:=XDRL[GCT]+0.5*dX;
	   XDRR[GCT]:=XDRL[GCT];
	end;
	if ProcessLeft[GCT]=StartReached then
	begin
	   DamYL[GCT]:=DamYL[GCT]+dX*Tan(DSH[GCT]);
	   if DamYL[GCT]>DamTop[GCT] then DamYL[GCT]:=DamTop[GCT];
	   YDR[GCT]:=YDR[GCT]+dX*Tan(DSH[GCT]);
	end;
	if ProcessLeft[GCT]=Full then
	begin
	   XDRL[GCT]:=XDRL[GCT]+dX;
	end;
	if ProcessLeft[GCT]=Reached then
	begin
	   YDR[GCT]:=YDR[GCT]+dX*Tan(DSH[GCT]);
	   DamYR[GCT]:=YDR[GCT];
	   if DamYR[GCT]>DamTop[GCT] then DamYR[GCT]:=DamTop[GCT];
	end;
	if ProcessLeft[GCT]=Toes then
	begin
	   YDR[GCT]:=YDR[GCT]+0.5*dX*Tan(DSH[GCT]);
	   XDRL[GCT]:=XDRL[GCT]+0.5*dX;
	   XDRR[GCT]:=XDRL[GCT];
	end;

	if YDR[GCT]>=DamTop[GCT]-0.01 then
	begin
	   Construction[GCT]:=Finished;
	   ActualVolume[GCT]:=RequiredVolume[GCT];
	   MultiBeep;
	   if YDR[GCT]-OYDR<>0 then
	   begin
	      AddFill:=AddFill*(DamTop[GCT]-OYDR)/(YDR[GCT]-OYDR);
	      SubFill:=SubFill*(DamTop[GCT]-OYDR)/(YDR[GCT]-OYDR);
	      TotFill:=TotFill*(DamTop[GCT]-OYDR)/(YDR[GCT]-OYDR);
	   end;
	   YDR[GCT]:=DamTop[GCT];
	end;

	DumpedLeft[GCT]:=DumpedLeft[GCT]+AddFill;
	ErodedLeft[GCT]:=ErodedLeft[GCT]+SubFill;

      end;

      {Verify actual construction situation}

			      {stop skipping if no volume left to be skipped}

      if SkippedVolumeRight[GCT]<10 then SkippedVolumeRight[GCT]:=0;
      if SkippedVolumeLeft[GCT]<10  then SkippedVolumeLeft[GCT]:=0;

    if (Construction[GCT]=Finished) or
	 (Construction[GCT]=Collapsed) then
	 delay(50);

      if Construction[GCT]<>Finished then
      begin
	 {side levels of dam can never be higher than sill top!}
	 if DamYL[GCT]<YDR[GCT] then DamYL[GCT]:=YDR[GCT];
	 if DamYR[GCT]<YDR[GCT] then DamYR[GCT]:=YDR[GCT];

	 LastProcessLeft:=ProcessLeft[GCT];                   {remember last}
	 LastProcessRight:=ProcessRight[GCT];            {construction phase}


	 {in the lines below, the administration of construction}
	 {phases is handled. See manual volume I, page ### for a}
	 {detailed description of the possible phases of construction}

	 if (XDRL[GCT]<(DamTop[GCT]-YDR[GCT])/Tan(DSH[GCT])) then
	 begin
	    if LastProcessLeft =Reached then ProcessLeft[GCT]:=StartReached;
	    if LastProcessLeft =Toes    then ProcessLeft[GCT]:=StartToes;
	 end
	 else
	 if DamYL[GCT]=DamTop[GCT] then
	 begin
	    if ProcessLeft[GCT]=Start        then ProcessLeft[GCT]:=Full;
	    if ProcessLeft[GCT]=StartReached then ProcessLeft[GCT]:=Reached;
	    if ProcessLeft[GCT]=StartToes    then ProcessLeft[GCT]:=Toes;
	 end;

	 if (XDRR[GCT]>(OrigGapWidth[GCT]-(DamTop[GCT]-YDR[GCT])/Tan(DSH[GCT]))) then
	 begin
	    if LastProcessRight=Reached then ProcessRight[GCT]:=StartReached;
	    if LastProcessRight=Toes    then ProcessRight[GCT]:=StartToes;
	 end
	 else
	 if DamYR[GCT]=DamTop[GCT] then
	 begin
	    if ProcessRight[GCT]=Start        then ProcessRight[GCT]:=Full;
	    if ProcessRight[GCT]=StartReached then ProcessRight[GCT]:=Reached;
	    if ProcessRight[GCT]=StartToes    then ProcessRight[GCT]:=Toes;
	 end;

	 if (XDRR[GCT]<=0) then
	 begin
	    XDRR[GCT]:=0;
	    XDRL[GCT]:=0;
	    ProcessLeft[GCT]:=StartToes;
	    if ProcessRight[GCT]=Full      then ProcessRight[GCT]:=Reached;
	    if ProcessRight[GCT]=Start     then ProcessRight[GCT]:=StartReached;
	    if ProcessRight[GCT]=Toes      then ProcessRight[GCT]:=Reached;
	    if ProcessRight[GCT]=StartToes then ProcessRight[GCT]:=StartReached;
	 end
	 else
	 begin
	    If ProcessRight[GCT]=Reached      then ProcessRight[GCT]:=Full;
	    If ProcessRight[GCT]=StartReached then ProcessRight[GCT]:=Start;
	 end;

	 if (XDRL[GCT]>=OrigGapWidth[GCT]) then
	 begin
	    XDRR[GCT]:=OrigGapWidth[GCT];
	    XDRL[GCT]:=OrigGapWidth[GCT];
	    ProcessRight[GCT]:= StartToes;
	    if ProcessLeft[GCT]=Full      then ProcessLeft[GCT]:=Reached;
	    if ProcessLeft[GCT]=Start     then ProcessLeft[GCT]:=StartReached;
	    if ProcessLeft[GCT]=Toes      then ProcessLeft[GCT]:=Reached;
	    if ProcessLeft[GCT]=StartToes then ProcessLeft[GCT]:=StartReached;
	 end
	 else
	 begin
	    if ProcessLeft[GCT]=Reached      then ProcessLeft[GCT]:=Full;
	    if ProcessLeft[GCT]=StartReached then ProcessLeft[GCT]:=Start;
	 end;

	 if YDR[GCT]>=DamTop[GCT]-0.01 then              {last check for finished}
	 begin                                                 {construction}
	   Construction[GCT]:=Finished;
	   ActualVolume[GCT]:=RequiredVolume[GCT];
	   Multibeep;
	   if (YDR[GCT]-OYDR)<>0 then if YDR[GCT]-OYDR<>0 then
	   begin
	      AddFill:=AddFill*(DamTop[GCT]-OYDR)/(YDR[GCT]-OYDR);
	      SubFill:=SubFill*(DamTop[GCT]-OYDR)/(YDR[GCT]-OYDR);
	      TotFill:=TotFill*(DamTop[GCT]-OYDR)/(YDR[GCT]-OYDR);
	   end;
	   YDR[GCT]:=DamTop[GCT];
	 end;

	 if (ActSeaLevel-YDR[GCT]<VesselDraft)    {if too shallow for barges}
	 and (GradualUp[GCT]<>0) 		       {and actually dumping}
	 and (WayOfConstruction[GCT]=csVessels)         {choose other method}
	 then begin
	    Warn_VesselDraft;
	    NoActivities;
	    case NumOfGaps of                             {show dialog boxes}
	    1: begin
	       Dial_Methods1(WayOfConstruction);
	       Dial_GradualClose1(GradualLeft, GradualRight, GradualUp, UpMaxLevel, DamD50);
	       end;
	    2: begin
	       Dial_Methods2(WayOfConstruction);
	       Dial_GradualClose2(GradualLeft, GradualRight, GradualUp, UpMaxLevel, DamD50);
	       end;
	    3: begin
	       Dial_Methods3(WayOfConstruction);
	       Dial_GradualClose3(GradualLeft, GradualRight, GradualUp, UpMaxLevel, DamD50);
	       end;
	    end;
	 end;

	 if (XDRL[GCT]>=XDRR[GCT]) and (ProcessRight[GCT]<>Reached)
				   and (ProcessLeft[GCT] <>Reached) then
	 begin
	    if ProcessRight[GCT]=Start then ProcessRight[GCT]:=StartToes;
	    if ProcessRight[GCT]=Full  then ProcessRight[GCT]:=Toes;
	    if ProcessLeft[GCT] =Start then ProcessLeft[GCT] :=StartToes;
	    if ProcessLeft[GCT] =Full  then ProcessLeft[GCT] :=Toes;
	    XDRL[GCT]:=XDRR[GCT];
	 end;

					 {add constructed and eroded volumes}

	 TotalDumped[GCT]:=DumpedLeft[GCT]+DumpedRight[GCT]+DumpedUp[GCT];
	 TotalEroded[GCT]:=ErodedLeft[GCT]+ErodedRight[GCT]+ErodedUp[GCT];
	 ActualVolume[GCT]:=TotalDumped[GCT]-TotalEroded[GCT];

	 if (TotalDumped[GCT]>0) then SomethingDumped:=True
				 else SomethingDumped:=False;

    end;
  end;

  for GCT:=1 to NumOfGaps do
  begin
					       {determine location  left toe}
     GapLeft :=XDRL[GCT]-0.5*(DamYL[GCT]-YDR[GCT])/Tan(DSH[GCT]);
     if GapLeft<0 then GapLeft:=0;
					       {determine location right toe}
     GapRight:=XDRR[GCT]+0.5*(DamYR[GCT]-YDR[GCT])/Tan(DSH[GCT]);
     if GapRight>OrigGapWidth[GCT] then GapRight:=OrigGapWidth[GCT];

     GapWidth[GCT]:=GapRight-GapLeft; {gap width is difference toe locations}

     if GapWidth[GCT]<0.01 then GapWidth[GCT]:=0;

					    {determine actual closure method}
     ClosureScheme[GCT]:=Vertical; ClosureDirection[GCT]:=Up;

     if (DumpedLeft[GCT]>0) or (DumpedLeft[GCT]>0) then
     ClosureScheme[GCT]:=Horizontal;

     if (DumpedLeft[GCT]>0)  then ClosureDirection[GCT]:=Left;
     if (DumpedRight[GCT]>0) then ClosureDirection[GCT]:=Right;
     if (DumpedLeft[GCT]>0) and (DumpedRight[GCT]>0) then
				  ClosureDirection[GCT]:=Both;

     if (DamTop[GCT]-OrigGapDepthAtMSL[GCT])*OrigGapWidth[GCT] <> 0 then
	 Percentage[GCT]:=
	    Round(100-100*GapWidth[GCT]*
	    (DamTop[GCT]-GapDepthAtMSL[GCT])/
	    ((DamTop[GCT]-OrigGapDepthAtMSL[GCT])*OrigGapWidth[GCT]))
	  else
	 Percentage[GCT]:=0;
  end;
  for GCT:=1 to NumOfGaps do
	ActDamHeight[GCT]:=Max(YDR[GCT],Max(DamYL[GCT], DamYR[GCT]))
			   -OrigGapDepthAtMSL[GCT];
end;

procedure Calcul_ScouringIntegral;

var Alpha10,            {turbulence factor for Lbp/Hw = 10}
    AlphaArea,
    Alpha,              {turbulence factor for actual situation}
    EquiVelocity,       {Velocity in equilibrium profile of channel}
    VelocityEndBP,      {velocity at end of bottom protection}
    VelocityDif,        {difference between acting and critical velocity}
    RealShadowLeft,     {shadow zone  left, in meters}
    RealShadRight,      {shadow zone right, in meters}
    SnapPlace,          {width section counter, in meters}
    RealShearLeft,      {turbulence zone left,  in meters}
    RealShearRight,     {turbulence zone right, in meters}
    SnapShearLeft,      {turbulence zone  left, in width sections}
    SnapShearRight,     {turbulence zone right, in width sections}
    ME, MP,	        {Constant from sediment transport formula}
    ReducE,
    ReducP: Real;       {Partial reduction for this time step}

begin

   {FOR CALCULATION OF SCOUR HOLE DEPTH}
   TimeSinceKent:=TimeSinceKent+TimeStep;           {advance time since last}
						     {time levels were equal}
   CriticVelocity:=                             {calculate critical velocity}
       Chezy*SQRT(0.04*Delta*BottomD50/1000);

   if (Construction[GCT]=Finished) or
	 (Construction[GCT]=Collapsed) then
	 delay(50);


   for GCT:=1 to NumOfGaps do                         {for all gaps, if they}
   if  (Construction[GCT]<>Collapsed)                {are have not collapsed}
   and (Construction[GCT]<>Finished)                      {nor been finished}
   and (StandLengthProt[GCT]<>0) then      {if the bottom has been protected}

   begin
     RealShadowLeft:=XDRL[GCT]-0.5*(DamYL[GCT]-YDR[GCT])/Tan(DSS[GCT])-
			       (1/12)*StandLengthProt[GCT];      {shadow zone}
     if RealShadowLeft<0 then RealShadowLeft:=0;          {not left from gap}
     ShadowLeft[GCT]:=T(RealShadowLeft/SnapWidth[GCT]);    {truncated border}
     if ShadowLeft[GCT]=0 then ShadowLeft[GCT]:=-1;

     RealShadRight:=XDRR[GCT]+0.5*(DamYR[GCT]-YDR[GCT])/Tan(DSS[GCT])+
		    (1/12)*StandLengthProt[GCT];         {same for right side}

     if RealShadRight>OrigGapWidth[GCT] then
	RealShadRight:=OrigGapWidth[GCT];
     ShadowRight[GCT]:=T(RealShadRight/SnapWidth[GCT]);
     if ShadowRight[GCT]=NumOfSnaps[GCT] then
	ShadowRight[GCT]:=NumOfSnaps[GCT]+1;

     AlphaArea:=0;
     for GCT:=1 to NumOfGaps do
     if TotalDumped[GCT]=0
	 then AlphaArea:=AlphaArea+abs(GapWidth[GCT]*OrigGapDepthAtMSL[GCT])
	 else AlphaArea:=AlphaArea+abs(GapSurface[GCT]);

     for SC:=0 to NumOfSnaps[GCT] do                 {for each width section}
     Begin
	SnapPlace:=SC*SnapWidth[GCT];         {determine location of section}

	Alpha10:=AlphaMin+(                     {calculate turbulence factor}

	(OrigTotalGapSurface-AlphaArea)/OrigTotalGapSurface)
				*(AlphaMaxDepth-AlphaMin);

	RealShearLeft:=                                   {shear zone border}
			(XDRL[GCT]+(1/16)*StandLengthProt[GCT]);
	RealShearRight:=(XDRR[GCT]-(1/16)*StandLengthProt[GCT]);

	if XDRL[GCT]=0  then RealShearLeft:=0;      {cannot be left from gap}
	if XDRR[GCT]=OrigGapWidth[GCT] then RealShearRight:=OrigGapWidth[GCT];

	SnapShearLeft  :=T(RealShearLeft/SnapWidth[GCT]);  {same, but now in}
	SnapShearRight :=T(RealShearRight/SnapWidth[GCT]);   {section widths}

	if (SC<=SnapShearLeft)  and (XDRL[GCT]<>0) or
	   (SC>=SnapShearRight) and (XDRR[GCT]<>OrigGapWidth[GCT])

		then Alpha10:=Alpha10+(             {in turbulence zone, the}
						       {turbulence factor is}
	(OrigTotalWidth-TotalWidth)/OrigTotalWidth)          {locally higher}
				*(AlphaMaxWidth-AlphaMin);


	if FlowDirection=OutFlow      {calculation is done with local length}
						   {of the bottom protection}

	   then LocalProtLength:=LastProtOut[GCT,SC]*ProtSection[GCT]
	   else LocalProtLength:=LastProtIn[GCT,SC]*ProtSection[GCT];

	if ((RealShadRight-RealShadowLeft)*           {calculate velocity at}
	   (ActSeaLevel-OrigGapDepthAtMSL[GCT]))<>0   {end of the protection}
	   then VelocityEndBP:=GapFlow[GCT]/
	   ((RealShadRight-RealShadowLeft)*           {if the gap is closed,}
	   (ActSeaLevel-OrigGapDepthAtMSL[GCT]))      {this velocity is zero}
	   else VelocityEndBP:=99;

	if (SnapPlace>=RealShadowLeft) and              {else, this velocity}
	   (SnapPlace<=XDRL[GCT]) and                       {is the gap flow}
	   (XDRL[GCT]-RealShadowLeft<>0) then           {divided by the area}
		VelocityEndBP:=VelocityEndBP *       {between the turbulence}
		(SnapPlace-RealShadowLeft)/                           {zones}
		(XDRL[GCT]-RealShadowLeft);

	if (SnapPlace>=XDRR[GCT]) and                    {idem for the other}
	   (SnapPlace<=RealShadRight) and                   {turbulence zone}
	   (XDRR[GCT]-RealShadRight<>0) then
		VelocityEndBP:=VelocityEndBP *
		(SnapPlace-RealShadRight)/
		(XDRR[GCT]-RealShadRight);

	if (SnapPlace<RealShadowLeft) or            {in the shadow zone, the}
	(SnapPlace>RealShadRight) then           {velocity at the end of the}
	VelocityEndBP:=0;                  {protection is assumed to be zero}

	Alpha:=1.5+(1.57*Alpha10 - 2.35)*          {calculate alpha with the}
	       Power(e,-(0.045*LocalProtLength/ {actual protection and depth}
	       abs(OrigGapDepthAtMSL[GCT])));

	if GapSurface[GCT]<>0 then
	begin
	   VelocityDif:=                                      {calculate the}
	      abs(Alpha*VelocityEndBP) - CriticVelocity;  {scouring velocity}
	   if (VelocityDif<0) then VelocityDif:=0;       {and accumulate the}
	   VelocityDif:=VelocityDif*Sgn(VelocityEndBP);   {scouring integral}
	   If StaticsOn then VelocityDif:=Abs(
	   StaticAlpha*StaticVelocityEndBP -		 {(Static Situation)}
	   CriticVelocity);
							       {according to}
	   AUUC34[GCT, SC]:=AUUC34[GCT, SC]+              {Breuser's formula}
	     Power(abs(VelocityDif), 1.7) * TimeStep;
	end;
	if FlowDirection=InFlow then
	if VelocityEndBP<>0
	then Write(OutP, Int(VelocityEndBP*10)/10:3:1,' ')
	else Write(OutP, 'shd ');
     end;
     if FlowDirection=InFlow then
     WriteLn(OutP,'   ',{int(100*AlphaArea/OrigTotalGapSurface):2:0,'  ',
			int(100*TotalWidth/OrigTotalWidth):2:0{,'  ',}
			int(10*Velocity[1])/10:2:1);

     {FOR CALCULATION OF BETA}
     if (Construction[GCT]<>Finished)          {accumulate velocity integral}
     and (Construction[GCT]<>Collapsed) then             {for calculation of}
	U02:=U02+(VelocityEndBP*VelocityEndBP*TimeStep);        {scour angle}

      {FOR CALCULATION OF TRANSPORT REDUCTION}
      if (Construction[GCT]<>Finished) and       {if scouring still relevant}
      (Construction[GCT]<>Collapsed) then
      begin
			 {calculate transport at end of bottom protection as}
			   {reduction of the scour process behind protection}
	    EquiVelocity:=TotalFlow/OrigTotalGapSurface;
	    ME:=0.084/(Power(Chezy,3)*
	    SQRT(Gravity)*SQR(Delta)*
	    (BottomD50/1000));
	    MP:=6.56E+18*2600*Power(Gravity, 1.5);
	    ReducE:=ME*Power(Abs(EquiVelocity),5);
	    if BottomD50>100 then
	    begin
	       ReducP:=MP*SQR(SQR(SQR(SQR(SQR(Abs(EquiVelocity/
		       (Chezy*Power(Delta,0.484375)*
		       Power(BottomD50/1000,0.4531))))))));
	       ReducPerM:=ReducPerM+Min(ReducE, ReducP)*TimeStep;
	    end
	    else ReducPerM:=ReducPerM+ReducE*TimeStep;
       end;
   end;
end;

procedure BedDestruction;                     {CALCULATION OF SCOURING HOLES}

begin
    {As the calculation of scouring holes is only done once a tide,}
    {the procedure for loss which is continuously called only}
    {accumulates the scouring integral according to Breusers.}

    Calcul_ScouringIntegral;
end;

procedure DamDestruction;               {CALCULATION OF LOSS OF DAM MATERIAL}

var ME, MP,
    ErosE, ErosP: Real;
    BL, SQBL, SQEPM: Real;

begin
   for GCT:=1 to NumOfGaps do
   begin
						   {Calculate Erosion Dam Material}
      ME:=0.084/(Power(Chezy,3)*SQRT(Gravity)*SQR(Delta)*(DamD50[GCT]/1000));
      MP:=6.56e+18*2600*Power(gravity, 1.5);
      ErosE:=ME*Power(Abs(Velocity[GCT]*CrestMult[GCT]),5);
      if DamD50[GCT]>100 then
      begin
	 ErosP:=MP*SQR(SQR(SQR(SQR(SQR(
	     Abs(Velocity[GCT]*CrestMult[GCT]/
	     (Chezy*Power(Delta,0.484375)*Power(DamD50[GCT]/1000,0.4531))))))));
	 ErosionPerMPerS[GCT]:=Min(ErosE, ErosP);
      end
      else ErosionPerMPerS[GCT]:=ErosE;

				{Calculate Erosion Bottom Material At Dam Location}
      ME:=0.084/(Power(Chezy,3)*SQRT(Gravity)*SQR(Delta)*(BottomD50/1000));
      ErosE:=ME*Power(Abs(Velocity[GCT]*CrestMult[GCT]),5);
      if BottomD50>100 then
      begin
	 ErosP:=MP*SQR(SQR(SQR(SQR(SQR(
	      Abs(Velocity[GCT]*CrestMult[GCT]/
	     (Chezy*Power(Delta,0.484375)*Power(BottomD50/1000,0.4531))))))));
	 BotErosPerMPerS[GCT]:=Min(ErosE, ErosP);
      end
      else BotErosPerMPerS[GCT]:=ErosE;
    end;
end;

Procedure StormCheck;                          {CHECK WHETHER A STORM OCCURS}

var RN: Real; {Random variable}

begin
   Randomize;                                            {Shuffle randomizor}
   RN:=Random(10000)/10000;          {Determine random number smaller than 1}
   if RN<StormChance then             {if the random number smaller than the}
   begin                                          {actual storm chance, then}
      TimeToStorm:=StormPeriod*3600;     {start storm by setting the counter}
   end;
end;

Procedure ZipCheck;  {CHECK WHETHER A DUMPING INACCURACY HAS CAUSED COLLAPSE}

begin
   if (Zipped[GCT]=True) and (SomeZipped=False) then                   {if a deeper stone has moved}
   begin
      SomeZipped:=True;
      MultiBeep; MultiBeep; MultiBeep;               {then play warning tune}
      for GCT:=1 to NumOfGaps do
      begin
	 NoActivities;                     {stop all construction activities}
	 Zipped[GCT]:=True;                              {reset warning flag}
	 Construction[GCT]:=Collapsed;      {set construction flag collapsed}
      end;
   end;
end;

Procedure Calculate;            {MAIN PROCEDURE FOR CALCULATION OF PROCESSES}

var SecEtm: Real; {Timestep truncated number of seconds in one day}

begin

   ActSeaLevel:=                     {Calculate actual sealevel with respect}
      SeaLevel(MeanSeaLevel,       {to the relevant parameters. Function for}
	       TideAmp,                    {sea level determination has been}
	       TidePeriod,           {implemented in the unit named SIMTOOLS}
	       TidePhase0,
	       JobHours);

   Calcul_Komberg;                        {Calculate levels-flows-velocities}

   If JobHours>3 then                  {the first three hours the level-flow}
      if (ONOG=NumOfGaps) then         {relation needs time to settle. After}
      begin                               {this, the erosions are calculated}
	 DamDestruction;                                {of the dam material}
	 BedDestruction;                            {and of the bed material}
      end
      else
	 Delay(50);

   if (ONOG=NumOfGaps)                                           {error trap}
   then Activities;                                {execute human activities}

   AdvanceTime(T(TimeStep));                  {advance the time one timestep}

   SecEtm:=Int(3600*24/TimeStep)*TimeStep;
   if ((JobHours*3600/SecEtm)
   =Int(JobHours*3600/SecEtm))                          {if storm check time}
   or (StormChance=1)                                {or storm button chosen}
   and (TimeToStorm=0) then                      {and no storm happening yet}
   begin StormCheck; end;             {then look whether it is time to storm}


   if (WayOfConstruction[GCT]=csVessels) or
      (WayOfConstruction[GCT]=csCableWay) then
   ZipCheck            {check whether the dumping inaccuracy caused collapse}
   else Zipped[GCT]:=False;

End;

end.