{**********************************************************}
{         CLOSIM v 1.00  --  VARIABLE AND CONSTANT UNIT    }
{**********************************************************}
{ Containing the global variables and constants for the    }
{ simulation program on the Closure of Tidal Basins.       }
{ Written in Turbo Pascal 7.0 by Mark Middag, TUDelft, 1994}
{**********************************************************}

Unit SimVars;                       {GLOBAL VARIABLES FOR SIMULATION PROGRAM}
                                             {ON THE CLOSURE OF TIDAL BASINS}
Interface

Uses Dos;                                    {Dos used only for type PATHSTR}

type RealArr = Array[1..5] of Real;    {Reals, for gap and tidal information}
     IntArr  = Array[1..3] of Integer;        {Integers, for gap information}

     RecString  = String[45];                  {String type for dialog input}
     FileString = PathStr;               {String type for file specification}

const


{== GLOBAL CONSTANTS FOR THE SIMULATION PROGRAM ============================}

    ProgName = 'CLOSIM';                                       {Program Name}
    Ver = '1.0';                                            {Program Version}

    WinNum: Integer    = 0;                                  {Window Counter}
    dpTV1Dialog        = 1000;               {Color pointer for Dialog Boxes}
    hcColorSel         = 1001;                    {Color selector variable 1}
    cmSetColors        = 210;                     {Color selector variable 2}
    cmDosCriticalError = 212;                                 {Error command}


{== MENU CONSTANTS FOR TURBO VISION GRAPHICS ===============================}

    cmOverallWindow    = 214;          {Overall graphical information window}
    cmDataBoxWindow    = 216;                 {Overall numerical data window}
    cmOptionsSave      = 220;                             {Save, menu option}
    cmOptionsLoad      = 222;                             {Load, menu option}
    cmAbout            = 238;                        {Information on program}
    cmLogFiles         = 255;
    cmDefault          = 256;                {Load default closure situation}
    cmInitiateProcess  = 114;                    {Initiate closure situation}
    cmAdaptAll         = 115;				     {Adapt All Data}
    cmStart            = 116;                     {Start calculation process}
    cmInterr           = 118;                 {Interrupt calculation process}
    cmProcessToggle    = 120;           {Start or interrupt (toggle) process}
    cmToggleSound      = 122;                       {Toggle sound: ON or OFF}
    cmSelectColors     = 126;                   {Color selector, menu option}
    cmDateTime         = 128;                       {Set basin date and time}
    cmBasin            = 130;                    {Set basin storage function}
    cmClosure	       = 132;                {Set global closure information}
    cmDepthsWidths     = 134;                 {Set depths and widths of gaps}
    cmTide             = 140;                          {Set tidal conditions}
    cmRiverData        = 142;                                {Set river data}
    cmDimensions       = 144;                            {Set dam dimensions}
    cmMethods          = 145;			            {Building Method}
    cmVesselDraft      = 146;                              {Draft of Vessels}
    cmAngles	       = 147;                   {Set dam side and head angle}
    cmProtection       = 150;                      {Set length of protection}
    cmGradualClose     = 152;                {Set productions and activities}
    cmDefStorm	       = 154;                                {Define a storm}
    cmStartStorm       = 156;                                 {Start a storm}
    cmCaissonClose     = 158;                  {Caisson closure, now unabled}
    cmCulvert          = 160;                               {Build a culvert}
    cmHelpOnTopics     = 162;                                   {Help option}
    cmIntro            = 163;	         		  {Intro explanation}


{== PERIODS FOR TIDAL COMPONENTS ===========================================}

    PeriodM2 = 44100;            {Period of M2 component of tidal wave, in m}
    PeriodS2 = 43200;            {Period of S2 component of tidal wave, in m}
    PeriodK1 = 22050;            {Period of K1 component of tidal wave, in m}
    PeriodO1 = 21600;            {Period of O1 component of tidal wave, in m}


{== VARIOUS CONSTANTS FOR SIMULATION PROGRAM ===============================}

    Left  = 0;           Horizontal = 1;             {Answers and directions}
    Right = 1;           Vertical   = 2;
    Both  = 2;           cmYes      = 1;
    Up    = 3;           cmNo       = 0;

    OutFlow=-1;                                   {Definition FlowDirections}
    Closed=0;
    InFlow=1;

    Complete=1;                      {Values for weir and overfall situation}
    InComplete=-1;
    Opened=1;

    Busy=1;                                   {Values for construction phase}
    Finished=2;
    Interrupted=0;
    Collapsed=3;

    Good=0;                                  {Qualities of Bottom Protection}
    Bad=1;

    Gravity=9.81;                                                   {Gravity}
    Delta=1.65;                             {delta (mass) for rocky material}

    e=2.7182818;                                          {Natural logarithm}

    AlphaMin=1.5;                                 {Turbulence, minimum value}
    AlphaMaxDepth=4;               {Maximum turbulence for depth restriction}
    AlphaMaxWidth=6;               {Maximum turbulence for width restriction}

    FormFact=20;                                {Form factor for Scour Holes}

    ScourRed=True;     {Apply Scour Reduction or not (Programmer's use only)}

    NotBegun     = 0;                               {Possible Closure Status}
    Start        = 1;
    StartReached = 2;
    StartToes    = 3;
    Full         = 4;
    Reached      = 5;
    Toes         = 6;

    csTrucks     = 0;                                {Construction by Trucks}
    csVessels    = 1;                               {Construction by Vessels}
    csCableWay   = 2;                              {Construction by Cableway}
    csSandDump   = 3;                          {Construction by Sand Dumping}

    DegToPi = 2*Pi/360;                  {Conversion factor, degrees to rads}
    PiToDeg = 1/DegToPi;                 {Conversion factor, rads to degrees}

var

{== JOB TIME VARIABLES =====================================================}

    BasinYear,
    BasinMonth,
    BasinDay,
    BasinHour,
    BasinMinute: String;                        {For Job Time Administration}

    JobDayNo: Integer;                                {Number of day in week}

    DayS: String[12];                                   {Name of day in week}


{== STORAGE SURFACE OF BASIN ===============================================}

    KomDepth,                         {Data Points X:   Level of basin, in m}
    KomSur: RealArr;                 {Data Points Y: Surface of basin, in m2}


{== VARIABLES FOR STORM ====================================================}

    StormSurge,                          {Maximum possible storm setup, in m}
    WaveDuringStorm,
    ActStormSurge,                                 {Actual storm setup, in m}
    StormPeriod,                              {Total duration of storm, in h}
    StormChance,                         {Probability of storm occurrance, -}
    TimeToStorm: Real;                    {Time left of storm duration, in s}


{== TIME VARIABLES FOR CALCULATIONS ========================================}

    TimeStep,
    InitTimeStep,
    JobHours,                                       {Number of process hours}
    OldJobHours,                                                 {Last value}
    FictiveTime,                           {See manual volume I, chapter ###}
    YearDay,                        {Day of Year for calculation of week day}
    WX1,WY1,WDX,WDY,                                         {Draw variables}
    OWX1,OWY1,OWDX,OWDY: Real;


{== VARIOUS COUNTERS FOR PROGRAM ===========================================}

    NumOfGaps,                                 {Total number of closure gaps}
    ONOG,                                       {Last number of closure gaps}
    Counter,                                           {First global counter}
    Counter2,                                         {Second global counter}
    SC,                                               {Width section counter}
    GCT,                                                {Closure gap counter}
    PSC,                                           {Scour hole slope counter}
    Control,                                        {Global control variable}
    DrawCounter,                                       {Counter for drawings}
    NumOfKenterings: Integer;               {Number of equal levels occurred}

    OChanged,

    Dummy: Real;                  {Real dummy variable, for programmer's use}
    DumInt: Integer;           {Integer dummy variable, for programmer's use}

    NumOfSnaps: IntArr;                            {Number of width sections}


{== GLOBAL VARIABLES ON FLOWS AND LEVELS ===================================}

    FlowDirection,                             {Direction of flow in channel}
    OldFlowDirection: Integer;        {Previous direction of flow in channel}

    MaxLevel: Real;          {The maximum level of sea and basin level, in m}


{== GLOBAL VARIABLES FOR CONSTRUCTION AND EROSION ==========================}

    GradualLeft,                         {Production from Left Side, in m3/h}
    GradualRight,                       {Production from Right Side, in m3/h}
    GradualUp,                                 {Vertical production, in m3/h}
    UpMaxLevel,                           {Required top level for sill, in m}
    VerticalInAcc,                    {Inaccuracy for vertical dumping, in m}
    DamTopWidth, ODamTopWidth,                       {Top Width of dam, in m}
    DamTop,                                {Required Top Height of dam, in m}
    DamHeight,                                 {Required Heigth of dam, in m}
    ActDamHeight,                                {Actual Height of dam, in m}
    DSH,                       {Angle for head of horizontal construction, -}
    DSS,                          {Side angle for section of construction, -}
    DamD50,                                      {D50 of dam material, in mm}
    VeloInAcc,                               {Velocity in inaccuracy, in m/s}
    CritVelo,			    {Critical velocity in inaccuracy, in m/s}
    InAccVeloFact: RealArr;               {Velocity factor for inaccuracy, -}

    MaterialSize: Word;				   {Check for Material Sizes}

    InAccuracyLevel,              {Water level according to inaccuracy, in m}
    InAccMinLevel  : Real;      {Minimum level according to inaccuracy, in m}

    OnceCableWay: Array[1..3] of Word;             {Flag for use of cableway}

    ClosureScheme,              {Actual activity scheme, horizontal/vertical}
    ClosureDirection,                      {Actual direction of construction}

    YDR,                                 {Actual Level of sill or toes, in m}
    XDRL,                                           {Left toe location, in m}
    XDRR,                                          {Right toe location, in m}
    DamYL,                                             {Left top level, in m}
    DamYR,                                            {Right top level, in m}
    DumpedLeft,                       {Quantity produced on left side, in m3}
    DumpedRight,                     {Quantity produced on right side, in m3}
    DumpedUp,                           {Quantity produced vertically, in m3}
    ErodedLeft,                       {Quantity eroded from left side, in m3}
    ErodedRight,                     {Quantity eroded from right side, in m3}
    ErodedUp,                              {Quantity eroded from sill, in m3}
    oYDR,                              {Previous level of sill or toes, in m}
    oXDRL,                                 {Previous left toe location, in m}
    oXDRR,                                {Previous right toe location, in m}
    oDamYL,                                   {Previous left top level, in m}
    oDamYR,                                  {Previous right top level, in m}
    ActualVolume,                               {Actual volume of dam, in m3}
    RequiredVolume,                           {Required volume of dam, in m3}
    TotalDumped,                      {Total dumped quantity till now, in m3}
    TotalEroded,                      {Total eroded quantity till now, in m3}
    ErosionPerMPerS,                    {Actual erosion per width, in m3/m/s}
    BotErosPerMPerS,		     {Erosion of bottom per width, in m3/m/s}
    TotalErosion,                   {Total actual erosion quantity, in m3/dT}

    SkippedVolumeLeft,                          {Skipped volume at left side}
    SkippedVolumeRight: RealArr;               {Skipped volume at right side}

    Percentage,
    WayOfConstruction,                                  {Construction Method}
    HorOn, VerOn,			      {For Construction Dialog Boxes}
    ProcessRight, ProcessLeft: IntArr;                  {Construction Phases}


{== BOTTOM PROTECTION AND SCOUR HOLES ======================================}

    ProtQuality: IntArr;                       {Quality of bottom protection}

    StandLengthProt,                {Start length of bottom protection, in m}
    SnapWidth: RealArr;            {Section width of bottom protection, in m}

    AUUC34,                                    {Breuser's integral for scour}
    LastProtIn,    {Last protecting section of bottom protection, basin side}
    LastProtOut,                     {idem for sea side of bottom protection}
    InHoleDepth,        {Reduced scour hole depth for sections at basin side}
    OutHoleDepth,                             {Idem for sections at sea side}
    InHoleScour,                           {Scour for sections at basin side}
    OutHoleScour,                             {Idem for sections at sea side}
    oInHoleDepth,                                      {Idem, previous value}
    oOutHoleDepth: Array[1..3, 0..40] of Real;         {Idem, previous value}

    MaxInHole,                {Maximum scour hole depth for basin side, in m}
    MaxOutHole,                                    {Idem, for sea side, in m}
    MaxInHolePlace,          {Location of max. scour depth, basin side, in m}
    MaxOutHolePlace: RealArr;                      {Idem, for sea side, in m}

    U02,            {Integral for square of velocities, for angles, in m2/s2}
    ReducPerM,                               {Reduction on scour, in m3/m/dT}
    TimeSinceKent,             {Time since last time levels were equal, in s}
    Beta,                         {Angle of scour hole at protection side, -}
    CriticVelocity,          {Critical velocity for Breuser's formula,in m/s}
    Chezy,                                    {Chezy bottom roughness, in ()}
    BottomD50,                                {D50 of bottom material, in mm}
    LastVelocity,
    TotalVelocity,
    Velocity0: Real;   {Current velocity at end of bottom protection, in m/s}

    StaticAlpha,
    StaticVelocityEndBP: Real;		      {For programmer's testing only}

    ProtSection: RealArr;               {Length of protection sections, in m}

    InProtY,                                   {Protection settlements, in m}
    OutProtY: Array[1..3, 0..40, 0..20] of Real;

    LocalProtLength: Real;                 {Local length of protection, in m}

    ShadowLeft, ShadowRight: IntArr;   {Shadow zone length, in # of sections}


{== GAP INFORMATION ========================================================}

    GapDepthAtMSL,        OrigGapDepthAtMSL,       {Depth, Width and Surface}
    GapWidth,             OrigGapWidth,             {of gaps in m and m2 and}
    GapSurface,           OrigGapSurface,              {their initial values}

    GapMu,                               {contraction factor for each gap, -}
    GapFlow,                                 {Flow through each gap, in m3/s}
    LastGapFlow,                        {Previous value of gap flow, in m3/s}
    VeloReal,
    Velocity,                               {Current velocity in gap, in m/s}
    CrestMult: RealArr;             {Crest velocity multiplication factor, -}

    OrigTotalWidth,                     {Initial width sum of all gaps, in m}
    TotalWidth,                          {Actual width sum of all gaps, in m}
    OrigMaxHeight,           {Original maximum required heigth of dams, in m}
    OrigTotalHeight,		        {Original total heigth of dams, in m}
    TotalFlow,                                {Sum of all gap flows, in m3/s}
    WidthFact,                        {Relative width factor for drawings, -}
    LevelFactY,                             {Factor for drawing of levels, -}
    LevelDrX,                         {X-coordinate for drawing of levels, -}
    LastTotalFlow,                 {Previous sum of other gap flows, in m3/s}
    OYD1, OYD2, OYD3,	            {Previous Level and Velocity Coordinates}
    X1: Real;                          {X-coordinate for drawing of profiles}

    StartDrawX: RealArr;              {X-coordinates for drawing of profiles}


    ActSeaLevel,                                     {Actual sea level, in m}
    MeanSeaLevel,                                      {Mean sea level, in m}
    BasinLevel,                                        {Level in basin, in m}
    OldBasinLevel,                               {Previous basin level, in m}
    SeaLevel2,                           {Sea level for next time step, in m}
    OSeal,                                   {Previous drawn sea level, in m}
    OBasinLevel,                           {Previous drawn basin level, in m}
    TotalGapSurface,                           {Total of gap surfaces, in m3}
    OrigTotalGapSurface: Real;               {Initial sum of surfaces, in m3}

    Construction,                                    {Construction situation}
    WeirSituation: IntArr;                            {Overfall clear or not}


{== TIDAL CONDITIONS AND EQUILIBRIUM PROFILE ===============================}

    TideAmp,                       {Tidal amplitude for each component, in m}
    TidePhase0,                  {Tidal phase at  T=0  for each component, -}
    TidePeriod: RealArr;              {Tidal period for each component, in s}

    TotalAmplitude,             {Sum of amplitudes of tidal components, in m}
    TidalPrism,                         {Tidal prism, volume of water, in m3}
    EquiTotalGapSurface: Real;    {Sum of gap surfaces in equilibrium, in m3}


{== RIVER AND CULVERT FLOW =================================================}

    RiverFlow,                                            {River flow, in m3}
    CulvertSurface,                                  {Culvert surface, in m2}
    CulvertFlow,                                {Flow through culvert, in m3}


{== DRAFT OF VESSELS =======================================================}

    VesselDraft: Real;                           {Required depth for vessels}


{== BOOLEAN VARIABLES AND FLAGS ============================================}

    LookKentering,
    Started,                {Whether calculation processes have been started}
    OStarted,                                     {Previous value of Started}
    StaticsOn,              {Force Static Situation? (Programmer's use only)}
    SoundOn,                                                {Sound on or not}
    Warning,						   {Warning Required}
    HelpRequired,                                      {Help required or not}
    RememProfLev,                      {Whether profiles have been drawn yet}
    RememContours,                     {Whether contours have been drawn yet}
    RememLevels,          {Whether levels and velocities have been drawn yet}
    JustKentered,                       {Whether levels just have been equal}
    OverallOpen,                           {Whether overall window is opened}
    DataBoxOpen,                          {Whether data box window is opened}
    SomethingDrawn,                 {Whether something has been drawn lately}
    SomethingWritten,             {Whether something has been written lately}
    SomethingDumped,		           {Whether material has been dumped}
    ExitDialSeries,		        	{Exiting a dialog box series}
    Adapting,				 {Whether all information is adapted}
    DialSeriesOn,		     {Whether dialogs take place as a series}
    ReNewWindow,                       {Whether the window should be renewed}
    ProcessInited,            {Whether the process has been initiated or not}
    DataChanged,                               {Whether the data has changed}
    RenewDataBox,			       {Renew Data Box Window or not}
    DayChanged,				              {Whether new day began}
    Dialoged,				    {Whether there has been a dialog}
    StartUpCanceled,
    ErosLog,        {Whether log files are put on for Erosion and Production}
    VeloLog,                                         {For velocities in gaps}
    LevelLog,                                       {For Sea and Basin Level}
    GapLog: Boolean;                              {For Gap Depths and Widths}

    SomeZipped: Boolean;			 {Whether any gap has zipped}
    Zipped: Array[1..5] of Boolean;    		     {Whether Gap has Zipped}
{== EXTERNAL INPUT AND OUTPUT ==============================================}

    txErosLog,      {Output channel name for erosion and production log file}
    txVeloLog,                    {Output channel name for velocity log file}
    txLevelLog,                      {Output channel name for level log file}
    txGapLog: Text;          {Output channel name for gap dimension log file}

    OutP: Text;

    MouseSum: LongInt;                            {Sum of Mouse Coordiniates}

    FTL,                            {Name of file to load / last loaded file}
    FTS: FileString;                                   {Name of file to save}

    DialY1, DialY2: Integer;			             {Dialog Heights}

implementation

end.