{**********************************************************}
{       CLOSIM v 1.00  --  GRAPHIC PRESENTATION UNIT       }
{**********************************************************}
{ Containing the drawing procedures for the simulation     }
{ program on the Closure of Tidal Basins.                  }
{ Written in Turbo Pascal 7.0 by Mark Middag, TUDelft, 1994}
{**********************************************************}

unit Simdraws;

interface

uses MyGraph3,           {Advanced Graphics Library of Turbo Vision Graphics}
     SIMVARS,                                     {Variables of Main Program}
     GSIMDIAL,					               {Dialog Boxes}
     SIMTOOLS;                                {Various Tools of Main Program}

Procedure Draw_Levels(x1,y1,x2,dY: Real);    {Drawing of Levels and Velocity}
Procedure Draw_TopView(px,py,dx,dy: Real);              {Drawing of Top View}
Procedure Draw_Length(X1,Y1,dX,dY: Real);         {Drawing of Length Section}
Procedure Draw_Profile(x1,y1,x2,dY: Real);         {Drawing of Cross Section}
Procedure Draw_Contours(x1,y1,x2,dY: Real);  {Drawing of Scour Hole Contours}
Procedure Draw_LevelSpace(x1,y1,x2,dY: Real);   {Space for Drawing of Levels}
Procedure Overall_Draw(WX1,WY1,WDX,WDY: Real);   {Drawing of All Information}
Procedure Overall_KenterDraw(WX1,WY1,WDX,WDY: Real);   {Topview and Contours}

implementation

Procedure Draw_LevelSpace(x1,y1,x2,dY: Real);   {Space for Drawing of Levels}

var LevelFactY: Real;                                  {Level Scaling Factor}

begin
   Wipe(X1,Y1-DY,X2,Y1+DY);                               {Erase Level Space}
   SetColor(White);                                       {Set drawing color}
   LevelDrX:=TimeStep/200;                                 {Set X coordinate}
   if TotalAmplitude<>0 then                    {Scale Factor Level Drawings}
     LevelFactY:=dY/(TotalAmplitude+StormSurge);   {depends on maximum level}
   Box(X1,Y1-dY-1,X2,Y1+dY+1);                               {Draw Level Box}
   MoveCurs(X1,Y1+MeanSealevel*LevelFactY);                     {Draw X-Axis}
   DrawTo(X2,Y1+MeanSealevel*LevelFactY);

   For Counter:=1 to T((x2-x1)/5) do                   {Draw Grid for Levels}
     For Counter2:=1 to 10 do
     begin
       Plot(X1+Counter*5-3,Y1+Counter2*dY/10,LightGray);
       Plot(X1+Counter*5-3,Y1-Counter2*dY/10,LightGray);
     end;
   SetColor(White);                                   {Restore Drawing Color}
end;

Procedure Draw_Levels(x1,y1,x2,dY: Real);    {Drawing of Levels and Velocity}

var LevelFactX: Real;                        {Stretch factor for level graph}
    XDR, YD1, YD2, YD3,
    OXDR, MaxVelo: Real;

begin
   if JobHours>TimeStep/360 then
   begin
     LevelFactX:=(x2-x1)/TimeStep;
     OXDR:=X1+LevelFactX*LevelDrX;
     LevelDrX:=LevelDrX+1.3;                             {Reset X-Coordinate}
     if TotalAmplitude<>0 then                  {Scale Factor Level Drawings}
	LevelFactY:=dY/(TotalAmplitude+StormSurge);

     MaxVelo:=0;
     For GCT:=1 to NumOfGaps do
     if Abs(Velocity[GCT])>Abs(MaxVelo) then MaxVelo:=Velocity[GCT];

     XDR:=X1+LevelFactX*LevelDrX;             {Determine X and Y coordinates}
     YD1:=Y1-ActSeaLevel*LevelFactY;              {of the level and velocity}
     YD2:=Y1-BasinLevel*LevelFactY;                      {points to be drawn}
     YD3:=Y1-MaxVelo*dY/10;

     if RememLevels then
     begin
	SetColor(LightBlue);                       {Outside level in light blue}
	DrawLine(OXDR, OYD1, XDR, YD1);       {Connect last point and new point}
	SetColor(LightRed);                          {Inside level in light red}
	DrawLine(OXDR, OYD2, XDR, YD2);       {Connect last point and new point}
	SetColor(LightGreen);                     {Flow velocity in light green}
	DrawLine(OXDR, OYD3, XDR, YD3);       {Connect last point and new point}
     end;

     if LevelDrX*LevelFactX > (x2-x1-2) then         {If end of drawing area}
     begin                                              {reached, then erase}
	Draw_LevelSpace(x1,y1,x2,dY);
     end;

     OYD1:=YD1;					{Remember values for drawing}
     OYD2:=YD2;                                           {in next time step}
     OYD3:=YD3;
     RememLevels:=True;
   end;
end;

Procedure Draw_TopView(px,py,dx,dy: Real);           {Drawing of Top View of}
							      {Closure sites}
var PixCol:Integer;
    XL, XR, XL2, XR2, LeftX: Real;

begin
   for GCT:=1 to NumOfGaps do                                  {For all gaps}
   if (StandLengthProt[GCT]>29) then        {If they have bottom protection}
   begin
      LeftX:=px+StartDrawX[GCT]-10;
      SetColor(LightBlue);           {First draw untouched bottom protection}
      FillBox(LeftX, PY+DY*21,
	      LeftX+OrigGapWidth[GCT]*WidthFact,PY+DY*21+4);
      SetColor(LightRed);
      FillBox(LeftX, PY-DY*21,
	      LeftX+OrigGapWidth[GCT]*WidthFact,PY-DY*21-4);
      SetColor(White);
      FillBox(LeftX,
	      PY+DY*(DamTopWidth[GCT]/2+ActDamHeight[GCT]/
	      Tan(DSS[GCT]))/ProtSection[GCT]+1,
	      LeftX+OrigGapWidth[GCT]*WidthFact,PY+DY*21);
      FillBox(LeftX,
	      PY-DY*(DamTopWidth[GCT]/2+ActDamHeight[GCT]/
	      Tan(DSS[GCT]))/ProtSection[GCT]-1,
	      LeftX+OrigGapWidth[GCT]*WidthFact,PY-DY*21);

      for SC:=1 to NumOfSnaps[GCT] do          {Then, for all width sections}
      begin
	 for PSC:=1 to 20 do                {and for all protection sections}
	 begin
	    if (PY+PSC*DY)>              {If protection exceeds construction}
	    (PY+DY*(DamTopWidth[GCT]/2+ActDamHeight[GCT]/Tan(DSS[GCT]))/
	    ProtSection[GCT]) then
	    begin
	       if  InProtY[GCT,SC,PSC]<>0  then         {if has been settled}
	       begin
		  PixCol:=LightGray;                     {Draw in light gray}
		  if PSC>LastProtIn[GCT,SC]    {if settlement is fatal, then}
		  then PixCol:=DarkGray;                 {draw in  dark gray}
		  SetColor(PixCol);
		  if (PixCol=DarkGray) or (PixCol=LightGray) then
		  FillBox(LeftX+(SC-1)*OrigGapWidth[GCT]*WidthFact/NumOfSnaps[GCT],
			  PY+PSC*DY,
			  LeftX+(SC)*OrigGapWidth[GCT]*WidthFact/NumOfSnaps[GCT],
			  PY+dy+PSC*DY);
	       end;
	    end;
	    if (PY-PSC*DY)<                         {for other side the same}
	       (PY-DY*(DamTopWidth[GCT]/2+ActDamHeight[GCT]/Tan(DSS[GCT]))/
	       ProtSection[GCT]) then
	    begin
	       if OutProtY[GCT,SC,PSC]<>0 then
	       begin
		  PixCol:=LightGray;
		  if PSC>LastProtOut[GCT,SC] then PixCol:=DarkGray;
		  SetColor(PixCol);
		  if (PixCol=LightGray) or (PixCol=DarkGray) then
		  FillBox(LeftX+(SC-1)*OrigGapWidth[GCT]*WidthFact/NumOfSnaps[GCT],
			  PY-PSC*DY,
			  LeftX+(SC)*OrigGapWidth[GCT]*WidthFact/NumOfSnaps[GCT],
			  PY-dy-PSC*DY);
	       end;
	    end;
	 end;
      end;
      SetColor(Green);                        {draw dam slopes in dark green}
      FillBox(LeftX, PY-DY*(DamTopWidth[GCT]/2+
	      ActDamHeight[GCT]/Tan(DSS[GCT]))/ProtSection[GCT],
	      LeftX+OrigGapWidth[GCT]*WidthFact,PY+DY*(DamTopWidth[GCT]/2+
	      ActDamHeight[GCT]/Tan(DSS[GCT]))/ProtSection[GCT]);
      SetColor(LightGreen);                     {draw dam top in light green}
      FillBox(LeftX, PY-DY*(DamTopWidth[GCT]/2)/ProtSection[GCT],
	      LeftX+OrigGapWidth[GCT]*WidthFact,PY+DY*(DamTopWidth[GCT]/2)/ProtSection[GCT]);
      XL:=XDRL[GCT]/OrigGapWidth[GCT];
      XR:=XDRR[GCT]/OrigGapWidth[GCT];
      XL2:=(XDRL[GCT]-(DamYL[GCT]-YDR[GCT])/Tan(DSH[GCT]))/OrigGapWidth[GCT];
      XR2:=(XDRR[GCT]+(DamYR[GCT]-YDR[GCT])/Tan(DSH[GCT]))/OrigGapWidth[GCT];
      if XL2<0 then XL2:=0;
      if XR2>1 then XR2:=1;
      if (Construction[GCT]<>Finished) and
	 (ClosureScheme[GCT]=Horizontal) then
      begin
      SetColor(Green);
      FillBox(LeftX+OrigGapWidth[GCT]*WidthFact*XL2,
	      PY-DY*(DamTopWidth[GCT]/2+
	      ActDamHeight[GCT]/Tan(DSS[GCT]))/ProtSection[GCT],
	      LeftX+OrigGapWidth[GCT]*WidthFact*XR2,
	      PY+DY*(DamTopWidth[GCT]/2+
	      ActDamHeight[GCT]/Tan(DSS[GCT]))/ProtSection[GCT]);
      SetColor(White);
      FillBox(LeftX+OrigGapWidth[GCT]*WidthFact*XL,
	      PY-DY*(DamTopWidth[GCT]/2+
	      ActDamHeight[GCT]/Tan(DSS[GCT]))/ProtSection[GCT],
	      LeftX+OrigGapWidth[GCT]*WidthFact*XR-1,
	      PY+DY*(DamTopWidth[GCT]/2+
	      ActDamHeight[GCT]/Tan(DSS[GCT]))/ProtSection[GCT])
      end;
      SetColor(LightGray);                   {restore drawing color for text}
   end;
end;

Procedure Draw_Length(X1,Y1,dX,dY: Real);             {Length section of dam}
						      {and bottom protection}
var InMaxSect, OutMaxSect: Integer;
    LengthFactX,
    InHoleLevel, OutHoleLevel,
    PX1, PX2, PY1, PY2, YDist, YSize,
    DamDrawHeight: Real;

begin

   if OrigTotalHeight=0 then OrigTotalHeight:=10;

   YSize := (10/OrigTotalHeight);

   YDist:=27;
   for GCT:=1 to NumOfGaps do
   if StandLengthProt[GCT]<>0 then
   begin
					       {Determine levels and factors}
      InMaxSect:=T(MaxInHolePlace[GCT]);          {section with minimum hole}
      OutMaxSect:=T(MaxOutHolePlace[GCT]);        {section with minimum hole}
      InHoleLevel:=InHoleDepth[GCT, InMaxSect]+InProtY[GCT,
      InMaxSect, T(LastProtIn[GCT, InMaxSect])];
      OutHoleLevel:=OutHoleDepth[GCT, OutMaxSect]+OutProtY[GCT,
      OutMaxSect, T(LastProtOut[GCT, OutMaxSect])];
      LengthFactX:=0.8*dX/(DamTopWidth[GCT]/2+ActDamHeight[GCT]/
      Tan(DSS[GCT])+StandLengthProt[GCT]);
      PX1:=DamTopWidth[GCT]/2;
      PY1:=25*dY+GCT*YDist*dY-
	   ActDamHeight[GCT]*DY*Ysize;              {Set various coordinates}
      PX2:=PX1+ActDamHeight[GCT]/Tan(DSS[GCT]);
      PY2:=PY1+ActDamHeight[GCT]*dY*YSize;

      Wipe(X1-LengthFactX*(30*ProtSection[GCT]-               {Wipe old area}
	   MaxInHole[GCT]/Tan(Beta)),
	   Y1+PY1-20,
	   X1+LengthFactX*(30*ProtSection[GCT]+
	   MaxOutHole[GCT]/Tan(Beta)),
	   Y1+PY2+dY*Max(OutHoleLevel, InHoleLevel)+20);

      SetColor(LightRed);			           {Draw Dam Section}
      MoveCurs(X1-PX2*LengthFactX, Y1+PY2);
      DrawTo(X1-PX1*LengthFactX, Y1+PY1);
      DrawTo(X1, Y1+PY1);
      SetColor(LightBlue);
      DrawTo(X1+PX1*LengthFactX, Y1+PY1);
      DrawTo(X1+PX2*LengthFactX, Y1+PY2);

      if GCT=1 then
      begin
	 if FlowDirection=InFlow then
	 begin
	    SetColor(Black);
	    DrawLine(X1-15, Y1+40*dY-35, X1-20, Y1+40*dY-30);
	    DrawLine(X1-15, Y1+40*dY-25, X1-20, Y1+40*dY-30);
	    SetColor(LightBlue);
	    DrawLine(X1+15, Y1+40*dY-35, X1+20, Y1+40*dY-30);
	    DrawLine(X1+15, Y1+40*dY-25, X1+20, Y1+40*dY-30);
	 end
	 else
	 begin
	    SetColor(Black);
	    DrawLine(X1+15, Y1+40*dY-35, X1+20, Y1+40*dY-30);
	    DrawLine(X1+15, Y1+40*dY-25, X1+20, Y1+40*dY-30);
	    SetColor(LightBlue);
	    DrawLine(X1-15, Y1+40*dY-35, X1-20, Y1+40*dY-30);
	    DrawLine(X1-15, Y1+40*dY-25, X1-20, Y1+40*dY-30);
	 end;
	 DrawLine(X1-20, Y1+40*dY-30, X1+20, Y1+40*dY-30);
      end;

      SetColor(White);                    {Draw bottom protection for inflow}
      MoveCurs(X1+1*ProtSection[GCT]*LengthFactX,
	   Y1+(PY2+InProtY[GCT, InMaxSect, 1]*dY));
      for PSC:=1 to T(LastProtIn[GCT, InMaxSect]) do
	  DrawTo(X1+PSC*ProtSection[GCT]*LengthFactX,
		 Y1+(PY2+InProtY[GCT, InMaxSect, PSC]*dY));

      if Construction[GCT]<>Collapsed    {Draw maximum scour hole for inflow}
      then begin
	 SetColor(Green);                           {Inflow section in green}
	 if StandLengthProt[GCT]=0 then
	 begin
	 MoveCurs(X1,
	     Y1+PY2+dY*InHoleLevel);
	 DrawTo(X1+(LastProtIn[GCT, InMaxSect]*ProtSection[GCT]+
	     40)*LengthFactX,
	     Y1+PY2+dY*InHoleLevel);
	 end
	 else
	 DrawTo(X1+(LastProtIn[GCT, InMaxSect]*ProtSection[GCT]+
	     MaxInHole[GCT]/Tan(Beta))*LengthFactX,
	     Y1+PY2+dY*InHoleLevel);
      end;
					 {Draw bottom protection for outflow}
      SetColor(White);
      MoveCurs(X1-1*ProtSection[GCT]*LengthFactX,
	   Y1+(PY2+OutProtY[GCT, OutMaxSect, 1]*dY));
      for PSC:=1 to T(LastProtOut[GCT, OutMaxSect]) do
	  DrawTo(X1-PSC*ProtSection[GCT]*LengthFactX,
		 Y1+(PY2+OutProtY[GCT, OutMaxSect, PSC]*dY));

					{Draw maximum scour hole for outflow}
      if Construction[GCT]<>Collapsed then
      begin
	 SetColor(Cyan);
	 if StandLengthProt[GCT]=0 then
	 begin
	 MoveCurs(X1,
	     Y1+(PY2+dY*OutHoleLevel));
	 DrawTo(X1-(LastProtOut[GCT, OutMaxSect]*ProtSection[GCT]+
	     40)*LengthFactX,
	     Y1+(PY2+dY*OutHoleLevel))
	 end
	 else
	 DrawTo(X1-(LastProtOut[GCT, OutMaxSect]*ProtSection[GCT]+
	     MaxOutHole[GCT]/Tan(Beta))*LengthFactX,
	     Y1+(PY2+dY*OutHoleLevel));
      end;
   end;
end;

procedure Overall_Draw(WX1,WY1,WDX,WDY: Real);        {Draw Levels & Profile}
						       {into graphics window}
begin
				      {Only if number of gaps did not change}
   if (ONOG=NumOfGaps) then Draw_Levels(WX1+340*WDX/640,WY1+130*WDY/440,
					WX1+620*WDX/640,50*WDY/440);
   if (ONOG=NumOfGaps) then Draw_Profile(WX1+40*WDX/640,WY1+100*WDY/440,
					WX1+300*WDX/640,40*WDY/440);
end;

procedure Overall_KenterDraw(WX1,WY1,WDX,WDY: Real);   {Draw Length Section,}
						    {Top View and Scour Hole}
						       {Contours into window}
begin
   if Beta<>0 then                                               {Error Trap}
   begin
      Draw_Length(WX1+480*WDX/640,WY1+160*WDY/440, 200*WDX/640, 2*WDY/440);
      Draw_TopView(WX1+ 50*WDX/640,WY1+280*WDY/440, 1, 3*WDY/440);
      Draw_Contours(WX1+ 40*WDX/640,WY1+100*WDY/440,WX1+300*WDX/640,
							       40*WDY/440);
   end;
end;

Procedure Draw_Profile(x1,y1,x2,dY: Real);      {Draw Cross Sections of Gaps}

var xl, DrPrSzX, DrPrSzY, HoleFactY,
    XUpSlL, XUpSlR, OChanged: Real;
    OYSea, OYBin: Integer;
    ZipPlaceFact, ZipPlace: Real;

begin

    DrPrSzX:=1;
    If OrigMaxHeight=0 then DrPrSzY:=0.4                      {Minimum Scale}
		       else DrPrSzY:=(OrigMaxHeight/dY);       {Scale factor}

    for GCT:=1 to NumOfGaps do if (RememProfLev=True) then

    if ((T((10*Oseal)/DrPrSzY))<>OYSea) or             {If something changed}
       (T((10*OBasinLevel)/DrPrSzY)<>OYBin) or
       (Started=False) then

    begin
      SetColor(DarkGray);                             {Draw Original Profile}
      MoveCurs(X1+StartDrawX[GCT]/DrPrSzX,Y1-DamTop[GCT]/DrPrSzY);
      DrawTo(X1+StartDrawX[GCT]/DrPrSzX,
	 Y1-(OrigGapDepthAtMSL[GCT]/DrPrSzY));
      DrawTo(X1+(StartDrawX[GCT]+OrigGapWidth[GCT]*WidthFact)/DrPrSzX,
	 Y1-OrigGapDepthAtMSL[GCT]/DrPrSzY);
      DrawTo(X1+(StartDrawX[GCT]+OrigGapWidth[GCT]*WidthFact)/DrPrSzX,
      Y1-DamTop[GCT]/DrPrSzY);

      SetColor(Black);                               {ReMoveCurs Old Profile}
      XUpSlL:=Max(0,oXDRL[GCT]-(oDamYL[GCT]-oYDR[GCT])/Tan(DSH[GCT]));
      XUpSlR:=Min(OrigGapWidth[GCT],oXDRR[GCT]+(oDamYR[GCT]-oYDR[GCT])/
						       Tan(DSH[GCT]));
      MoveCurs(X1+StartDrawX[GCT]/DrPrSzX+0*WidthFact/DrPrSzX,
	 Y1-oDamYL[GCT]/DrPrSzY);
      DrawTo(X1+StartDrawX[GCT]/DrPrSzX+(XUpSlL)*WidthFact/DrPrSzX,
	 Y1-oDAMYL[GCT]/DrPrSzY);
      DrawTo(X1+StartDrawX[GCT]/DrPrSzX+oXDRL[GCT]*WidthFact/DrPrSzX,
	 Y1-oYDR[GCT]/DrPrSzY);
      DrawTo(X1+StartDrawX[GCT]/DrPrSzX+oXDRR[GCT]*WidthFact/DrPrSzX,
	 Y1-oYDR[GCT]/DrPrSzY);
      DrawTo(X1+StartDrawX[GCT]/DrPrSzX+(XUpSlR)*WidthFact/DrPrSzX,
	 Y1-oDAMYR[GCT]/DrPrSzY);
      DrawTo(X1+StartDrawX[GCT]/DrPrSzX+OrigGapWidth[GCT]*WidthFact/DrPrSzX,
	 Y1-oDAMYR[GCT]/DrPrSzY);

      SetColor(White);                                     {Draw New Profile}
      XUpSlL:=Max(XDRL[GCT]-(DamYL[GCT]-YDR[GCT])/Tan(DSH[GCT]),0);
      XUpSlR:=Min(OrigGapWidth[GCT],XDRR[GCT]+(DamYR[GCT]-YDR[GCT])/
						    Tan(DSH[GCT]));
      MoveCurs(X1+StartDrawX[GCT]/DrPrSzX+0*WidthFact/DrPrSzX,
	 Y1-DamYL[GCT]/DrPrSzY);
      DrawTo(X1+StartDrawX[GCT]/DrPrSzX+(XUpSlL)*WidthFact/DrPrSzX,
	 Y1-DamYL[GCT]/DrPrSzY);
      DrawTo(X1+StartDrawX[GCT]/DrPrSzX+XDRL[GCT]*WidthFact/DrPrSzX,
	 Y1-YDR[GCT]/DrPrSzY);
      if (Zipped[GCT]=False) then
      begin
	 DrawTo(X1+StartDrawX[GCT]/DrPrSzX+XDRR[GCT]*WidthFact/DrPrSzX,
	    Y1-YDR[GCT]/DrPrSzY)
      end
      else                              {If collapse by zipping has occurred}
      begin
	 ZipPlaceFact:=Random(100);                {Could occur at any place}
	 ZipPlace:=0.008*(XDRL[GCT]*ZipPlaceFact +
					    XDRR[GCT]*(100-ZipPlaceFact));
	 DrawTo(X1+StartDrawX[GCT]/DrPrSzX+(ZipPlace+10)*WidthFact/DrPrSzX,
	    Y1-YDR[GCT]/DrPrSzY);
	 DrawTo(X1+StartDrawX[GCT]/DrPrSzX+(ZipPlace+20)*WidthFact/DrPrSzX,
	    Y1-YDR[GCT]/DrPrSzY+80);
	 DrawTo(X1+StartDrawX[GCT]/DrPrSzX+(ZipPlace+30)*WidthFact/DrPrSzX,
	    Y1-YDR[GCT]/DrPrSzY);
	 DrawTo(X1+StartDrawX[GCT]/DrPrSzX+XDRR[GCT]*WidthFact/DrPrSzX,
	    Y1-YDR[GCT]/DrPrSzY);
      end;
      DrawTo(X1+StartDrawX[GCT]/DrPrSzX+(XUpSlR)*WidthFact/DrPrSzX,
	 Y1-DAMYR[GCT]/DrPrSzY);
      DrawTo(X1+StartDrawX[GCT]/DrPrSzX+OrigGapWidth[GCT]*WidthFact/DrPrSzX,
	 Y1-DAMYR[GCT]/DrPrSzY);

      SetColor(Black);
      MoveCurs((X1+StartDrawX[1])/DrPrSzX-6,
				Y1-Oseal/DrPrSzY);     {Remove Last SeaLevel}
      DrawTo(X2/DrPrSzX+6,Y1-Oseal/DrPrSzY);
      SetColor(LightBlue);
      MoveCurs((X1+StartDrawX[1])/DrPrSzX-6,
			  Y1-ActSeaLevel/DrPrSzY);     {Draw Actual SeaLevel}
      DrawTo(X2/DrPrSzX+6,Y1-ActSeaLevel/DrPrSzY);

      SetColor(Black);                              {Remove last Basin Level}
      MoveCurs((X1+StartDrawX[1])/DrPrSzX-6,Y1-(OBasinLevel)/DrPrSzY);
      DrawTo(X2/DrPrSzX+6,Y1-(OBasinLevel)/DrPrSzY);
      SetColor(LightRed);                           {Draw Actual Basin Level}
      MoveCurs((X1+StartDrawX[1])/DrPrSzX-6,Y1-(BasinLevel)/DrPrSzY);
      DrawTo(X2/DrPrSzX+6,Y1-(BasinLevel)/DrPrSzY);
      Setcolor(White);					{Reset Drawing Color}
    end;

    RememProfLev:=True;                     {Set flag for remembering values}
    oseal:=ActSeaLevel;
    oBasinLevel:=BasinLevel;
    OYBin:=T((OBasinLevel)/DrPrSzY);
    OYSea:=T((Oseal)/DrPrSzY);
    TotalWidth:=0;
    for GCT:=1 to NumOfGaps do		        	{Remember old values}
    begin                                          {so they can be erased in}
       oYDR[GCT]:=YDR[GCT];                              {the next time step}
       oXDRL[GCT]:=XDRL[GCT];
       oXDRR[GCT]:=XDRR[GCT];
       oDamYL[GCT]:=DamYL[GCT];
       oDamYR[GCT]:=DamYR[GCT];
       TotalWidth:=TotalWidth+GapWidth[GCT];
    end;
    for GCT:=1 to NumOfGaps do
    if Zipped[GCT] then
    begin
       Zipped[GCT]:=False;
       Started:=False;
       {Warn_Zipped;}
    end;
end;

Procedure Draw_Contours(x1,y1,x2,dY: Real);        {Draw Scour Hole Contours}

var DrPrSzX, DrPrSzY, HoleFactY: Real;

begin
    DrPrSzX:=1;                                               {Scale factors}
    HoleFactY:=-1;

    If OrigMaxHeight=0 then DrPrSzY:=0.4                      {Minimum scale}
		       else DrPrSzY:=(OrigMaxHeight/dY);

    for GCT:=1 to NumOfGaps do                                 {for all gaps}
    if (StandLengthProt[GCT]<>0) then            {If the bottom is protected}
    begin
      if RememContours=True then            {If they have been drawn already}
      for SC:=1 to NumOfSnaps[GCT] do
      begin
	SetColor(Black);                {ReMove old Scour Contour for Inflow}
	MoveCurs(X1+Round((StartDrawX[GCT]+(SC-1)*
					  SnapWidth[GCT]*WidthFact)/DrPrSzX),
	   Y1-Round((OrigGapDepthAtMSL[GCT]/DrPrSzY)+
					 oInHoleDepth[GCT, SC-1]*HoleFactY));
	DrawTo(X1+Round((StartDrawX[GCT]+
				   (SC-0)*SnapWidth[GCT]*WidthFact)/DrPrSzX),
	   Y1-Round((OrigGapDepthAtMSL[GCT]/DrPrSzY)+
					   oInHoleDepth[GCT, SC]*HoleFactY));

	SetColor(Black);               {ReMove old Scour Contour for Outflow}
	MoveCurs(X1+Round((StartDrawX[GCT]+
				   (SC-1)*SnapWidth[GCT]*WidthFact)/DrPrSzX),
	   Y1-Round((OrigGapDepthAtMSL[GCT]/DrPrSzY)+
					oOutHoleDepth[GCT, SC-1]*HoleFactY));
	DrawTo(X1+Round((StartDrawX[GCT]+
				   (SC-0)*SnapWidth[GCT]*WidthFact)/DrPrSzX),
	   Y1-Round((OrigGapDepthAtMSL[GCT]/DrPrSzY)+
					  oOutHoleDepth[GCT, SC]*HoleFactY));

	SetColor(Cyan);                        {Draw New Contour for Outflow}
	MoveCurs(X1+Round((StartDrawX[GCT]+
	   (SC-1)*SnapWidth[GCT]*WidthFact)/DrPrSzX),
	   Y1-Round((OrigGapDepthAtMSL[GCT]/DrPrSzY)+
	   (OutHoleDepth[GCT, SC-1]+OutProtY[GCT,SC-1,
	   T(LastProtOut[GCT,SC-1])])*HoleFactY));
	DrawTo(X1+Round((StartDrawX[GCT]+
	   (SC-0)*SnapWidth[GCT]*WidthFact)/DrPrSzX),
	   Y1-Round((OrigGapDepthAtMSL[GCT]/DrPrSzY)+
	   (OutHoleDepth[GCT, SC]+OutProtY[GCT,SC,
	   T(LastProtOut[GCT,SC])])*HoleFactY));

	SetColor(Green);                        {Draw New Contour for Inflow}
	MoveCurs(X1+Round((StartDrawX[GCT]+
	   (SC-1)*SnapWidth[GCT]*WidthFact)/DrPrSzX),
	   Y1-Round((OrigGapDepthAtMSL[GCT]/DrPrSzY)+
	   (InHoleDepth[GCT, SC-1]+InProtY[GCT,SC-1,
	   T(LastProtIn[GCT,SC-1])])*HoleFactY));
	DrawTo(X1+Round((StartDrawX[GCT]+
	   (SC-0)*SnapWidth[GCT]*WidthFact)/DrPrSzX),
	   Y1-Round((OrigGapDepthAtMSL[GCT]/DrPrSzY)+
	   (InHoleDepth[GCT, SC]+InProtY[GCT,SC,
	   T(LastProtIn[GCT,SC])])*HoleFactY));

      end;
      for SC:=0 to NumOfSnaps[GCT] do                   {Remember Old Values}
      begin
	oInHoleDepth[GCT, SC]:=
	InHoleDepth[GCT, SC]+InProtY[GCT,SC,T(LastProtIn[GCT,SC])];
	oOutHoleDepth[GCT, SC]:=
	OutHoleDepth[GCT, SC]+OutProtY[GCT,SC,T(LastProtOut[GCT,SC])];
      end;
    end;
    RememContours:=True;		     {Set Flag for Remembered Values}
end;

end.